﻿#SingleInstance
#Requires AutoHotkey v2+

;------------------------------------------------------------------------------
; CONTENTS
;	Discussion
;   AUto-COrrect TWo COnsecutive CApitals
;   Hotstring Helper -- Multi Line
;   ----------------------------------
;   Big list of auto correct items
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
;   Disussion
;   This is based on the excellent 2007 AutoCorrect.ahk script by Jim Biancolo
;   and Wikipedia's Lists of Common Misspellings.  Please find download link
;   here https://www.autohotkey.com/docs/v2/Hotstrings.htm#AutoCorrect
;   The original script has additional discussion and information.
;   See also, discussion here: https://www.autohotkey.com/boards/viewtopic.php?f=83&t=120220
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
;       AUto-COrrect TWo COnsecutive CApitals
; This version by forum member Ntepa. Updated 8-7-2023.
; https://www.autohotkey.com/boards/viewtopic.php?p=533067#p533067
;------------------------------------------------------------------------------

fix_consecutive_caps()
fix_consecutive_caps() {
    ; Hotstring only works if CapsLock is off.
    HotIf (*) => !GetKeyState("CapsLock", "T")
    loop 26 {
        char1 := Chr(A_Index + 64)
        loop 26 {
            char2 := Chr(A_Index + 64)
            ; Create hotstring for every possible combination of two letter capital letters.
            Hotstring(":*?CXB0:" char1 char2, fix.Bind(char1, char2))
        }
    }
    HotIf

    ; Third letter is checked using InputHook.
    fix(char1, char2, *) {
        ih := InputHook("V I101 L1 T.4")
        ih.OnEnd := OnEnd
        ih.Start()
        OnEnd(ih) {
            char3 := ih.Input
            if (char3 ~= "[a-z]") ; If char is lowercase alpha.
            || (char3 = A_Space && char1 char2 ~= "OF|TO|IN|IT|IS|AS|AT|WE|HE|BY|ON|BE|NO") ; Fix two letter words.
                Send("{BS 2}" StrLower(char2) char3)
        }
    }
}

;------------------------------------------------------------------------------
;       Hotstring Helper - Multi line
; By Kunkel321, with much help from forum members and others. Version 8-7-2023
; https://www.autohotkey.com/boards/viewtopic.php?f=6&t=114688
; A version of Hotstring Helper that will support block multi-line replacements.
; Customization options are present throughout, and are flagged as such.
; Needs AHK v2. Partly auto-converted from v1, partly rewritten.
; Please get a copy of AutoHotkey.exe (v2) and rename it to match the name of this
; script file, so that the .exe and the .ahk have the same name, in the same folder.
; DO NOT COMPILE, or the Append command won't work. The Gui stays in RAM, but gets
; repopulated upon hotkey press. HotStrings will be appended (added) by the
; script at the bottom.Remove these comments as desired.
;------------------------------------------------------------------------------

;==Change=colors=as=desired========================
GuiColor := "F0F8FF" ; "F0F8FF" is light blue
FontColor := "003366" ; "003366" is dark blue
;==================================================

Global hFactor := 0 ; Don't change size here.  Change in TogSize() function, below.
Global wFactor := 0 ; Don't change here.  Change in TogSize() function.
FormName := "Hotstring Helper -- Muli-Line" ; Change here, if desired.

hh := Gui('', FormName)
hh.Opt("-MinimizeBox +alwaysOnTop")
hh.BackColor := GuiColor
hh.SetFont("s11 c" . FontColor)
; -----  Trigger string parts
hh.AddText('y4 w30', 'Options')
hh.AddText('vTrigStrLbl x+20 w250', 'Trigger String')
hh.AddEdit('vMyDefaultOpts yp+20 xm+10 w30 h24')
DefHotStr := hh.AddEdit('vDefHotStr x+28 w' . wFactor + 250, '')
; ----- Replacement string parts
hh.AddText('xm', 'Enter Replacement String')
hh.SetFont('s9')
hh.AddButton('vSizeTog x+5 yp-5 h8 +notab', 'Make Bigger').OnEvent("Click", TogSize)
hh.AddButton('vSymTog x+5 h8 +notab', '+ Symbols').OnEvent("Click", TogSym)
hh.SetFont('s11')
;RepStr := hh.AddEdit('vRepStr +Wrap yp+25 xs h' . hFactor + 100 . ' w' . wFactor + 320, '')
RepStr := hh.AddEdit('vRepStr +Wrap y+1 xs h' . hFactor + 100 . ' w' . wFactor + 320, '')
ComLbl := hh.AddText('xm y' . hFactor + 182, 'Enter Comment')
hh.SetFont("s11 cGreen")
ComStr := hh.AddEdit('vComStr xs y' . hFactor + 200 . ' w' . wFactor + 315)
; ---- Buttons
(ButApp := hh.AddButton('xm y' . hFactor + 234, '&Append')).OnEvent("Click", hhButtonAppend)
(ButVal := hh.AddButton('+notab x+5 y' . hFactor + 234, '&Validate')).OnEvent("Click", hhButtonValidate)
(ButSpell := hh.AddButton('+notab x+5 y' . hFactor + 234, '&Spell')).OnEvent("Click", hhButtonSpell)
(ButOpen := hh.AddButton('+notab x+5 y' . hFactor + 234, '&Open')).OnEvent("Click", hhButtonOpen)
(ButCancel := hh.AddButton('+notab x+5 y' . hFactor + 234, '&Cancel')).OnEvent("Click", hhButtonCancel)

#h::   ; HotString Helper activation hotkey-combo (not string) is Win+h. Change if desired.
{ MyDefaultOpts := ""
  DefaultHotStr := ""
  Global myPrefix := ""
  Global mySuffix := ""
  Global ClipboardOld := ClipboardAll() ; Save and put back later.
  A_Clipboard := ""  ; Must start off blank for detection to work.
  Send("^c") ; Copy selected text.
  Errorlevel := !ClipWait(0.3) ; Wait for clipboard to contain text.
  If !InStr(A_Clipboard, "`n") ; Only trim NON multi line text strings.
    A_Clipboard := Trim(A_Clipboard) ; Because MS Word keeps leaving spaces.

  ; If white space present in selected text, probably not an Autocorrect entry.
  If (InStr(A_Clipboard, " ") || InStr(A_Clipboard, "`n"))
  {
   ;=======Change=options=for=MULTI=word=entry=options=and=trigger=strings=as=desired==============
   MyDefaultOpts := ""    ; PreEnter these multi-word hotstring options; "*" = end char not needed, etc.
   myPrefix := ";"        ; Optional character that you want suggested at the beginning of each hotstring.
   addFirstLetters := 5   ; Add first letter of this many words. (5 recommended; 0 = don't use feature.)
    tooSmallLen := 2      ; Only first letters from words longer than this. (Moot if addFirstLetters = 0)
   mySuffix := ""         ; An empty string "" means don't use feature.
  ;===========================================================one=more=below=======================
    If (addFirstLetters > 0)
    { LBLhotstring := "Edit trigger string as needed"
      initials := "" ; Initials will be the first letter of each word as a hotstring suggestion.
      HotStrSug := StrReplace(A_Clipboard, "`n", " ") ; Unwrap, but only for hotstr suggestion.
      Loop Parse, HotStrSug, A_Space
      { If (Strlen(A_LoopField) > tooSmallLen) ; Check length of each word, ignore if N letters.
           initials :=initials . SubStr(A_LoopField, ("1")<1 ? ("1")-1 : ("1"), "1")
        If (StrLen(initials) = addFirstLetters) ; stop looping if hotstring is N chars long.
           break
      }
      initials := StrLower(initials)
      DefaultHotStr := myPrefix . initials . mySuffix ; Append preferred prefix or suffix, as defined above, to initials.
    }
    else
    {LBLhotstring := "Add a trigger string"
     DefaultHotStr := myPrefix . mySuffix ; Use prefix and/or suffix as needed, but no initials.
    }
  }
  Else If (A_Clipboard = "")
      LBLhotstring := "Add a trigger string"
  else
  { LBLhotstring := "Add misspelled word"
    DefaultHotStr := A_Clipboard ; No spaces found so assume it's a mispelling autocorrect entry: no pre/suffix.
    ;===============Change=options=AUTOCORRECT=words=as=desired======================================
    myDefaultOpts := ""    ; PreEnter these (single-word) autocorrect options; "T" = raw text mode, etc.
    ;================================================================================================
  }
  hh['MyDefaultOpts'].value := MyDefaultOpts
  hh['TrigStrLbl'].value := LBLhotstring
  hh['DefHotStr'].value := DefaultHotStr
  hh['RepStr'].value := A_Clipboard
  hh['RepStr'].Opt("-Readonly")
  ButApp.Enabled := true
  hh.Show('Autosize')
} ; bottom of hotkey function

TogSize(*)
{   If (hh['SizeTog'].text = "Make Bigger") {
    hh['SizeTog'].text := "Make Smaller"
    ; ======Change=size=of=GUI=when="Make Bigger"=is=envoked========
    hFactor := 200 ; Height of Replacement box, Y pos of things below it.
    wFactor := 200 ; Width of 3 of the edit boxes.
    ;===============================================================
    SubTogSize(hFactor, wFactor)
    hh.Show('Autosize Center')
    return
  }
  If (hh['SizeTog'].text = "Make Smaller") {
    hh['SizeTog'].text := "Make Bigger"
    SubTogSize(0, 0)
    hh.Show('Autosize')
    return
  }
  SubTogSize(hFactor, wFactor)
  {
    DefHotStr.Move(,, wFactor + 250,)
    RepStr.Move(,, wFactor + 320, hFactor + 100)
    ComLbl.Move(, hFactor + 182,,)
    ComStr.move(, hFactor + 200, wFactor + 315,)
    ButApp.Move(, hFactor + 234,,)
    ButVal.Move(, hFactor + 234,,)
    ButSpell.Move(, hFactor + 234,,)
    ButOpen.Move(, hFactor + 234,,)
    ButCancel.Move(, hFactor + 234,,)
  }
}

TogSym(*)
{ ;====assign=symbolss=for="show symb"=button=================================
  myPilcrow := "¶"    ; Okay to change symb here if desired.
  myDot := "• "       ; adding a space allows more natural wrapping.
  myTab := " -> "
  ;===========================================================================
  If (hh['SymTog'].text = "+ Symbols") {
     hh['SymTog'].text := "- Symbols"
     RepStr := hh['RepStr'].text
     RepStr := StrReplace(StrReplace(RepStr, "`r`n", "`n"), "`n", myPilcrow . "`n") ; Pilcrow for Enter
     RepStr := StrReplace(RepStr, A_Space, myDot) ; middle dot for Space
     RepStr := StrReplace(RepStr, A_Tab, myTab) ; space arrow space for Tab
     hh['RepStr'].value := RepStr
     hh['RepStr'].Opt("+Readonly")
     ButApp.Enabled := false
     hh.Show('Autosize')
     return
  }
  If (hh['SymTog'].text = "- Symbols") {
    hh['SymTog'].text := "+ Symbols"
    RepStr := hh['RepStr'].text
    RepStr := StrReplace(RepStr, myPilcrow . "`r", "`r") ; Have to use `r ... weird.
	RepStr := StrReplace(RepStr, myDot, A_Space)
	RepStr := StrReplace(RepStr, myTab, A_Tab)
    hh['RepStr'].value := RepStr
    hh['RepStr'].Opt("-Readonly")
    ButApp.Enabled := true
    hh.Show('Autosize')
    return
  }
}

#HotIf WinActive(FormName, ) ; Allows window-specific hotkeys.
{
$Enter:: ; When Enter is pressed, but only in this GUI. "$" prevents accidental Enter key loop.
  { If (hh['SymTog'].text = "Hide Symb")
      return
    Else if RepStr.Focused {
      Send("{Enter}") ; Just normal typing; Enter yields Enter key press.
      Return
    }
    Else {
      hhButtonAppend() ; Replacement box not focused, so press Append button.
      return
    }
  }
  Esc::
  { hh.Hide()
    A_Clipboard := ClipboardOld
  }
}
#HotIf ; Turn off window-specific behavior.

hhButtonAppend(*)
{ tMyDefaultOpts := hh['MyDefaultOpts'].text
  tDefHotStr := hh['DefHotStr'].text
  tRepStr := hh['RepStr'].text
  ValidationFunction(tMyDefaultOpts, tDefHotStr, tRepStr)
  If Not InStr(CombinedValidMsg, "-Okay.",,, 3)
  {    ; Msg doesn't have three occurrences of "-Okay."
    msgResult := MsgBox(CombinedValidMsg "`n`n####################`nContinue Anyway?", "VALIDATION", "OC 4096" )
    if (msgResult = "OK") {
       Appendit(tMyDefaultOpts, tDefHotStr, tRepStr) ; not valid, but user chose to continue anyway
       return
     }
    else
       return ; not valid, and user cancelled
  }
  else { ; no validation problems found
    Appendit(tMyDefaultOpts, tDefHotStr, tRepStr)
    return
 }
}

hhButtonValidate(*)
{ tMyDefaultOpts := hh['MyDefaultOpts'].text
  tDefHotStr := hh['DefHotStr'].text
  tRepStr := hh['RepStr'].text
  ValidationFunction(tMyDefaultOpts, tDefHotStr, tRepStr)
  MsgBox("Validation Results`n#################`n" . CombinedValidMsg,, 4096)
  Return
}

ValidationFunction(tMyDefaultOpts, tDefHotStr, tRepStr)
{ Global CombinedValidMsg
  ThisFile := Fileread(A_ScriptName) ; Save these contents to variable 'ThisFile'.
 ; ThisFile := Fileread("S:\AutoHotkey\MasterScript\MasterScript.ahk") ; <---- CHANGE later
  If (tMyDefaultOpts = "") ; If options box is empty, skip regxex check.
    validOpts := "Okay."
  else { ;===== Make sure hotstring options are valid ========
   NeedleRegEx := "(\*|B0|\?|SI|C|K[0-9]{1,3}|SE|X|SP|O|R|T)" ; These are in the AHK docs I swear!!!
   WithNeedlesRemoved := RegExReplace(tMyDefaultOpts, NeedleRegEx, "") ; Remove all valid options from var.

  If(WithNeedlesRemoved = "") ; If they were all removed...
     validOpts := "Okay."
   else { ; Some characters from the Options box were not recognized.
     OptTips := " ; Just a block text assignement to var
       (
  Don't include the colons.
  ..from AHK v1 docs...
   * - ending char not needed
   ? - trigger inside other words
   B0 - no backspacing
   SI - send input mode
   C - case-sensitive
   K(n) - set key delay
   SE - send event mode
   X - execute command
   SP - send play mode
   O - omit end char
   R - send raw
   T - super raw
      )"
     validOpts := "Invalid Hotsring Options found.`n---> " . WithNeedlesRemoved . "`n`n`tTips:`n" . OptTips
   }
  }
    ;==== Make sure hotstring box content is valid ========
  validHot := "" ; Reset to empty each time.
  If (tDefHotStr = "") || (tDefHotStr = myPrefix) || (tDefHotStr = mySuffix) || InStr(tDefHotStr, ":")
      validHot := "HotString box should not be empty.`n-Don't include colons."
  else ; No colons, and not empty. Good. Now check for duplicates.
     Loop Parse, ThisFile, "`n", "`r" ; Check line-by-line.
      If instr(A_LoopField, ":" . tDefHotStr . "::") { ; If line contains tDefHotStr...
           validHot := "DUPLICATE FOUND`nAt Line " . A_Index . ":`n " . A_LoopField
           break
         }
   If (validHot = "") ; If variable didn't get set in loop, then no duplicates found
       validHot := "Okay."
  ;==== Make sure replacement string box content is valid ===========
  If (tRepStr = "") || (SubStr(tRepStr, ("1")<1 ? ("1")-1 : ("1"), "1")==":") ; If Replacement box empty, or first char is ":"
      validRep := "Replacement string box should not be empty.`n-Don't include the colons."
  else
      validRep := "Okay."
  ; Concatenate the three above validity checks.
  CombinedValidMsg := "OPTIONS BOX `n-" . validOpts . "`n`nHOTSTRING BOX `n-" . validHot . "`n`nREPLACEMENT BOX `n-" . validRep
  Return CombinedValidMsg ; return result for use is Append or Validation functions.
} ; end of validation func

Appendit(tMyDefaultOpts, tDefHotStr, tRepStr)
{ WholeStr := ""
  tMyDefaultOpts := hh['MyDefaultOpts'].text
  tDefHotStr := hh['DefHotStr'].text
  tRepStr := hh['RepStr'].text
  tComStr := hh['ComStr'].text
  If (tComStr != "")
    tComStr := " `; " . tComStr
  If InStr(tRepStr, "`n") {
    WholeStr :=  ":" . tMyDefaultOpts . ":" . tDefHotStr . "::" . tComStr . "`n(`n" . tRepStr . "`n)"
  }
  Else {
    WholeStr :=  ":" . tMyDefaultOpts . ":" . tDefHotStr . "::" . tRepStr . tComStr
  }
  FileAppend("`n" WholeStr, A_ScriptFullPath) ; 'n makes sure it goes on a new line.
  Reload() ; relaod the script so the new hotstring will be ready for use.
}

hhButtonSpell(*) ; Called is "Spell" because "Spell Check" is too long.
{ tRepStr := hh['RepStr'].text
  If (tRepStr = "")
    MsgBox("Replacement Text not found.",, 4096)
  else {
    googleSugg := GoogleAutoCorrect(tRepStr) ; Calls below function
    If (googleSugg = "")
        MsgBox("No suggestions found.",, 4096)
    Else {
      msgResult := MsgBox(googleSugg "`n`n######################`nChange Replacement Text?", "Google Suggestion", "OC 4096")
      if (msgResult = "OK")
        hh['RepStr'].value := googleSugg
      else
      return
    }
  }
}

GoogleAutoCorrect(word)
{ ; Original by TheDewd, converted to v2 by Mikeyww.
  ; autohotkey.com/boards/viewtopic.php?f=82&t=120143
 objReq := ComObject('WinHttp.WinHttpRequest.5.1')
 objReq.Open('GET', 'https://www.google.com/search?q=' word)
 objReq.SetRequestHeader('User-Agent'
  , 'Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0)')
 objReq.Send(), HTML := objReq.ResponseText
 If RegExMatch(HTML, 'value="(.*?)"', &A)
 If RegExMatch(HTML, ';spell=1.*?>(.*?)<\/a>', &B)
 Return B[1] || A[1]
}

hhButtonOpen(*)
{  ; Open this file and go to the bottom so you can see your Hotstrings.
  hh.Hide()
  A_Clipboard := ClipboardOld  ; Restore previous contents of clipboard.
  Edit()
  WinWaitActive(A_ScriptName) ; Wait for the script to be open in text editor.
  Sleep(250)
  Send("{Ctrl Down}{End}{Ctrl Up}{Home}") ; Navigate to the bottom.
}

hhButtonCancel(*)
{ hh.Hide()
  A_Clipboard := ClipboardOld  ; Restore previous contents of clipboard.
}

;------------------------------------------------------------------------------
;  AutoCorrects -- Table of Contents (this)
;  Ctrl+F Fix counter
;  Replacement nullifiers
;  ==Word Parts===
; :*: - Word Beginnings
; :*?C: - Word Middles w/Case Sensitive
; :*C: - Word Beginnings w/Case Sensitive
; :: - Single-match
; :*?: - Word Middles 
; :?: - Word Endings
; :?C: - Word Endings w/Case Sensitive
; :C: - Single-match w/Case Sensitive
;  -Multi-fix items are commented with " ; Fixes N misspellings"
;  -warning: several items break obscure words.  These are commented with " ; Misspells xxx" with an explanation.
;  -as of 10-6-2023, >5 items, >300k potential fixes. 
;  ================
;  Accented non English Items (with definitions)
;  Capatalize Dates
;  Items appennded via Hotstring Helper at the very bottom.
;------------------------------------------------------------------------------

;###############################################
^F3:: ; How many potential word fixes are there in the autocorrect items?
{	list := FileRead(A_ScriptFullPath)
	sum := 0
	Loop Parse list, '`n' ; mikeyww wrote this too.  
		If RegExMatch(A_LoopField, 'Fixes\h*\K\d+', &n)
			sum += n[]
	MsgBox sum, 'Sum', 64
}
;###############################################

; Trigger strings to nullify the potential misspellings that are indicated. 
:B0:Savitr:: ; (Important Hindu god) Here for :?:itr::it, which corrects 366 words.
:B0:Vaisyas:: ; (A member of the mercantile and professional Hindu caste.) Here for :?:syas::says, which corrects 12 words.
:B0:Wheatley:: ; (a fictional artificial intelligence from the Portal franchise) Here for :?:atley::ately, which corrects 162 words.
:B0:arraign:: ; Here for :?:ign::ing, which corrects 11384 words. (This is from the 2007 AutoCorrect script.)
:B0:bialy:: ; (Flat crusty-bottomed onion roll) Here for :?:ialy::ially, which corrects 244 words.
:B0:callsign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:champaign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:coign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:condign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:consign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:coreign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:cosign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:countersign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:deign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:deraign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:eloign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:ensign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:feign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:indign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:kc:: ; (thousand per second). Here for :?:kc::ck, which corrects 610 words.
:B0:malign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:miliary:: ; Here for :?:miliary::military, which corrects 4 words.
:B0:minyanim:: ; (The quorum required by Jewish law to be present for public worship) Here for :?:anim::anism, which corrects 123 words.
:B0:pfennig:: ; (100 pfennigs formerly equaled 1 DeutscheÂ Mark in Germany). Here for :?:nig::ing, which corrects 11414 words.
:B0:reign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:sice:: ; (The number six at dice) Here for :?:sice::sive, which corrects 166 words.
:B0:sign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0:verisign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:align:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:assign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:benign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:campaign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:design:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:foreign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:resign:: ; Here for :?:ign::ing, which corrects 11384 words.
:B0?:sovereign:: ; Here for :?:ign::ing, which corrects 11384 words.
/*
Unfortunately, it doesn't work if other the multi-fix item has :*: in the options.  So these can't be nullified.  
If you hope to ever type any of these words, locate the corresponding autocorrect item and delete it. 
:B0:Ahvenanmaa:: ; also :Jahvey:, :Wahvey:, :Yahve:, :Yahveh: (Hebrew names for God.) Here for :?*:ahve::have, which corrects 47 words.
:B0:Basra:: ; (An oil city in Iraq) Here for :?*:asr::ase, which corrects 698 words.
:B0:Datapoint:: ; For username Datapoint. Here for :?*:apoint::appoint, which corrects 30 words.
:B0:Dennstaedtia:: ; (fern), Hoffmannsthal, (poet) Here for :?*:nnst::nst, which corrects 729 words.
:B0:Gadiformes:: ; (Cods, haddocks, grenadiers) Here for :?*:adif::atif, which corrects 50 words.
:B0:Illecebrum:: ; (Species of plan in Europe) Here for :?*:lece::lesce, which corrects 52 words.
:B0:Mephitinae:: ; (skunk), also :neritina: (snail) Here for :?*:itina::itiona, which corrects 79 words.
:B0:Minkowski:: ; (German mathematician) Here for :?*:nkow::know, which corrects 66 words.
:B0:Mulloidichthys:: ; a genus of Mullidae. Here for :*:dicht::dichot, which corrects 18 words.
:B0:Ondaatje:: ; (Canadian writer) Here for :?*:tje::the, which corrects 2176 words.
:B0:Phalangiidae:: ; (type of Huntsman spider) Here for :?*:giid::good, which corrects 31 words.
:B0:Prosecco:: ; (Italian wine) and recco (abbrev. for Reconnaissance) Here for :?*:ecco::eco, which corrects 994 words.
:B0:Pycnanthemum:: ; (mint), and Tridacna (giant clam).+ Here for :?*:cna::can, which corrects 1019 words.
:B0:Scincella:: ; (A reptile genus of Scincidae) Here for :?*:scince::science, which corrects 25 words.
:B0:Scirpus:: ; (Rhizomatous perennial grasslike herbs) Here for :?*:cirp::crip, which corrects 126 words.
:B0:Taoiseach:: ; (The prime minister of the Irish Republic) Here for :?*:seach::search, which corrects 25 words.
:B0:accroides:: ; (An alcohol-soluble resin) Here for :?*:accro::acro, which corrects 145 words.
:B0:ammeter:: ; (electrician's tool). Here for :*:amme::ame, which corrects 341 words.
:B0:braaivleis:: ; (Type of S. Affrican BBQ) Here for :?*:ivle::ivel, which corrects 589 words.
:B0:brodiaea:: ; (a type of plant) Here for :?*:brod::broad, which corrects 55 words.
:B0:ceviche:: ; (South American seafood dish) Here for :?*:cev::ceiv, which corrects 82 words.
:B0:darshan:: ; ((Hinduism - being in the presence of the divine or holy person or image) Here for :?*:rshan::rtion, which corrects 84 words.
:B0:emcee:: ; (host at formal occasion) Here for :?*:emce::ence, which corrects 775 words.
:B0:gaol:: ; British spelling of jail Here for :*:gaol::goal, which corrects 22 words.
:B0:grama:: ; (Pasture grass of plains of South America and western North America) Here for :?*:grama::gramma, which corrects 72 words.
:B0:indite:: ; (Produce a literaryÂ work) Here for :?*:indite::indict, which corrects 22 words.
:B0:itraconazole:: ; (Antifungal drug). Here for :*:itr::it, which corrects 101 words.
:B0:lisente:: ; (100 lisente equal 1 loti in Lesotho, S. Afterica) Here for :?*:lisen::licen, which corrects 34 words.
:B0:pemphigous:: ; (a skin disease) Here for :?*:igous::igious, which corrects 23 words.
:B0:seviche:: ; (South American dish of raw fish) Here for :?*:sevic::servic, which corrects 25 words.
:B0:spritual:: ; (A light spar that crosses a fore-and-aft sail diagonally) Here for :?*:spritual::spiritual, which corrects 31 words.
:B0:spycatcher:: ; (secret spy stuff) Here for :?*:spyc::psyc, which corrects 192 words.
:B0:unfeasable:: ; (archaic, no longer used) Here for :?*:feasable::feasible, which corrects 11 words.
:B0:vicomte:: ; (French nobleman) Here for :?*C:comt::cont, which corrects 587 words.
*/
{	return  ; This makes the above hotstrings do nothing so that they override the indicated rules below.
}
:*:pinon::piñon  ; noun any of several low-growing pines of western North America (must be above ":?*:pinon::pion ; Corrects 44 words")

#Hotstring Z ; The Z causes the end char to be reset after each activation. 

:*:Buddist::Buddhist ; Fixes 3 words
:*:Hatian::Haitian ; Fixes 2 words
:*:Naploeon::Napoleon ; Fixes 6 words
:*:Napolean::Napoleon ; Fixes 6 words
:*:Pennyslvania::Pennsylvania ; Fixes 3 words
:*:Queenland::Queensland ; Fixes 3 words
:*:xoom::zoom ; Fixes 15 words
:*:a ab::an ab
:*:a ac::an ac
:*:a ad::an ad
:*:a af::an af
:*:a ag::an ag
:*:a al::an al
:*:a am::an am
:*:a an::an an
:*:a ap::an ap
:*:a as::an as
:*:a av::an av
:*:a aw::an aw
:*:a ea::an ea
:*:a ef::an ef
:*:a ei::an ei
:*:a el::an el
:*:a em::an em
:*:a en::an en
:*:a ep::an ep
:*:a eq::an eq
:*:a es::an es
:*:a et::an et
:*:a ex::an ex
:*:a ic::an ic
:*:a id::an id
:*:a ig::an ig
:*:a il::an il
:*:a im::an im
:*:a in::an in
:*:a ir::an ir
:*:a is::an is
:*:a oa::an oa
:*:a ob::an ob
:*:a oi::an oi
:*:a ol::an ol
:*:a op::an op
:*:a or::an or
:*:a os::an os
:*:a ot::an ot
:*:a ou::an ou
:*:a ov::an ov
:*:a ow::an ow
:*:a ud::an ud
:*:a ug::an ug
:*:a ul::an ul
:*:a um::an um
:*:a un::an un
:*:a up::an up
:*:abandonned::abandoned ; Fixes 2 words
:*:abcense::absence ; Fixes 2 words
:*:abera::aberra ; Fixes 15 words
:*:abondon::abandon ; Fixes 8 words
:*:abreviat::abbreviat ; Fixes 9 words
:*:absail::abseil ; Fixes 6 words
:*:abscen::absen ; Fixes 16 words
:*:absense::absence ; Fixes 2 words
:*:acclimit::acclimat ; Fixes 18 words
:*:accomd::accommod ; Fixes 16 words
:*:accordeon::accordion ; Fixes 4 words
:*:accordian::accordion ; Fixes 4 words
:*:achei::achie ; Fixes 12 words
:*:achiv::achiev ; Fixes 10 words
:*:aciden::acciden ; Fixes 8 words
:*:ackward::awkward ; Fixes 5 words
:*:acord::accord ; Fixes 15 words
:*:acquite::acquitte ; Fixes 3 words
:*:acuse::accuse ; Fixes 6 words
:*:adbandon::abandon ; Fixes 8 words
:*:adhear::adher ; Fixes 9 words
:*:adheran::adheren ; Fixes 5 words
:*:adresa::addressa ; Fixes 3 words
:*:adress::address ; Fixes 13 words
:*:adves::advers ; Fixes 11 words
:*:afair::affair ; Fixes 4 words
:*:afficianado::aficionado ; Fixes 2 words
:*:afficionado::aficionado ; Fixes 2 words
:*:agani::again ; Fixes 2 words
:*:aggregious::egregious ; Fixes 3 words
:*:agian::again ; Fixes 2 words
:*:agina::again ; Fixes 2 words
:*:agriev::aggriev ; Fixes 5 words
:*:aiport::airport ; Fixes 2 words
:*:aledg::alleg ; Fixes 46 words
:*:alege::allege ; Fixes 6 words
:*:alegien::allegian ; Fixes 5 words
:*:algebraical::algebraic ; Fixes 3 words
:*:alientat::alienat ; Fixes 8 words
:*:alledg::alleg ; Fixes 46 words
:*:allivia::allevia ; Fixes 12 words
:*:allopon::allophon ; Fixes 4 words
:*:alse::else ; Fixes 3 words
:*:alterior::ulterior ; Fixes 4 words
:*:alternit::alternat ; Fixes 15 words
:*:alusi::allusi ; Fixes 5 words
:*:amalgom::amalgam ; Fixes 11 words
:*:amature::amateur ; Fixes 7 words
:*:amme::ame ; Fixes 341 words, Misspells ammeter (electrician's tool).
:*:ammuse::amuse ; Fixes 6 words.
:*:amoung::among ; Fixes 2 words
:*:amung::among ; Fixes 2 words
:*:amunition::ammunition ; Fixes 2 words
:*:an large::a large 
:*:analag::analog ; Fixes 23 words
:*:anarchim::anarchism ; Fixes 2 words
:*:andd::and ; Fixes 73 words
:*:androgenous::androgynous ; Fixes 3 words
:*:anih::annih ; Fixes 9 words
:*:aniv::anniv ; Fixes 2 words
:*:anonim::anonym ; Fixes 19 words
:*:anoyance::annoyance ; Fixes 2 words
:*:ansal::nasal ; Fixes 20 words
:*:ansest::ancest ; Fixes 8 words
:*:antartic::antarctic ; Fixes 2 words
:*:anthrom::anthropom ; Fixes 27 words
:*:anual::annual ; Fixes 15 words
:*:anul::annul ; Fixes 17 words
:*:aproxim::approxim ; Fixes 14 words
:*:aquaduct::aqueduct ; Fixes 2 words
:*:aquir::acquir ; Fixes 12 words
:*:arbouret::arboret ; Fixes 3 words
:*:archiac::archaic ; Fixes 6 words
:*:archtyp::archetyp ; Fixes 6 words
:*:areod::aerod ; Fixes 10 words
:*:ariv::arriv ; Fixes 11 words
:*:armistace::armistice ; Fixes 2 words
:*:arogan::arrogan ; Fixes 6 words
:*:arren::arran ; Fixes 12 words
:*:arrou::arou ; Fixes 11 words
:*:artc::artic ; Fixes 26 words
:*:artical::article ; Fixes 3 words
:*:artifical::artificial ; Fixes 6 words
:*:artillar::artiller ; Fixes 6 words
:*:asetic::ascetic ; Fixes 6 words
:*:asphyxa::asphyxia ; Fixes 13 words
:*:assasin::assassin ; Fixes 10 words
:*:assesment::assessment ; Fixes 4 words
:*:asside::aside ; Fixes 2 words
:*:assisnat::assassinat ; Fixes 8 words
:*:assistent::assistant ; Fixes 4 words
:*:assit::assist ; Fixes 14 words
:*:assualt::assault ; Fixes 10 words
:*:asum::assum ; Fixes 19 words
:*:athenean::Athenian ; Fixes 2 words
:*:atn::ant ; Fixes 704 words
:*:atorne::attorne ; Fixes 5 words
:*:attourne::attorne ; Fixes 5 words
:*:attroci::atroci ; Fixes 5 words
:*:auromat::automat ; Fixes 36 words
:*:austrailia::Australia ; Fixes 14 words
:*:authorative::authoritative ; Fixes 3 words
:*:authoritive::authoritative ; Fixes 3 words
:*:autochtonous::autochthonous ; Fixes 3 words
:*:autocton::autochthon ; Fixes 10 words
:*:autorit::authorit ; Fixes 9 words
:*:autsim::autism ; Fixes 2 words
:*:auxilar::auxiliar ; Fixes 2 words
:*:auxillar::auxiliar ; Fixes 2 words
:*:auxilliar::auxiliar ; Fixes 2 words
:*:avalance::avalanche ; Fixes 3 words
:*:avati::aviati ; Fixes 3 words
:*:averagee::average ; Fixes 5 words
:*:aywa::away ; Fixes 4 words
:*:bananna::banana ; Fixes 2 words
:*:bandonn::abandon ; Fixes 8 words
:*:bandwith::bandwidth ; Fixes 2 words
:*:bankrupc::bankruptc ; Fixes 2 words
:*:banrupt::bankrupt ; Fixes 7 words
:*:barb wire::barbed wire  ; Fixes 2 words
:*:beachead::beachhead ; Fixes 2 words
:*:beastia::bestia ; Fixes 14 words
:*:begginer::beginner ; Fixes 2 words
:*:beggining::beginning ; Fixes 3 words
:*:begining::beginning ; Fixes 3 words
:*:bellweather::bellwether ; Fixes 2 words
:*:bergamont::bergamot ; Fixes 2 words
:*:beseig::besieg ; Fixes 9 words
:*:beteen::between ; Fixes 3 words
:*:betwen::between ; Fixes 3 words
:*:beut::beaut ; Fixes 20 words
:*:beween::between ; Fixes 3 words
:*:bewteen::between ; Fixes 3 words
:*:bigining::beginning ; Fixes 3 words
:*:biginning::beginning ; Fixes 3 words
:*:billingual::bilingual ; Fixes 7 words
:*:bizzare::bizarre ; Fixes 3 words
:*:blaim::blame ; Fixes 14 words
:*:blitzkreig::Blitzkrieg ; Fixes 4 words
:*:bodydbuilder::bodybuilder ; Fixes 2 words
:*:boyan::buoyan ; Fixes 5 words
:*:brasillian::Brazilian ; Fixes 2 words
:*:breakthough::breakthrough ; Fixes 2 words
:*:brillan::brillian ; Fixes 9 words
:*:brocolli::broccoli ; Fixes 2 words
:*:buddah::Buddha ; Fixes 2 words
:*:buoan::buoyan ; Fixes 5 words
:*:bve::be ; Fixes 1565 words
:*:cacus::caucus ; Fixes 4 words
:*:calaber::caliber ; Fixes 2 words
:*:calander::calendar ; Fixes 4 words
:*:calender::calendar ; Fixes 4 words
:*:califronia::California ; Fixes 3 words
:*:caligra::calligra ; Fixes 15 words
:*:cambrige::Cambridge ; Fixes 2 words
:*:camoflag::camouflag ; Fixes 4 words
:*:candidiat::candidat ; Fixes 4 words
:*:cannota::connota ; Fixes 5 words
:*:cansel::cancel ; Fixes 21 words ; Added be Steve
:*:cantalop::cantaloup ; Fixes 4 words
:*:carniver::carnivor ; Fixes 7 words
:*:carree::caree ; Fixes 12 words
:*:carrib::Carib ; Fixes 8 words
:*:carthogr::cartogr ; Fixes 9 words
:*:casion::caisson ; Fixes 2 words
:*:cassawor::cassowar ; Fixes 2 words
:*:cassowarr::cassowar ; Fixes 2 words
:*:casulat::casualt ; Fixes 2 words
:*:catapillar::caterpillar ; Fixes 2 words
:*:catapiller::caterpillar ; Fixes 2 words
:*:catepillar::caterpillar ; Fixes 2 words
:*:caterpilar::caterpillar ; Fixes 2 words
:*:caterpiller::caterpillar ; Fixes 2 words
:*:catterpilar::caterpillar ; Fixes 2 words
:*:catterpillar::caterpillar ; Fixes 2 words
:*:caucasion::Caucasian ; Fixes 2 words
:*:ceasa::Caesa ; Fixes 14 words
:*:cemetar::cemeter ; Fixes 3 words
:*:champang::champagn ; Fixes 5 words
:*:chauffer::chauffeur ; Fixes 4 words
:*:choclat::chocolat ; Fixes 7 words
:*:chuch::church ; Fixes 30 words
:*:ciel::ceil ; Fixes 10 words
:*:cilind::cylind ; Fixes 8 words
:*:cirtu::citru ; Fixes 7 words
:*:colate::collate ; Fixes 19 words
:*:colea::collea ; Fixes 2 words
:*:collaber::collabor ; Fixes 15 words
:*:collos::coloss ; Fixes 9 words
:*:comande::commande ; Fixes 11 words
:*:comando::commando ; Fixes 2 words
:*:comback::comeback ; Fixes 2 words
:*:comdem::condem ; Fixes 12 words
:*:commadn::command ; Fixes 22 words
:*:commemerat::commemorat ; Fixes 12 words
:*:commerorat::commemorat ; Fixes 12 words
:*:compair::compare ; Fixes 3 words
:*:comparit::comparat ; Fixes 6 words
:*:competion::competition ; Fixes 2 words
:*:compona::compone ; Fixes 5 words
:*:compulsar::compulsor ; Fixes 3 words
:*:compulser::compulsor ; Fixes 3 words
:*:concensu::consensu ; Fixes 4 words
:*:conciet::conceit ; Fixes 5 words
:*:condamn::condemn ; Fixes 12 words
:*:condemm::condemn ; Fixes 12 words
:*:conesencu::consensu ; Fixes 4 words
:*:confidental::confidential ; Fixes 5 words
:*:congradulat::congratulat ; Fixes 9 words
:*:coniv::conniv ; Fixes 11 words
:*:conneticut::Connecticut ; Fixes 2 words
:*:conot::connot ; Fixes 9 words
:*:conquerer::conqueror ; Fixes 2 words
:*:consorci::consorti ; Fixes 4 words
:*:consulan::consultan ; Fixes 4 words
:*:consulten::consultan ; Fixes 4 words
:*:copy or report::copy of report
:*:copy or signed::copy of signed
:*:corosi::corrosi ; Fixes 6 words
:*:correpond::correspond ; Fixes 12 words
:*:corridoor::corridor ; Fixes 2 words
:*:coucil::council ; Fixes 14 words
:*:coudl::could
:*:councellor::counselor ; Fixes 4 words
:*:counr::countr ; Fixes 18 words
:*:creeden::creden ; Fixes 10 words
:*:creme::crème ; Fixes 2 words
:*:critere::criteri ; Fixes 6 words
:*:critiz::criticiz ; Fixes 7 words
:*:crucifiction::crucifixion ; Fixes 2 words
:*:culimi::culmi ; Fixes 8 words
:*:curriculm::curriculum ; Fixes 2 words
:*:cyclind::cylind ; Fixes 8 words
:*:dacquiri::daiquiri ; Fixes 2 words
:*:dael::deal ; Fixes 31 words
:*:dakiri::daiquiri ; Fixes 2 words
:*:dalmation::dalmatian ; Fixes 2 words
:*:deafult::default ; Fixes 6 words
:*:decathalon::decathlon ; Fixes 2 words
:*:definan::defian ; Fixes 5 words
:*:delapidat::dilapidat ; Fixes 6 words
:*:deleri::deliri ; Fixes 7 words
:*:derogit::derogat ; Fixes 11 words
:*:descripter::descriptor ; Fixes 2 words
:*:desease::disease ; Fixes 5 words.
:*:desica::desicca ; Fixes 11 words
:*:desinte::disinte ; Fixes 24 words.
:*:desktiop::desktop ; Fixes 2 words
:*:desorder::disorder ; Fixes 8 words.
:*:desorient::disorient ; Fixes 10 words.
:*:desparat::desperat ; Fixes 6 words.
:*:dessicat::desiccat ; Fixes 9 words.
:*:deteoriat::deteriorat ; Fixes 6 words.
:*:deteriat::deteriorat ; Fixes 6 words.
:*:deterioriat::deteriorat ; Fixes 6 words.
:*:detrement::detriment ; Fixes 5 words.
:*:devaste::devastate ; Fixes 3 words
:*:devestat::devastat ; Fixes 9 words.
:*:devistat::devastat ; Fixes 9 words.
:*:diablic::diabolic ; Fixes 4 words.
:*:diast::disast ; Fixes 5 words.
:*:dicht::dichot ; Fixes 18 words.  Misspells "Mulloidichthys" a genus of Mullidae (goatfishes or red mullets).
:*:diconnect::disconnect ; Fixes 9 words.
:*:diffcult::difficult ; Fixes 5 words
:*:dificult::difficult ; Fixes 5 words
:*:diminuit::diminut ; Fixes 6 words
:*:dimunit::diminut ; Fixes 6 words
:*:diphtong::diphthong ; Fixes 14 words
:*:diplomanc::diplomac ; Fixes 2 words
:*:diptheria::diphtheria ; Fixes 3 words
:*:dipthong::diphthong ; Fixes 14 words
:*:disasterous::disastrous ; Fixes 3 words
:*:disatisf::dissatisf ; Fixes 11 words
:*:disatrous::disastrous ; Fixes 3 words
:*:diseminat::disseminat ; Fixes 9 words
:*:dispair::despair ; Fixes 6 words
:*:dispele::dispelle ; Fixes 3 words
:*:dispicab::despicab ; Fixes 5 words
:*:dispite::despite ; Fixes 5 words
:*:disproportiate::disproportionate ; Fixes 6 words
:*:dissag::disag ; Fixes 16 words
:*:dissap::disap ; Fixes 37 words
:*:dissar::disar ; Fixes 25 words
:*:dissob::disob ; Fixes 15 words
:*:divinition::divination ; Fixes 2 words
:*:double header::doubleheader ; Fixes 2 words
:*:draughtm::draughtsm ; Fixes 4 words
:*:elphant::elephant ; Fixes 6 words
:*:embezell::embezzl ; Fixes 8 words
:*:emblamatic::emblematic ; Fixes 4 words
:*:emial::email ; Fixes 6 words
:*:eminat::emanat ; Fixes 6 words
:*:emite::emitte ; Fixes 3 words
:*:emn::enm ; Fixes 8 words
:*:emphysyma::emphysema ; Fixes 3 words
:*:empirial::imperial ; Fixes 18 words
:*:emporer::emperor ; Fixes 4 words
:*:enchanc::enhanc ; Fixes 9 words
:*:encylop::encyclop ; Fixes 16 word
:*:endevors::endeavors ; Fixes 8 words
:*:endolithe::endolith ; Fixes 2 words (which are not in WordWeb)
:*:ened::need ; Fixes 44 words
:*:english::English ; Fixes 8 words
:*:enlargment::enlargement ; Fixes 2 words
:*:enlish::English ; Fixes 8 words
:*:enourmous::enormous ; Fixes 3 words
:*:enscons::ensconc ; Fixes 4 words
:*:enteratin::entertain ; Fixes 10 words
:*:entrepeneur::entrepreneur ; Fixes 7 words
:*:enviorment::environment ; Fixes 8 words
:*:enviorn::environ ; Fixes 12 words
:*:envirom::environm ; Fixes 8 words
:*:envrion::environ ; Fixes 8 words
:*:epidsod::episod ; Fixes 6 words
:*:epsiod::episod ; Fixes 6 words
:*:equitor::equator ; Fixes 5 words
:*:eral::real ; Fixes 74 words
:*:eratic::erratic ; Fixes 4 words
:*:erest::arrest ; Fixes 14 words
:*:errupt::erupt ; Fixes 6 words
:*:escta::ecsta ; Fixes 5 words
:*:esle::else ; Fixes 3 words
:*:europian::European ; Fixes 15 words
:*:eurpean::European ; Fixes 15 words
:*:eurpoean::European ; Fixes 15 words
:*:evenhtual::eventual ; Fixes 4 words
:*:evental::eventual ; Fixes 4 words
:*:evential::eventual ; Fixes 4 words
:*:excede::exceed ; Fixes 8 words
:*:excelen::excellen ; Fixes 9 words
:*:excellan::excellen ; Fixes 9 words
:*:exection::execution ; Fixes 5 words
:*:exelen::excellen ; Fixes 9 words
:*:exellen::excellen ; Fixes 9 words
:*:exerbat::exacerbat ; Fixes 7 words
:*:exerpt::excerpt ; Fixes 6 words
:*:exerternal::external ; Fixes 22 words
:*:exhalt::exalt ; Fixes 10 words
:*:exhibt::exhibit ; Fixes 20 words
:*:exibit::exhibit ; Fixes 20 words
:*:exilera::exhilara ; Fixes 9 words
:*:exlud::exclud ; Fixes 7 words
:*:exonorat::exonerat ; Fixes 7 words
:*:expeiment::experiment ; Fixes 14 words
:*:explainat::explanat ; Fixes 7 words
:*:expropiat::expropriat ; Fixes 8 words
:*:exteme::extreme ; Fixes 6 words
:*:extraterrestial::extraterrestrial ; Fixes 3 words
:*:extravagent::extravagant ; Fixes 3 words
:*:extrordinar::extraordinar ; Fixes 3 words
:*:eyar::year ; Fixes 17 words
:*:faciliat::facilitat ; Fixes 10 words
:*:facillitat::facilitat ; Fixes 10 words
:*:facinat::fascinat ; Fixes 10 words
:*:faetur::featur ; Fixes 6 words
:*:fleed::freed ; Fixes 4 words
:*:forhe::forehe ; Fixes 5 words
:*:fortell::foretell ; Fixes 5 words
:*:foundar::foundr ; Fixes 5 words
:*:fouth::fourth ; Fixes 3 words
:*:fransiscan::Franciscan ; Fixes 3 words
:*:froniter::frontier ; Fixes 6 words
:*:fued::feud ; Fixes 28 words
:*:fuhrer::Führer ; Fixes 2 words
:*:furner::funer ; Fixes 6 words
:*:futhe::furthe ; Fixes 10 words
:*:fwe::few ; Fixes 5 words
:*:ganst::gangst ; Fixes 6 words
:*:gaol::goal ; Fixes 22 words ; Misspells British spelling of "jail"
:*:gauren::guaran ; Fixes 15 words
:*:geneolog::genealog ; Fixes 7 words
:*:gerat::great ; Fixes 12 words
:*:girat::gyrat ; Fixes 9 words
:*:gloabl::global ; Fixes 18 words
:*:gnaww::gnaw ; Fixes 8 words
:*:gouvener::governor ; Fixes 6 words
:*:governer::governor ; Fixes 6 words
:*:graet::great ; Fixes 12 words
:*:grafitti::graffiti ; Fixes 5 words
:*:gridle::griddle ; Fixes 5 words
:*:guage::gauge ; Fixes 6 words
:*:guerrila::guerrilla ; Fixes 2 words
:*:guidlin::guidelin ; Fixes 2 words
:*:gutteral::guttural ; Fixes 4 words
:*:haemorrage::haemorrhage ; Fixes 3 words
:*:halarious::hilarious ; Fixes 3 words
:*:halp::help ; Fixes 21 words
:*:hapen::happen ; Fixes 7 words
:*:harasm::harassm ; Fixes 2 words
:*:harassement::harassment ; Fixes 2 words
:*:hda::had ; Fixes 28 words
:*:headquarer::headquarter ; Fixes 4 words
:*:headquater::headquarter ; Fixes 4 words
:*:helment::helmet ; Fixes 5 words
:*:hemmorhage::hemorrhage ; Fixes 3 words
:*:hesista::hesita ; Fixes 19 words
:*:hge::he ; Fixes 1607 words
:*:hieght::height ; Fixes 6 words
:*:hlep::help ; Fixes 21 words
:*:holliday::holiday ; Fixes 6 words
:*:hosit::hoist ; Fixes 6 words
:*:hsa::has ; Fixes 64 words
:*:hte::the ; Fixes 402 words
:*:hti::thi ; Fixes 186 words
:*:hwi::whi ; Fixes 310 words
:*:hwo::who ; Fixes 76 words
:*:hygein::hygien ; Fixes 18 words
:*:hyjack::hijack ; Fixes 7 words
:*:iconclas::iconoclas ; Fixes 6 words
:*:idae::idea ; Fixes 40 words
:*:idealogi::ideologi ; Fixes 7 words
:*:illegim::illegitim ; Fixes 6 words
:*:illegitma::illegitima ; Fixes 6 words
:*:illieg::illeg ; Fixes 27 words
:*:ilog::illog ; Fixes 7 words
:*:ilu::illu ; Fixes 61 words
:*:iman::immin ; Fixes 11 words
:*:imcom::incom ; Fixes 78 words
:*:imigra::immigra ; Fixes 8 words
:*:immida::immedia ; Fixes 5 words
:*:immidia::immedia ; Fixes 5 words
:*:immunosupress::immunosuppress ; Fixes 9 words
:*:impecab::impecca ; Fixes 6 words
:*:impressa::impresa ; Fixes 4 words
:*:improvision::improvisation ; Fixes 4 words
:*:inagura::inaugura ; Fixes 11 words
:*:inate::innate ; Fixes 3 words
:*:inaugure::inaugurate ; Fixes 3 words
:*:inbalance::imbalance ; Fixes 3 words
:*:incread::incred ; Fixes 10 words
:*:indefineab::undefinab ; Fixes 4 words
:*:independan::independen ; Fixes 8 words
:*:indesp::indisp ; Fixes 16 words
:*:indigine::indigen ; Fixes 24 words
:*:inevatibl::inevitabl ; Fixes 4 words
:*:inevitib::inevitab ; Fixes 6 words
:*:inevititab::inevitab ; Fixes 6 words
:*:inmigra::immigra ; Fixes 8 words
:*:inocenc::innocenc ; Fixes 4 words
:*:inofficial::unofficial ; Fixes 3 words
:*:inot::into ; Fixes 36 words
:*:inpen::impen ; Fixes 22 words
:*:interelat::interrelat ; Fixes 10 words
:*:intertain::entertain ; Fixes 10 words
:*:intial::initial ; Fixes 25 words
:*:intrument::instrument ; Fixes 19 words
:*:intrust::entrust ; Fixes 4 words
:*:inumer::innumer ; Fixes 8 words
:*:inventer::inventor ; Fixes 6 words
:*:ireleven::irrelevan ; Fixes 6 words
:*:iresistabl::irresistibl ; Fixes 3 words
:*:iresistib::irresistib ; Fixes 5 words
:*:iritab::irritab ; Fixes 5 words
:*:iritat::irritat ; Fixes 12 words
:*:itr::it ; Fixes 101 words, but misspells itraconazole (Antifungal drug). 
:*:jeapard::jeopard ; Fixes 13 words
:*:jouney::journey ; Fixes 9 words
:*:lable::label ; Fixes 12 words
:*:lasoo::lasso ; Fixes 8 words
:*:lazer::laser ; Fixes 4 words
:*:leage::league ; Fixes 7 words
:*:lefr::left ; Fixes 22 words
:*:leran::learn ; Fixes 13 words
:*:leutenan::lieutenan ; Fixes 4 words
:*:levle::level ; Fixes 24 words
:*:lias::liais ; Fixes 6 words, Case-sensitive to not misspell Lias (One of the Jurrasic periods.)
:*:libell::libel ; Fixes 18 words
:*:lible::libel ; Fixes 18 words
:*:librer::librar ; Fixes 6 words
:*:liesure::leisure ; Fixes 5 words
:*:liev::live ; Fixes 58 words
:*:liquif::liquef ; Fixes 11 words
:*:lsat::last ; Fixes 11 words
:*:lsit::list ; Fixes 30 words
:*:lveo::love ; Fixes 42 words
:*:lvoe::love ; Fixes 42 words
:*:lybia::Libya ; Fixes 3 words
:*:maginc::magic ; Fixes 9 words
:*:magnificien::magnificen ; Fixes 5 words
:*:magol::magnol ; Fixes 7 words
:*:manisf::manif ; Fixes 17 words
:*:marrtyr::martyr ; Fixes 23 words
:*:masterbat::masturbat ; Fixes 9 words
:*:mataph::metaph ; Fixes 18 words
:*:mechandi::merchandi ; Fixes 12 words
:*:mercentil::mercantil ; Fixes 7 words
:*:mesag::messag ; Fixes 5 words
:*:meterolog::meteorolog ; Fixes 7 words
:*:micos::micros ; Fixes 40 words
:*:milion::million ; Fixes 9 words
:*:milleni::millenni ; Fixes 9 words
:*:minsitr::ministr ; Fixes 6 words
:*:mirrorr::mirror ; Fixes 6 words
:*:miscellanious::miscellaneous ; Fixes 3 words
:*:miscellanous::miscellaneous ; Fixes 3 words
:*:mischeivous::mischievous ; Fixes 3 words
:*:mischevious::mischievous ; Fixes 3 words
:*:mischievious::mischievous ; Fixes 3 words
:*:misdameanor::misdemeanor ; Fixes 2 words
:*:misdemenor::misdemeanor ; Fixes 2 words
:*:misouri::Missouri ; Fixes 5 words
:*:mispell::misspell ; Fixes 5 words
:*:misteri::mysteri ; Fixes 4 words
:*:monestar::monaster ; Fixes 2 words
:*:monicker::moniker ; Fixes 3 words
:*:monkie::monkey ; Fixes 10 words
:*:montain::mountain ; Fixes 17 words
:*:montyp::monotyp ; Fixes 3 words
:*:movei::movie ; Fixes 6 words
:*:muncipal::municipal ; Fixes 16 words
:*:munnicipal::municipal ; Fixes 16 words
:*:muscician::musician ; Fixes 5 words
:*:myraid::myriad ; Fixes 3 words
:*:mysogyn::misogyn ; Fixes 10 words
:*:mysterous::mysterious ; Fixes 3 words
:*:naieve::naive ; Fixes 9 words
:*:necessiat::necessitat ; Fixes 6 words
:*:neglib::negligib ; Fixes 4 words
:*:negligab::negligib ; Fixes 4 words
:*:negociab::negotiab ; Fixes 4 words
:*:nkwo::know ; Fixes 24 words
:*:norhe::northe ; Fixes 24 words
:*:northen::northern ; Fixes 8 words
:*:northereast::northeast ; Fixes 11 words
:*:noteri::notori ; Fixes 5 words
:*:nothern::northern ; Fixes 8 words
:*:notive::notice ; Fixes 10 words
:*:nowe::now ; Fixes 17 words
:*:nto::not ; Fixes 116 words
:*:numbero::numero ; Fixes 11 words
:*:nutur::nurtur ; Fixes 10 words
:*:nver::never ; Fixes 3 words
:*:nwe::new ; Fixes 123 words
:*:nwo::now ; Fixes 17 words
:*:obess::obsess ; Fixes 14 words
:*:obssess::obsess ; Fixes 14 words
:*:ocasion::occasion ; Fixes 12 words
:*:ocass::occas ; Fixes 12 words
:*:occaison::occasion ; Fixes 12 words
:*:occation::occasion ; Fixes 12 words
:*:octohedr::octahedr ; Fixes 5 words
:*:ocuntr::countr ; Fixes 18 words
:*:ocur::occur ; Fixes 8 words
:*:offce::office ; Fixes 11 words
:*:onot::not ; Fixes 116 words
:*:oponen::opponen ; Fixes 4 words
:*:opose::oppose ; Fixes 6 words
:*:oposi::opposi ; Fixes 17 words
:*:oppositit::opposit ; Fixes 15 words
:*:opre::oppre ; Fixes 11 words
:*:optmiz::optimiz ; Fixes 8 words
:*:optomi::optimi ; Fixes 22 words
:*:orthag::orthog ; Fixes 23 words
:*:oublish::publish ; Fixes 9 words
:*:oustanding::outstanding ; Fixes 3 words
:*:overwelm::overwhelm ; Fixes 6 words
:*:owudl::would ; Fixes 5 words
:*:owuld::would ; Fixes 5 words
:*:oximoron::oxymoron ; Fixes 3 words
:*:palist::Palest ; Fixes 7 words
:*:pamflet::pamphlet ; Fixes 6 words
:*:pamplet::pamphlet ; Fixes 6 words
:*:pantomine::pantomime ; Fixes 5 words
:*:paranthe::parenthe ; Fixes 15 words
:*:parrakeet::parakeet ; Fixes 2 words
:*:pastural::pastoral ; Fixes 11 words
:*:peageant::pageant ; Fixes 4 words
:*:peculure::peculiar ; Fixes 5 words
:*:pedestrain::pedestrian ; Fixes 15 words
:*:pensle::pencil ; Fixes 10 words
:*:peom::poem ; Fixes 2 words
:*:perade::parade ; Fixes 5 words
:*:peretrat::perpetrat ; Fixes 8 words
:*:peripathetic::peripatetic ; Fixes 7 words
:*:peristen::persisten ; Fixes 6 words
:*:perjer::perjur ; Fixes 9 words
:*:perjorative::pejorative ; Fixes 3 words
:*:perpindicular::perpendicular ; Fixes 6 words
:*:persan::person ; Fixes 55 words
:*:perseveren::perseveran ; Fixes 4 words
:*:persue::pursue ; Fixes 5 words
:*:persui::pursui ; Fixes 6 words
:*:philipi::Philippi ; Fixes 7 words
:*:pilgrimm::pilgrim ; Fixes 8 words
:*:plagar::plagiar ; Fixes 23 words
:*:plateu::plateau ; Fixes 5 words
:*:playright::playwright ; Fixes 3 words
:*:playwrite::playwright ; Fixes 3 words
:*:plebicit::plebiscit ; Fixes 3 words
:*:pomot::promot ; Fixes 14 words
:*:posthomous::posthumous ; Fixes 3 words
:*:potra::portra ; Fixes 15 words
:*:practioner::practitioner ; Fixes 2 words
:*:prairy::prairie ; Fixes 2 words
:*:prarie::prairie ; Fixes 2 words
:*:preample::preamble ; Fixes 3 words
:*:precurser::precursor ; Fixes 3 words
:*:preferra::prefera ; Fixes 5 words
:*:premei::premie ; Fixes 10 words
:*:premillenial::premillennial ; Fixes 6 words
:*:preminen::preeminen ; Fixes 4 words
:*:premissio::permissio ; Fixes 3 words
:*:prepart::preparat ; Fixes 5 words
:*:prepera::prepara ; Fixes 5 words
:*:presed::presid ; Fixes 18 words
:*:presitg::prestig ; Fixes 5 words
:*:prevers::pervers ; Fixes 10 words
:*:primativ::primitiv ; Fixes 8 words
:*:primordal::primordial ; Fixes 4 words
:*:principial::principal ; Fixes 8 words
:*:prinici::princi ; Fixes 17 words
:*:privt::privat ; Fixes 35 words
:*:procede::proceed ; Fixes 5 words
:*:proceding::proceeding ; Fixes 2 words
:*:proceedur::procedur ; Fixes 4 words
:*:profesor::professor ; Fixes 10 words
:*:profilic::prolific ; Fixes 5 words
:*:progid::prodig ; Fixes 10 words
:*:promiscous::promiscuous ; Fixes 3 words
:*:pronomial::pronominal ; Fixes 3 words
:*:propoga::propaga ; Fixes 25 words
:*:proseletyz::proselytiz ; Fixes 8 words
:*:protruberanc::protuberanc ; Fixes 4 words
:*:pseudonyn::pseudonym ; Fixes 9 words
:*:puch::push ; Fixes 34 words
:*:pumkin::pumpkin ; Fixes 4 words
:*:puritannic::puritanic ; Fixes 4 words
:*:purpot::purport ; Fixes 5 words
:*:pysci::psychi ; Fixes 12 words
:*:quantat::quantit ; Fixes 14 words
:*:quess::guess ; Fixes 14 words 
:*:quinessen::quintessen ; Fixes 4 words
:*:quize::quizze ; Fixes 4 words
:*:racaus::raucous ; Fixes 3 words
:*:raed::read ; Fixes 63 words
:*:rasberr::raspberr ; Fixes 2 words
:*:reasea::resea ; Fixes 18 words
:*:recie::recei ; Fixes 17 words
:*:reciv::receiv ; Fixes 13 words
:*:recomen::recommen ; Fixes 18 words
:*:recommed::recommend ; Fixes 12 words
:*:reconaissance::reconnaissance ; Fixes 2 words
:*:reconize::recognize ; Fixes 6 words
:*:recuit::recruit ; Fixes 9 words
:*:recurran::recurren ; Fixes 4 words
:*:redicu::ridicu ; Fixes 9 words
:*:refedend::referend ; Fixes 3 words
:*:refridgera::refrigera ; Fixes 11 words
:*:refusla::refusal ; Fixes 2 words
:*:reher::rehear ; Fixes 13 words
:*:reica::reinca ; Fixes 9 words
:*:reknown::renown ; Fixes 5 words
:*:reliz::realiz ; Fixes 12 words
:*:remenant::remnant ; Fixes 2 words
:*:remenic::reminisc ; Fixes 12 words
:*:reminent::remnant ; Fixes 2 words
:*:remines::reminis ; Fixes 12 words
:*:reminsc::reminisc ; Fixes 12 words
:*:reminsic::reminisc ; Fixes 12 words
:*:rendevous::rendezvous ; Fixes 4 words
:*:rendezous::rendezvous ; Fixes 4 words
:*:renewl::renewal ; Fixes 2 words
:*:repid::rapid ; Fixes 8 words
:*:repon::respon ; Fixes 22 words
:*:reprtoire::repertoire ; Fixes 2 words
:*:repubi::republi ; Fixes 15 words
:*:requr::requir ; Fixes 9 words
:*:resaura::restaura ; Fixes 8 words
:*:resembe::resemble ; Fixes 5 words
:*:resevoir::reservoir ; Fixes 2 words
:*:resignement::resignation ; Fixes 2 words
:*:resignment::resignation ; Fixes 2 words
:*:resse::rese ; Fixes 98 words
:*:ressurrect::resurrect ; Fixes 7 words
:*:restara::restaura ; Fixes 8 words
:*:restaurati::restorati ; Fixes 9 words
:*:resteraunt::restaurant ; Fixes 6 words
:*:restraunt::restaurant ; Fixes 6 words
:*:resturant::restaurant ; Fixes 6 words
:*:resturaunt::restaurant ; Fixes 6 words
:*:retalitat::retaliat ; Fixes 10 words
:*:retrun::return ; Fixes 10 words 
:*:reult::result ; Fixes 7 words
:*:reveral::reversal ; Fixes 2 words
:*:rfere::refere ; Fixes 20 words
:*:rockerfeller::Rockefeller ; Fixes 2 words
:*:rococco::rococo ; Fixes 2 words
:*:role call::roll call ; Fixes 4 words
:*:roll play::role play ; Fixes 4 words
:*:roomate::roommate ; Fixes 2 words
:*:rucupera::recupera ; Fixes 11 words
:*:rulle::rule ; Fixes 9 words
:*:rumer::rumor ; Fixes 6 words
:*:russina::Russian ; Fixes 13 words
:*:russion::Russian ; Fixes 13 words
:*:rythem::rhythm ; Fixes 8 words
:*:rythm::rhythm ; Fixes 8 words
:*:sacrelig::sacrileg ; Fixes 5 words
:*:sacrifical::sacrificial ; Fixes 2 words
:*:safegard::safeguard ; added by steve
:*:salery::salary ; Fixes 3 words
:*:sandwhich::sandwich ; Fixes 6 words
:*:sargan::sergean ; Fixes 6 words
:*:sargean::sergean ; Fixes 6 words
:*:saterday::Saturday ; Fixes 2 words
:*:saxaphon::saxophon ; Fixes 5 words
:*:say la v::c'est la vie
:*:scandanavia::Scandinavia ; Fixes 3 words
:*:scaricit::scarcit ; Fixes 2 words
:*:scavang::scaveng ; Fixes 6 words
:*:scrutinit::scrutin ; Fixes 18 words
:*:scuptur::sculptur ; Fixes 11 words
:*:secceed::seced ; Fixes 4 words
:*:secrata::secreta ; Fixes 14 words
:*:seguoy::segue ; Fixes 4 words
:*:seh::she ; Fixes 236 words
:*:seinor::senior ; Fixes 5 words
:*:senari::scenari ; Fixes 4 words
:*:senc::sens ; Fixes 107 words
:*:sentan::senten ; Fixes 9 words
:*:sepina::subpoena ; Fixes 4 words
:*:sergent::sergeant ; Fixes 4 words
:*:set back::setback ; Fixes 2 words
:*:shamen::shaman ; Fixes 15 words
:*:short coming::shortcoming ; Fixes 2 words
:*:shoudl::should ; Fixes 8 words
:*:shreak::shriek ; Fixes 8 words
:*:side affect::side effect ; Fixes 2 words
:*:side kick::sidekick ; Fixes 2 words
:*:sideral::sidereal ; Fixes 2 words
:*:siez::seiz ; Fixes 12 words
:*:simetr::symmetr ; Fixes 18 words 
:*:site line::sight line ; Fixes 2 words
:*:sneek::sneak ; Fixes 13 words
:*:socit::societ ; Fixes 4 words
:*:sofware::software ; Fixes 2 words
:*:soilder::soldier ; Fixes 15 words
:*:solatar::solitar ; Fixes 4 words
:*:soliders::soldiers ; Fixes 3 words
:*:soliliqu::soliloqu ; Fixes 12 words
:*:somtime::sometime ; Fixes 2 words
:*:sophmore::sophomore ; Fixes 2 words
:*:sorceror::sorcerer ; Fixes 2 words
:*:sorround::surround ; Fixes 6 words
:*:sould::should ; Fixes 8 words
:*:sountrack::soundtrack ; Fixes 2 words
:*:sourth::south ; Fixes 59 words
:*:souvenier::souvenir ; Fixes 2 words
:*:soveit::soviet ; Fixes 19 words
:*:sovereignit::sovereignt ; Fixes 4 words
:*:speciman::specimen ; Fixes 2 words
:*:spendour::splendour ; Fixes 2 words
:*:sportscar::sports car ; Fixes 2 words
:*:sppech::speech ; Fixes 18 words
:*:squared inch::square inch ; Fixes 2 words
:*:squared kilometer::square kilometer ; Fixes 2 words
:*:squared meter::square meter ; Fixes 2 words
:*:squared mile::square mile ; Fixes 2 words
:*:stale mat::stalemat ; Fixes 4 words
:*:staring role::starring role ; Fixes 2 words
:*:starring roll::starring role ; Fixes 2 words
:*:stilus::stylus ; Fixes 2 words
:*:stpo::stop ; Fixes 33 words
:*:strenous::strenuous ; Fixes 3 words
:*:strike out::strikeout ; Fixes 2 words
:*:strnad::strand ; Fixes 6 words
:*:stroy::story ; Fixes 12 words
:*:struggel::struggle ; Fixes 5 words
:*:strugl::struggl ; Fixes 7 words
:*:stuggl::struggl ; Fixes 7 words
:*:subjudgation::subjugation ; Fixes 2 words
:*:subsidar::subsidiar ; Fixes 6 words
:*:subsiduar::subsidiar ; Fixes 6 words
:*:subsquen::subsequen ; Fixes 5 words
:*:substace::substance ; Fixes 2 words
:*:substatia::substantia ; Fixes 22 words
:*:substitud::substitut ; Fixes 14 words
:*:substract::subtract ; Fixes 12 words
:*:subtance::substance ; Fixes 2 words
:*:suburburban::suburban ; Fixes 16 words
:*:succedd::succeed ; Fixes 7 words
:*:succede::succeede ; Fixes 3 words
:*:suceed::succeed ; Fixes 7 words
:*:sucide::suicide ; Fixes 3 words
:*:sucidial::suicidal ; Fixes 4 words
:*:sudent::student ; Fixes 7 words
:*:sufferag::suffrag ; Fixes 10 words
:*:sumar::summar ; Fixes 22 words
:*:suop::soup ; Fixes 14 words
:*:superce::superse ; Fixes 17 words
:*:supliment::supplement ; Fixes 10 words
:*:surplant::supplant ; Fixes 6 words
:*:surrepetitious::surreptitious ; Fixes 3 words
:*:surreptious::surreptitious ; Fixes 3 words
:*:surrond::surround ; Fixes 6 words
:*:surroud::surround ; Fixes 6 words
:*:surrunder::surrender ; Fixes 6 words
:*:surveilen::surveillan ; Fixes 3 words
:*:swiming::swimming ; Fixes 3 words
:*:synagouge::synagogue ; Fixes 2 words
:*:synph::symph ; Fixes 30 words
:*:syrap::syrup ; Fixes 4 words
:*:tabacco::tobacco ; Fixes 4 words
:*:tatoo::tattoo ; Fixes 8 words
:*:telelev::telev ; Fixes 14 words
:*:televiz::televis ; Fixes 10 words
:*:televsion::television ; Fixes 2 words
:*:temerature::temperature ; Fixes 2 words
:*:temperment::temperament ; Fixes 5 words
:*:temperture::temperature ; Fixes 2 words
:*:tenacle::tentacle ; Fixes 3 words
:*:termoil::turmoil ; Fixes 2 words
:*:testomon::testimon ; Fixes 4 words
:*:thansk::thanks ; Fixes 6 words
:*:thegovernment::the government ; Fixes 4 words
:*:there final::their final ; Fixes 2 words
:*:thge::the ; Fixes 402 words
:*:thier::their ; Fixes 2 words
:*:thisyear::this year ; Fixes 2 words
:*:thna::than ; Fixes 35 words
:*:thne::then ; Fixes 9 words
:*:threee::three ; Fixes 17 words
:*:threshhold::threshold ; Fixes 4 words
:*:thrid::third ; Fixes 5 words
:*:thror::thor ; Fixes 57 words
:*:thsi::this ; Fixes 7 words
:*:thta::that ; Fixes 14 words
:*:tiem::time ; Fixes 49 words
:*:time out::timeout ; Fixes 2 words
:*:timeschedule::time schedule ; Fixes 2 words
:*:timne::time ; Fixes 49 words
:*:tiome::time ; Fixes 49 words
:*:tobbaco::tobacco ; Fixes 4 words
:*:todya::today ; Fixes 2 words
:*:tolkein::Tolkien ; Fixes 2 words
:*:tommorow::tomorrow ; Fixes 2 words
:*:tommorrow::tomorrow ; Fixes 2 words
:*:tomorow::tomorrow ; Fixes 2 words
:*:tortise::tortoise ; Fixes 4 words
:*:traffice::trafficke ; Fixes 3 words
:*:trafic::traffic ; Fixes 10 words
:*:trancend::transcend ; Fixes 17 words
:*:transcendan::transcenden ; Fixes 13 words
:*:transend::transcend ; Fixes 17 words
:*:transferin::transferrin ; Fixes 3 words
:*:translater::translator ; Fixes 2 words
:*:transpora::transporta ; Fixes 8 words
:*:tremelo::tremolo ; Fixes 2 words
:*:triathalon::triathlon ; Fixes 2 words
:*:triguer::trigger ; Fixes 8 words
:*:triolog::trilog ; Fixes 2 words
:*:tthe::the ; Fixes 402 words
:*:tust::trust ; Fixes 33 words
:*:tution::tuition ; Fixes 3 words
:*:twelth::twelfth ; Fixes 4 words
:*:tyo::to ; Fixes 1110 words
:*:tyrrani::tyranni ; Fixes 20 words
:*:ubiquitious::ubiquitous ; Fixes 3 words
:*:ubli::publi ; Fixes 37 words
:*:uise::use ; Fixes 20 words
:*:ukran::Ukrain ; Fixes 3 words
:*:ulser::ulcer ; Fixes 12 words 
:*:unanym::unanim ; Fixes 8 words
:*:under go::undergo ; Fixes 4 words
:*:under rate::underrate ; Fixes 3 words
:*:under take::undertake ; Fixes 5 words
:*:underat::underrat ; Fixes 4 words 
:*:undreground::underground ; Fixes 3 words
:*:uneccesar::unnecessar ; Fixes 3 words
:*:unecessar::unnecessar ; Fixes 3 words
:*:unequalit::inequalit ; Fixes 2 words
:*:unihabit::uninhabit ; Fixes 6 words
:*:univeral::universal ; Fixes 22 words
:*:univerist::universit ; Fixes 2 words
:*:univerit::universit ; Fixes 2 words
:*:universti::universit ; Fixes 2 words
:*:univesit::universit ; Fixes 2 words
:*:unkow::unknow ; Fixes 14 words
:*:unliek::unlike ; Fixes 11 words
:*:unotice::unnotice ; Fixes 4 words
:*:unplease::displease ; Fixes 5 words
:*:unuseable::unusable ; Fixes 2 words
:*:vaccum::vacuum ; Fixes 4 words
:*:vacinit::vicinit ; Fixes 2 words
:*:vaguar::vagar ; Fixes 4 words
:*:vaiet::variet ; Fixes 5 words
:*:varit::variet ; Fixes 5 words
:*:vasall::vassal ; Fixes 4 words
:*:vehicule::vehicle ; Fixes 2 words
:*:vengance::vengeance ; Fixes 2 words
:*:vengence::vengeance ; Fixes 2 words
:*:verfication::verification ; Fixes 4 words
:*:vermillion::vermilion ; Fixes 4 words
:*:versitilat::versatilit ; Fixes 2 words
:*:versitlit::versatilit ; Fixes 2 words
:*:vetween::between ; Fixes 3 words
:*:vigour::vigor ; Fixes 9 words
:*:villian::villain ; Fixes 11 words
:*:villifi::vilifi ; Fixes 6 words
:*:villify::vilify ; Fixes 2 words
:*:villin::villain ; Fixes 11 words
:*:vincinit::vicinit ; Fixes 2 words
:*:virutal::virtual ; Fixes 16 words
:*:visabl::visibl ; Fixes 3 words
:*:vistor::visitor ; Fixes 2 words
:*:vitor::victor ; Fixes 15 words
:*:vocal chord::vocal cord ; Fixes 2 words
:*:volcanoe::volcano ; Fixes 8 words
:*:voley::volley ; Fixes 8 words
:*:vriet::variet ; Fixes 5 words
:*:vulnerablilit::vulnerabilit ; Fixes 2 words
:*:wardobe::wardrobe ; Fixes 2 words
:*:whn::when ; Fixes 5 words
:*:whould::would ; Fixes 5 words
:*:wich::which ; Fixes 3 words, Case-sensitive to not misspell Wichita.
:*:widesread::widespread ; Fixes 3 words
:*:wih::whi ; Fixes 310 words
:*:withdrawl::withdrawal ; Fixes 2 words
:*:withold::withhold ; Fixes 6 words
:*:worsten::worsen ; Fixes 5 words
:*:woudl::would ; Fixes 5 words
:*:wreckless::reckless ; Fixes 3 words 
:*:yatch::yacht ; Fixes 9 words
:*:yelow::yellow ; Fixes 28 words
:*:yera::year ; Fixes 17 words
:*:yotube::youtube ; Fixes 4 words
:*:yrea::year ; Fixes 17 words
:*?:alell::allel ; Fixes 57 words
:*?:alsitic::alistic ; Fixes 98 words
:*?:onvertab::onvertib ; Fixes 18 words
:*?:sucess::success ; Fixes 19 words
:*?C:balen::balan ; Fixes 45 words.  Case-sensitive to not misspell Balenciaga (Spanish fashion designer). 
:*?C:beng::being ; Fixes 7 words. Case-sensitive to not misspell, Bengali. 
:*?C:hiesm::theism ; Fixes 19 words
:*C:aquit::acquit ; Fixes 10 words.  Case-sensitive to not misspell Aquitaine (A region of southwestern France between Bordeaux and the Pyrenees)
:*C:carmel::caramel ; Fixes 12 words.  Case-sensitive to not misspell Carmelite (Roman Catholic friar)
:*C:carrer::career ; Fixes 8 words.  Case-sensitive to not misspell Carrere (A famous architect) 
:*C:ehr::her ; Fixes 233 words, Made case sensitive so not to misspell Ehrenberg (a Russian novelist) or Ehrlich (a German scientist)
:*C:herat::heart ; Fixes 63 words, Case-sensitive to not misspell Herat (a city in Afganistan).
:*C:hsi::his ; Fixes 95 words, Case-sensitive to not misspell Hsian (a city in China)
:*C:ime::imme ; Fixes 35 words, Case-sensitive to not misspell IMEI (International Mobile Equipment Identity)
:*C:yoru::your ; Fixes 4 words, case sensitive to not misspell Yoruba (A Nigerian langue) 
::EDB::EBD
::Feburary::February 
::Isaax ::Isaac
::Israelies::Israelis 
::Janurary::January 
::Januray::January 
::Montnana::Montana 
::Novermber::November 
::Parri::Patti
::Sacremento::Sacramento
::Straight of::Strait of ; geography
::ToolTop::ToolTip
::a English::an English
::a FM::an FM
::a Internet::an Internet
::a MRI::an MRI
::a businessmen::a businessman
::a businesswomen::a businesswoman
::a consortia::a consortium
::a criteria::a criterion
::a dominate::a dominant
::a falling out::a falling-out
::a firemen::a fireman
::a flagella::a flagellum
::a forward by::a foreword by
::a freshmen::a freshman
::a fungi::a fungus
::a gunmen::a gunman
::a heir::an heir
::a herb::an herb
::a honest::an honest
::a honor::an honor
::a hour::an hour
::a larvae::a larva
::a lock up::a lockup
::a lose::a loss
::a manufacture::a manufacturer
::a nuclei::a nucleus
::a numbers of::a number of
::a ocean::an ocean
::a offensive::an offensive
::a official::an official
::a one of the::one of the
::a only a::only a
::a parentheses::a parenthesis
::a phenomena::a phenomenon
::a protozoa::a protozoon
::a pupae::a pupa
::a radii::a radius
::a renown::a renowned
::a resent::a recent
::a run in::a run-in
::a set back::a set-back
::a set up::a setup
::a several::several
::a simple as::as simple as
::a spermatozoa::a spermatozoon
::a statesmen::a statesman
::a strata::a stratum
::a taxa::a taxon
::a two months::a two-month
::a urban::an urban
::a vertebrae::a vertebra
::a women::a woman
::a work out::a workout
::about it's::about its
::about they're::about their
::about who to::about whom to
::about who's::about whose
::abouta::about a 
::aboutit::about it 
::above it's::above its
::abutts::abuts
::accidently::accidentally
::according a::according to a
::accordingto::according to 
::across it's::across its
::adres::address 
::affect on::effect on
::affect upon::effect upon
::affects of::effects of
::after along time::after a long time
::after awhile::after a while
::after been::after being
::after it's::after its
::after quite awhile::after quite a while
::agains::against
::against it's::against its
::against who::against whom
::againstt he::against the 
::aginst::against
::agre::agree
::agree in principal::agree in principle
::agreement in principal::agreement in principle
::ahjk::ahk
::airbourne::airborne 
::aircrafts'::aircraft's 
::aircrafts::aircraft 
::airplane hanger::airplane hangar
::airporta::airports 
::airrcraft::aircraft 
::albiet::albeit
::all for not::all for naught 
::all it's::all its 
::all though::although 
::all tolled::all told 
::allegedy::allegedly
::allegely::allegedly
::allot of::a lot of 
::allready::already
::alltime::all-time 
::alma matter::alma mater 
::almots::almost
::along it's::along its 
::along side::alongside 
::along time::a long time 
::alongside it's::alongside its 
::alot::a lot 
::also know as::also known as 
::also know by::also known by 
::also know for::also known for 
::alter boy::altar boy 
::alter server::altar server 
::althought::although 
::altoug::althoug
::alway::always 
::am loathe to::am loath to 
::amid it's::amid its 
::amidst it's::amidst its 
::amin::main
::among it's::among it 
::among others things::among other things 
::amongst it's::amongst its 
::amongst one of the::amongst the 
::amongst others things::amongst other things 
::an British::a British 
::an Canadian::a Canadian 
::an European::a European 
::an Hawaiian::a Hawaiian 
::an Malaysian::a Malaysian 
::an Scottish::a Scottish 
::an USB::a USB 
::an Unix::a Unix 
::an affect::an effect 
::an alumnae of::an alumna of 
::an alumni of::an alumnus of 
::an another::another 
::an antennae::an antenna 
::an film::a film 
::an half::a half 
::an halt::a halt 
::an hand::a hand 
::an head::a head 
::an heart::a heart 
::an helicopter::a helicopter 
::an hero::a hero 
::an high::a high 
::an historian::a historian 
::an historic::a historic 
::an historical::a historical 
::an history::a history 
::an hospital::a hospital 
::an hotel::a hotel 
::an humanitarian::a humanitarian 
::an law::a law 
::an lawyer::a lawyer 
::an local::a local 
::an new::a new 
::an nine::a nine 
::an ninth::a ninth 
::an non::a non 
::an number::a number 
::an other::another 
::an pair::a pair 
::an player::a player 
::an popular::a popular 
::an pre-::a pre- 
::an second::a second 
::an series::a series 
::an seven::a seven 
::an seventh::a seventh 
::an six::a six 
::an sixteen::a sixteen 
::an sixth::a sixth 
::an song::a song 
::an special::a special 
::an species::a species 
::an specific::a specific 
::an statement::a statement 
::an ten::a ten 
::an union::a union 
::an unit::a unit 
::anarchistm::anarchism
::and so fourth::and so forth 
::andone::and one 
::androgeny::androgyny
::andt he::and the 
::andteh::and the 
::anothe::another
::another criteria::another criterion 
::another words::in other words 
::anti-semetic::anti-Semitic 
::antiapartheid::anti-apartheid 
::any another::another 
::any resent::any recent 
::any where::anywhere 
::anyother::any other 
::anytying::anything
::apart form::apart from 
::apon::upon
::archimedian::Archimedean
::are aloud to::are allowed to 
::are build::are built 
::are dominate::are dominant 
::are drew::are drawn 
::are it's::are its 
::are know::are known 
::are lain::are laid 
::are lead by::are led by 
::are loathe to::are loath to 
::are meet::are met 
::are ran by::are run by 
::are renown::are renowned 
::are set-up::are set up 
::are setup::are set up 
::are shutdown::are shut down 
::are shutout::are shut out 
::are suppose to::are supposed to 
::are the dominate::are the dominant 
::are use to::are used to 
::aready::already 
::arised::arose 
::arn't::aren't 
::arond::around
::aroud::around 
::around it's::around its 
::arund::around
::as a resulted::as a result 
::as apposed to::as opposed to 
::as back up::as backup 
::as oppose to::as opposed to 
::asfar::as far 
::aside form::aside from 
::aside it's::aside its 
::aslo::also
::assume the reigns::assume the reins 
::assume the roll::assume the role 
::aswell::as well 
::at it's::at its 
::at of::at or 
::at the alter::at the altar 
::at the reigns::at the reins 
::at then end::at the end 
::atheistical::atheistic
::atleast::at least 
::atmospher::atmosphere
::attened::attended
::authorites::authorities 
::avengence::a vengeance
::averag::average
::away form::away from 
::baceause::because 
::back and fourth::back and forth 
::back drop::backdrop 
::back fire::backfire 
::back in forth::back and forth 
::back peddle::backpedal 
::back round::background 
::badly effected::badly affected 
::baited breath::bated breath 
::baled out::bailed out 
::baling out::bailing out 
::bare in mind::bear in mind 
::barily::barely
::basic principal::basic principle 
::be apart of::be a part of 
::be build::be built 
::be cause::because 
::be drew::be drawn 
::be it's::be its 
::be know as::be known as 
::be lain::be laid 
::be lead by::be led by 
::be loathe to::be loath to 
::be ran::be run 
::be rebuild::be rebuilt 
::be rode::be ridden 
::be send::be sent 
::be set-up::be set up 
::be setup::be set up 
::be shutdown::be shut down 
::be use to::be used to 
::be ware::beware 
::beacuse::because
::became it's::became its 
::became know::became known 
::becames::became
::becaus::because
::because of it's::because of its 
::becausea::because a 
::becauseof::because of 
::becausethe::because the 
::becauseyou::because you 
::beccause::because 
::becouse::because 
::becuse::because
::been accustom to::been accustomed to 
::been build::been built 
::been it's::been its 
::been know::been known 
::been lain::been laid 
::been lead by::been led by 
::been loathe to::been loath to 
::been mislead::been misled 
::been ran::been run 
::been rebuild::been rebuilt 
::been rode::been ridden 
::been send::been sent 
::been set-up::been set up 
::been setup::been set up 
::been show on::been shown on 
::been shutdown::been shut down 
::been use to::been used to 
::before hand::beforehand 
::began it's::began its 
::beggin::begin
::beggins::begins 
::behind it's::behind its 
::being build::being built 
::being it's::being its 
::being lain::being laid 
::being lead by::being led by 
::being loathe to::being loath to 
::being ran::being run 
::being rode::being ridden 
::being set-up::being set up 
::being setup::being set up 
::being show on::being shown on 
::being shutdown::being shut down 
::being use to::being used to 
::beligum::belgium 
::belived::believed 
::belives::believes 
::below it's::below its 
::beneath it's::beneath its 
::beside it's::beside its 
::besides it's::besides its 
::better know as::better known as 
::better know for::better known for 
::better then::better than 
::between I and::between me and 
::between he and::between him and 
::between it's::between its 
::between they and::between them and 
::beyond it's::beyond its 
::bicep::biceps 
::both it's::both its 
::both of it's::both of its 
::both of them is::both of them are 
::both of who::both of whom 
::brake away::break away 
::breakthroughts::breakthroughs
::breath fire::breathe fire 
::brethen::brethren 
::bretheren::brethren 
::brew haha::brouhaha 
::brimestone::brimstone 
::britian::Britain 
::brittish::British 
::broacasted::broadcast 
::broady::broadly 
::by it's::by its 
::by who's::by whose 
::byt he::by the 
::cafe::café 
::callipigian::callipygian
::can backup::can back up 
::can been::can be 
::can blackout::can black out 
::can breath::can breathe 
::can checkout::can check out 
::can playback::can play back 
::can setup::can set up 
::can tryout::can try out 
::can workout::can work out 
::can't breath::can't breathe 
::can't of::can't have 
::cant::can't 
::capetown::Cape Town 
::carcas::carcass 
::carnege::Carnegie 
::carnige::Carnegie 
::celcius::Celsius
::cementary::cemetery 
::centruy::century 
::centuties::centuries 
::centuty::century 
::certain extend::certain extent 
::cervial::cervical 
::chalk full::chock-full 
::changed it's::changed its 
::charistics::characteristics 
::childrens::children's 
::chock it up::chalk it up 
::chocked full::chock-full 
::chomping at the bit::champing at the bit 
::choosen::chosen 
::cincinatti::Cincinnati 
::cincinnatti::Cincinnati 
::clera::clear 
::cliant::client 
::closed it's::closed its 
::closer then::closer than 
::co-incided::coincided 
::colum::column 
::commandoes::commandos 
::commonly know as::commonly known as 
::commonly know for::commonly known for 
::confids::confides
::construction sight::construction site 
::controvercy::controversy
::controvery::controversy
::coudn't::couldn't 
::could backup::could back up 
::could breath::could breathe 
::could setup::could set up 
::could workout::could work out 
::couldn't breath::couldn't breathe 
::countires::countries
::criteria is::criteria are 
::criteria was::criteria were 
::criterias::criteria 
::daed::dead
::daily regiment::daily regimen 
::dardenelles::Dardanelles
::darker then::darker than 
::deciding on how::deciding how 
::decomposit::decompose 
::decomposited::decomposed 
::decompositing::decomposing 
::decomposits::decomposes 
::decress::decrees 
::deep-seeded::deep-seated 
::delusionally::delusionary 
::demographical::demographic 
::depending of::depending on 
::depends of::depends on 
::deside::decide 
::despite of::despite 
::devels::delves 
::diamons::diamonds
::didint::didn't 
::didn't fair::didn't fare 
::didnot::did not 
::didnt::didn't 
::dieties::deities
::diety::deity 
::different tact::different tack 
::different to::different from 
::difficulity::difficulty 
::diffuse the::defuse the 
::direct affect::direct effect 
::discontentment::discontent 
::discus a::discuss a  
::discus all::discuss all  
::discus any::discuss any  
::discus the::discuss the  
::discus this::discuss this  
::disparingly::disparagingly
::dispell::dispel
::dispells::dispels 
::do to::due to 
::docrines::doctrines
::doe snot::does not ; *could* be legitimate... but very unlikely!
::doen't::doesn't 
::dolling out::doling out 
::dominate player::dominant player 
::dominate role::dominant role 
::don't no::don't know 
::dont::don't 
::door jam::doorjamb 
::dosen't::doesn't 
::dosn't::doesn't 
::doub::doubt 
::down it's::down its 
::down side::downside 
::drunkeness::drunkenness 
::due to it's::due to its 
::dukeship::dukedom 
::dum::dumb 
::dumbell::dumbbell 
::during it's::during its 
::during they're::during their 
::each phenomena::each phenomenon 
::ealier::earlier 
::earlies::earliest 
::earnt::earned 
::ect::etc 
::eiter::either 
::elast::least 
::eles::eels 
::eluded to::alluded to 
::embargos::embargoes 
::embarras::embarrass
::en mass::en masse 
::enameld::enamelled 
::enought::enough 
::eventhough::even though 
::everthing::everything 
::everytime::every time 
::everyting::everything 
::excell::excel
::excells::excels
::exectued::executed
::exemple::example
::exerciese::exercises
::existince::existence
::expatriot::expatriate
::expeditonary::expeditionary
::expell::expel
::expells::expels
::experienc::experience
::explaning::explaining
::extered::exerted
::extermist::extremist
::extract punishment::exact punishment
::extract revenge::exact revenge
::extradiction::extradition
::extrememly::extremely
::extremeophile::extremophile
::extremly::extremely
::eyasr::years
::eye brow::eyebrow
::eye lash::eyelash
::eye lid::eyelid
::eye sight::eyesight
::eye sore::eyesore
::eyt::yet
::facia::fascia
::facilites::facilities
::faired as well::fared as well
::faired badly::fared badly
::faired better::fared better
::faired far::fared far
::faired less::fared less
::faired little::fared little
::faired much::fared much
::faired no better::fared no better
::faired poorly::fared poorly
::faired quite::fared quite
::faired rather::fared rather
::faired slightly::fared slightly
::faired somewhat::fared somewhat
::faired well::fared well
::faired worse::fared worse
::familes::families
::fanatism::fanaticism
::farenheit::Fahrenheit
::farther then::farther than
::faster then::faster than
::febuary::February
::femail::female
::feromone::pheromone
::fianlly::finally
::ficed::fixed
::fiercly::fiercely
::fightings::fighting
::figure head::figurehead
::filled a lawsuit::filed a lawsuit
::finaly::finally
::firey::fiery
::flag ship::flagship
::flemmish::Flemish
::florescent::fluorescent
::flourescent::fluorescent
::fo::of
::follow suite::follow suit
::following it's::following its
::for all intensive purposes::for all intents and purposes
::for along time::for a long time
::for awhile::for a while
::for he and::for him and
::for quite awhile::for quite a while
::for way it's::for what it's
::fora::for a
::forbad::forbade
::fore ground::foreground
::forego her::forgo her
::forego his::forgo his
::forego their::forgo their
::foreward::foreword
::forgone conclusion::foregone conclusion
::formalhaut::Fomalhaut
::formelly::formerly
::forsaw::foresaw
::forunner::forerunner
::free reign::free rein
::fro::for
::frome::from
::fromt he::from the
::fulfil::fulfill
::fulfiled::fulfilled
::full compliment of::full complement of
::funguses::fungi
::gae::game
::galatic::galactic
::galations::Galatians
::gameboy::Game Boy
::ganes::games
::gauarana::guarana
::gave advise::gave advice
::genialia::genitalia
::gentlemens::gentlemen's
::get setup::get set up
::get use to::get used to
::geting::getting
::gets it's::gets its
::getting use to::getting used to
::ghandi::Gandhi
::give advise::give advice
::gives advise::gives advice
::glamourous::glamorous
::going threw::going through
::got ran::got run
::got setup::got set up
::got shutdown::got shut down
::got shutout::got shut out
::grammer::grammar
::grat::great
::greater then::greater than
::greif::grief
::ground work::groundwork
::guadulupe::Guadalupe
::guatamala::Guatemala
::guatamalan::Guatemalan
::guest stared::guest-starred
::guilia::Giulia
::guiliani::Giuliani
::guilio::Giulio
::guiness::Guinness
::guiseppe::Giuseppe
::gunanine::guanine ; It's in bat poop.  LOL
::gusy::guys
::habaeus::habeas
::habeus::habeas
::habsbourg::Habsburg
::had arose::had arisen
::had awoke::had awoken
::had became::had become
::had began::had begun
::had being::had been
::had broke::had broken
::had brung::had brought
::had came::had come
::had chose::had chosen
::had comeback::had come back
::had cut-off::had cut off
::had did::had done
::had drank::had drunk
::had drew::had drawn
::had drove::had driven
::had fell::had fallen
::had flew::had flown
::had forbad::had forbidden
::had forbade::had forbidden
::had gave::had given
::had grew::had grown
::had it's::had its
::had knew::had known
::had know::had known
::had lead for::had led for
::had lead the::had led the
::had lead to::had led to
::had meet::had met
::had mislead::had misled
::had overcame::had overcome
::had overran::had overrun
::had overtook::had overtaken
::had plead::had pleaded
::had ran::had run
::had rang::had rung
::had rode::had ridden
::had runaway::had run away
::had sang::had sung
::had send::had sent
::had set-up::had set up
::had setup::had set up
::had shook::had shaken
::had shut-down::had shut down
::had shutdown::had shut down
::had shutout::had shut out
::had sowed::had sown
::had spend::had spent
::had spoke::had spoken
::had sprang::had sprung
::had swam::had swum
::had threw::had thrown
::had throve::had thriven
::had thunk::had thought
::had to much::had too much
::had to used::had to use
::had took::had taken
::had tore::had torn
::had undertook::had undertaken
::had underwent::had undergone
::had went::had gone
::had woke::had woken
::had wore::had worn
::had wrote::had written
::hadbeen::had been
::hadn't went::hadn't gone
::haev::have
::half and hour::half an hour
::hallowean::Halloween
::hand the reigns::hand the reins
::happend::happened
::happended::happened
::happenned::happened
::harases::harasses
::has arose::has arisen
::has awoke::has awoken
::has bore::has borne
::has broke::has broken
::has brung::has brought
::has build::has built
::has came::has come
::has chose::has chosen
::has cut-off::has cut off
::has did::has done
::has drank::has drunk
::has drew::has drawn
::has drove::has driven
::has fell::has fallen
::has flew::has flown
::has forbad::has forbidden
::has forbade::has forbidden
::has gave::has given
::has having::as having
::has it's::has its
::has lead the::has led the
::has lead to::has led to
::has meet::has met
::has mislead::has misled
::has overcame::has overcome
::has plead::has pleaded
::has ran::has run
::has rang::has rung
::has sang::has sung
::has set-up::has set up
::has setup::has set up
::has shook::has shaken
::has spoke::has spoken
::has sprang::has sprung
::has swam::has swum
::has threw::has thrown
::has throve::has thrived
::has thunk::has thought
::has took::has taken
::has trod::has trodden
::has undertook::has undertaken
::has underwent::has undergone
::has went::has gone
::has woke::has woken
::has wrote::has written
::hasbeen::has been
::hasnt::hasn't
::have drank::have drunk
::have it's::have its
::have lead to::have led to
::have mislead::have misled
::have ran::have run
::have rang::have rung
::have sang::have sung
::have setup::have set up
::have sprang::have sprung
::have swam::have swum
::have took::have taken
::have underwent::have undergone
::have went::have gone
::havebeen::have been
::haviest::heaviest
::having became::having become
::having began::having begun
::having being::having been
::having it's::having its
::having ran::having run
::having sang::having sung
::having setup::having set up
::having swam::having swum
::having took::having taken
::having underwent::having undergone
::having went::having gone
::hay day::heyday
::he begun::he began
::he let's::he lets
::he plead::he pleaded
::he seen::he saw
::he use to::he used to
::he's drank::he drank
::head gear::headgear
::head quarters::headquarters
::head stone::headstone
::head wear::headwear
::healthercare::healthcare
::heared::heard
::heathy::healthy
::heidelburg::Heidelberg
::heigher::higher
::held the reigns::held the reins
::helf::held
::hellow::hello
::help and make::help to make
::helpfull::helpful
::herf::href 
::heroe::hero
::heros::heroes
::hersuit::hirsute
::hesaid::he said
::heterogenous::heterogeneous
::hewas::he was
::hier::heir
::higer::higher
::higest::highest
::higher then::higher than
::himselv::himself
::hinderance::hindrance
::hinderence::hindrance
::hindrence::hindrance
::hipopotamus::hippopotamus
::his resent::his recent ; not good for 'her' 
::hismelf::himself
::hit the breaks::hit the brakes
::hitsingles::hit singles
::hold onto::hold on to
::hold the reigns::hold the reins
::holding the reigns::holding the reins
::holds the reigns::holds the reins
::homestate::home state
::hone in on::home in on
::honed in::homed in
::honory::honorary
::honourarium::honorarium
::honourific::honorific
::hotter then::hotter than
::house hold::household
::housr::hours
::how ever::however
::howver::however
::http:\\::http:// 
::httpL::http: 
::humer::humor
::huminoid::humanoid
::humoural::humoral
::husban::husband
::hydropile::hydrophile
::hydropilic::hydrophilic
::hydropobe::hydrophobe
::hydropobic::hydrophobic
::hypocracy::hypocrisy
::hypocrasy::hypocrisy
::hypocricy::hypocrisy
::hypocrit::hypocrite
::hypocrits::hypocrites
::i snot::is not
::i"m::I'm
::i;d::I'd
::idealogy::ideology
::identifers::identifiers
::ideosyncratic::idiosyncratic
::idesa::ideas
::idiosyncracy::idiosyncrasy
::if is::it is
::if was::it was
::ifb y::if by
::ifi t::if it
::ift he::if the
::ift hey::if they
::ignorence::ignorance
::ihaca::Ithaca
::iits the::it's the
::illess::illness
::illicited::elicited
::ilness::illness
::imagin::imagine
::imaginery::imaginary
::imminent domain::eminent domain
::impedence::impedance
::in affect::in effect
::in along time::in a long time
::in anyway::in any way
::in awhile::in a while
::in edition to::in addition to
::in lu of::in lieu of
::in masse::en masse
::in parenthesis::in parentheses
::in placed::in place
::in principal::in principle
::in quite awhile::in quite a while
::in regards to::in regard to
::in stead of::instead of
::in tact::intact
::in the long-term::in the long term
::in the short-term::in the short term
::in titled::entitled
::in vein::in vain
::inbetween::between
::incase of::in case of
::incidently::incidentally
::incuding::including
::indentical::identical
::indictement::indictment
::infact::in fact
::infered::inferred
::infinit::infinite
::influented::influenced
::ingreediants::ingredients
::inperson::in-person
::insectiverous::insectivorous
::inspite::in spite
::int he::in the
::inteh::in the
::interbread::interbred
::intered::interred
::interm::interim
::internation::international
::interrim::interim
::interrugum::interregnum
::interum::interim
::intervines::intervenes
::into affect::into effect
::into it's::into its
::introdued::introduced
::inwhich::in which
::irregardless::regardless
::is also know::is also known
::is consider::is considered
::is front of::in front of
::is it's::is its
::is know::is known
::is lead by::is led by
::is loathe to::is loath to
::is ran by::is run by
::is renown for::is renowned for
::is schedule to::is scheduled to
::is set-up::is set up
::is setup::is set up
::is use to::is used to
::is were::is where
::isnt::isn't
::it begun::it began
::it lead to::it led to
::it self::itself
::it set-up::it set up
::it setup::it set up
::it snot::it's not
::it spend::it spent
::it use to::it used to
::it was her who::it was she who
::it was him who::it was he who
::it weighted::it weighed
::it weights::it weighs
::it' snot::it's not
::it's current::its current
::it's end::its end
::it's entire::its entire
::it's entirety::its entirety
::it's final::its final
::it's first::its first
::it's former::its former
::it's goal::its goal
::it's name::its name
::it's own::its own
::it's performance::its performance
::it's source::its source
::it's successor::its successor
::it's tail::its tail
::it's test::its test
::it's theme::its theme
::it's timeslot::its timeslot
::it's toll::its toll
::it's total::its total
::it's user::its user
::it's website::its website
::itis::it is
::its a::it's a
::its the::it's the
::itwas::it was
::iunior::junior
::japanes::Japanese
::jaques::jacques
::jewelery::jewelry 
::jive with::jibe with
::johanine::Johannine
::jorunal::journal
::jospeh::Joseph
::journied::journeyed
::journies::journeys
::juadaism::Judaism
::juadism::Judaism
::key note::keynote
::klenex::kleenex
::knifes::knives
::knive::knife
::labratory::laboratory
::lack there of::lack thereof
::laid ahead::lay ahead
::laid dormant::lay dormant
::laid empty::lay empty
::larg::large
::larger then::larger than
::largley::largely
::largst::largest
::lastr::last
::lastyear::last year
::laughing stock::laughingstock
::lavae::larvae
::law suite::lawsuit
::lay low::lie low
::layed off::laid off
::layed::laid
::laying around::lying around
::laying awake::lying awake
::laying low::lying low
::lays atop::lies atop
::lays beside::lies beside
::lays in::lies in
::lays low::lies low
::lays near::lies near
::lays on::lies on
::lead by::led by
::lead roll::lead role
::leading roll::leading role
::lefted::left
::less dominate::less dominant
::less that::less than
::less then::less than
::lesser then::less than
::libary::library
::libitarianisn::libertarianism
::licence::license
::life time::lifetime
::liftime::lifetime
::lighter then::lighter than
::lightyear::light year
::lightyears::light years
::line of site::line of sight
::line-of-site::line-of-sight
::linnaena::linnaean
::lions share::lion's share
::litature::literature
::lonelyness::loneliness
::loose to::lose to
::loosing effort::losing effort
::loosing record::losing record
::loosing season::losing season
::loosing streak::losing streak
::loosing team::losing team
::loosing the::losing the
::loosing to::losing to
::lot's of::lots of
::lower that::lower than
::lower then::lower than
::maching::matching
::mackeral::mackerel
::made it's::made its
::magasine::magazine
::magizine::magazine
::maintance::maintenance
::major roll::major role
::make due::make do
::make it's::make its
::malcom::Malcolm
::maltesian::Maltese
::managerial reigns::managerial reins
::massachussets::Massachusetts
::massachussetts::Massachusetts
::massmedia::mass media
::materalists::materialist
::mathematican::mathematician
::matheticians::mathematicians
::mean while::meanwhile
::mear::mere
::medievel::medieval
::mediteranean::Mediterranean
::meerkrat::meerkat
::melieux::milieux
::membranaphone::membranophone
::menally::mentally
::menat::meant
::messanger::messenger
::messenging::messaging
::michagan::Michigan
::micheal::Michael
::might of::might have
::miligram::milligram
::millepede::millipede
::miniscule::minuscule
::ministery::ministry
::minor roll::minor role
::minstries::ministries
::minstry::ministry
::minumum::minimum
::misfourtunes::misfortunes
::missen::mizzen
::missle::missile
::mistery::mystery
::moderm::modem
::mohammedans::muslims
::moil::mohel
::momento::memento
::monolite::monolithic
::more dominate::more dominant
::more of less::more or less
::more often then::more often than
::more resent::more recent
::more that::more than
::more then::more than
::moreso::more so
::most dominate::most dominant
::most populace::most populous
::most resent::most recent
::muhammadan::muslim
::multipled::multiplied
::multiplers::multipliers
::must of::must have
::mute point::moot point
::mysef::myself
::mysefl::myself
::myu::my
::nad::and
::napoleonian::Napoleonic
::nation wide::nationwide
::nazereth::Nazareth
::near by::nearby
::neither criteria::neither criterion
::neither phenomena::neither phenomenon
::nestin::nesting
::neverthless::nevertheless
::new comer::newcomer
::newletters::newsletters
::newyorker::New Yorker
::niether::neither
::nightime::nighttime
::nineth::ninth
::ninteenth::nineteenth
::ninties::nineties ; fixed from "1990s": could refer to temperatures too.
::ninty::ninety
::no where to::nowhere to
::nontheless::nonetheless
::noone::no one
::note worthy::noteworthy
::noth::north
::noticable::noticeable
::noticably::noticeably
::notwhithstanding::notwithstanding
::noveau::nouveau
::nowdays::nowadays
::nuisanse::nuisance
::nusance::nuisance
::obstacal::obstacle
::of it's kind::of its kind
::of it's own::of its own
::ofits::of its
::oft he::of the ; Could be legitimate in poetry, but usually a typo.
::oftenly::often
::oging::going
::oil barron::oil baron
::ole::olÃ©
::omited::omitted
::omiting::omitting
::omlette::omelette
::ommited::omitted
::ommiting::omitting
::ommitted::omitted
::ommitting::omitting
::on accident::by accident
::on going::ongoing
::on it's own::on its own
::on-going::ongoing
::one criteria::one criterion
::one phenomena::one phenomenon
::oneof::one of
::onepoint::one point
::ongoing bases::ongoing basis
::onnair::onnaire
::onomatopeia::onomatopoeia
::ont he::on the
::onyl::only
::openess::openness
::opposit::opposite
::orded::ordered
::other then::other than
::our of::out of
::our resent::our recent
::out grow::outgrow
::out of sink::out of sync
::out of state::out-of-state
::out side::outside
::outof::out of
::over hear::overhear
::over heard::overheard
::over look::overlook
::over looked::overlooked
::over looking::overlooking
::over rated::overrated
::over saw::oversaw
::over see::oversee
::overthere::over there
::paleolitic::paleolithic
::paraphenalia::paraphernalia
::particulary::particularly
::partof::part of
::pasengers::passengers
::passerbys::passersby
::past away::passed away
::past down::passed down
::pasttime::pastime
::pavillion::pavilion
::payed::paid
::peacefuland::peaceful and
::peak her interest::pique her interest
::peak his interest::pique his interest
::peaked my interest::piqued my interest
::penatly::penalty
::peotry::poetry
::per say::per se
::percentof::percent of
::percentto::percent to
::perhasp::perhaps
::perheaps::perhaps
::perhpas::perhaps
::perogative::prerogative
::perphas::perhaps
::personel::personnel
::personell::personnel
::personnell::personnel
::pharoah::Pharaoh
::phenomenonly::phenomenally
::pheonix::phoenix ; Not forcing caps, as it could be the bird
::pinapple::pineapple
::pinnaple::pineapple
::planation::plantation
::plantiff::plaintiff
::poety::poetry
::poisin::poison
::pomegranite::pomegranate
::portayed::portrayed
::portugese::Portuguese
::portuguease::portuguese
::portugues::Portuguese
::potatoe::potato
::potatos::potatoes
::powerfull::powerful
::pre-Colombian::pre-Columbian
::precedessor::predecessor
::precentage::percentage
::prepat::preparat
::primarly::primarily
::principaly::principality
::principlaity::principality
::principle advantage::principal advantage
::principle cause::principal cause
::principle character::principal character
::principle component::principal component
::principle goal::principal goal
::principle group::principal group
::principle method::principal method
::principle owner::principal owner
::principle source::principal source
::principle student::principal student
::principly::principally
::probelms::problems
::procedger::procedure
::prologomena::prolegomena
::prophacy::prophecy
::protem::pro tem
::protocal::protocol
::proximty::proximity
::publically::publicly
::publicaly::publicly
::purposedly::purposely
::puting::putting
::quitted::quit
::rather then::rather than
::rebounce::rebound
::recal::recall
::receivedfrom::received from
::reek havoc::wreak havoc
::refering::referring
::regular bases::regular basis
::reign in::rein in
::reigns of power::reins of power
::rela::real
::relected::reelected
::remaing::remaining
::rememberable::memorable
::republi::republic
::resently::recently 
::retun::return
::revaluated::reevaluated
::rised::rose
::runner up::runner-up
::saddle up to::sidle up to
::saidhe::said he
::saidt he::said the
::sandess::sadness
::scientis::scientist
::seceed::secede
::seceeded::seceded
::severley::severely
::severly::severely
::she begun::she began
::she let's::she lets
::she seen::she saw
::sherif::sheriff
::shiped::shipped
::shorter then::shorter than
::shortly there after::shortly thereafter
::shortwhile::short while 
::should backup::should back up
::should not of::should not have
::should of::should have 
::should've went::should have gone
::show resent::show recent 
::shrinked::shrunk 
::silicone chip::silicon chip 
::simplier::simpler
::single handily::single-handedly
::singsog::singsong 
::slight of hand::sleight of hand
::slue of::slew of
::smaller then::smaller than
::smarter then::smarter than
::sneak peak::sneak peek
::soley::solely
::some how::somehow
::some one::someone
::some what::somewhat
::some where::somewhere
::somene::someone 
::someting::something 
::somthing::something 
::somwhere::somewhere 
::soon there after::soon thereafter
::sooner then::sooner than
::sot hat::so that 
::sotyr::story
::spainish::Spanish
::speach::speech
::spects::aspects 
::spilt among::split among
::spilt between::split between
::spilt into::split into
::spilt up::split up
::spinal chord::spinal cord
::split in to::split into
::spreaded::spread
::sprech::speech
::sq ft::ft²
::sq in::in²
::sq km::km²
::sq mi::mi²
::squared feet::square feet
::standars::standards
::stay a while::stay awhile
::stomache::stomach
::storise::stories
::stornegst::strongest
::strictist::strictest
::strikely::strikingly
::stronger then::stronger than
::stubborness::stubbornness
::student's that::students that
::subpecies::subspecies
::succeds::succeeds
::suppose to::supposed to
::supposingly::supposedly 
::surrended::surrendered
::surviver::survivor
::survivied::survived
::t he::the
::take affect::take effect
::take over the reigns::take over the reins
::take the reigns::take the reins
::taken the reigns::taken the reins
::taking the reigns::taking the reins
::tast::taste
::tath::that
::teached::taught 
::tellt he::tell the 
::thanks@!::thanks!
::thanks@::thanks!
::thast::that's 
::that him and::that he and
::thats::that's 
::thatt he::that the 
::the absent of::the absence of
::the advise of::the advice of
::the affect of::the effect of
::the affect on::the effect on
::the affects of::the effects of
::the both the::both the
::the break down::the breakdown
::the break up::the breakup
::the build up::the buildup
::the clamp down::the clampdown
::the crack down::the crackdown
::the dominate::the dominant
::the extend of::the extent of
::the follow up::the follow-up
::the injures::the injuries
::the lead up::the lead-up
::the phenomena is::the phenomenon is
::the rational behind::the rationale behind
::the rational for::the rationale for
::the resent::the recent
::the set up::the setup
::thecompany::the company 
::thefirst::the first 
::theif::thief
::their are::there are 
::their had::there had
::their has::there has
::their have::there have
::their is::there is 
::their may be::there may be
::their was::there was
::their were::there were
::their would::there would
::theives::thieves 
::them selves::themselves
::themselfs::themselves 
::themslves::themselves 
::thenew::the new 
::ther::there
::therafter::thereafter 
::therby::thereby 
::there after::thereafter
::there best::their best
::there by::thereby
::there first::their first
::there last::their last
::there new::their new
::there next::their next
::there of::thereof
::there own::their own
::there where::there were
::there's is::theirs is 
::there's three::there are three
::there's two::there are two
::theri::their 
::thesame::the same 
::these includes::these include
::these type of::these types of
::these where::these were
::thetwo::the two 
::they begun::they began
::they maybe::they may be
::they we're::they were
::they weight::they weigh
::they where::they were
::they're are::there are 
::they're is::there is 
::they;l::they'll 
::they;r::they're 
::they;v::they've 
::theyll::they'll 
::theyre::they're 
::theyve::they've 
::this data::these data
::this gut::this guy 
::this lead to::this led to
::this maybe::this may be
::this resent::this recent
::thn::then ; Fixes 9 words
::those includes::those include
::those maybe::those may be
::thoughout::throughout 
::threatend::threatened
::through it's::through its
::through the ringer::through the wringer
::throughly::thoroughly
::throughout it's::throughout its
::througout::throughout
::throws of passion::throes of passion
::thru::through
::to back fire::to backfire
::to back-off::to back off
::to back-out::to back out
::to back-up::to back up
::to backoff::to back off
::to backout::to back out
::to backup::to back up
::to bailout::to bail out
::to bath::to bathe
::to be build::to be built
::to be setup::to be set up
::to blackout::to black out
::to blastoff::to blast off
::to blowout::to blow out
::to blowup::to blow up
::to breakdown::to break down
::to breath::to breathe
::to buildup::to build up
::to built::to build
::to buyout::to buy out
::to chose::to choose
::to comeback::to come back
::to crackdown on::to crack down on
::to cut of::to cut off
::to cutback::to cut back
::to cutoff::to cut off
::to dropout::to drop out
::to emphasis the::to emphasise the
::to fill-in::to fill in
::to forego::to forgo
::to happened::to happen
::to have lead to::to have led to
::to he and::to him and
::to holdout::to hold out
::to kickoff::to kick off
::to loath::to loathe
::to lockout::to lock out
::to lockup::to lock up
::to login::to log in
::to logout::to log out
::to lookup::to look up
::to markup::to mark up
::to opt-in::to opt in
::to opt-out::to opt out
::to phaseout::to phase out
::to pickup::to pick up
::to playback::to play back
::to rebuilt::to be rebuilt
::to rollback::to roll back
::to runaway::to run away
::to seen::to be seen
::to sent::to send
::to setup::to set up
::to shut-down::to shut down
::to shutdown::to shut down
::to some extend::to some extent
::to spent::to spend
::to spin-off::to spin off
::to spinoff::to spin off
::to takeover::to take over
::to that affect::to that effect
::to they're::to their
::to touchdown::to touch down
::to try and::to try to
::to try-out::to try out
::to tryout::to try out
::to turn-off::to turn off
::to turnaround::to turn around
::to turnoff::to turn off
::to turnout::to turn out
::to turnover::to turn over
::to wakeup::to wake up
::to walkout::to walk out
::to wipeout::to wipe out
::to withdrew::to withdraw
::to workaround::to work around
::to workout::to work out
::today of::today or
::todays::today's 
::toldt he::told the 
::tomatos::tomatoes
::too also::also
::too be::to be
::took affect::took effect
::took and interest::took an interest
::took awhile::took a while
::took over the reigns::took over the reins
::took the reigns::took the reins
::toolket::toolkit
::tornadoe::tornado
::torpeados::torpedoes
::torpedos::torpedoes 
::tot he::to the 
::tothe::to the 
::trafficing::trafficking
::transcripting::transcribing
::transfered::transferred
::tried to used::tried to use
::troup::troupe
::try and::try to
::turn for the worst::turn for the worse
::tuscon::Tucson 
::twelve month's::twelve months
::twice as much than::twice as much as
::two in a half::two and a half
::tyhe::they
::tyrany::tyranny
::tyrrany::tyranny
::uber::über
::unbeknowst::unbeknownst
::unconfortability::discomfort 
::under it's::under its
::under wear::underwear
::under went::underwent
::undert he::under the 
::undoubtely::undoubtedly
::unitedstates::United States 
::unitesstates::United States 
::unoperational::nonoperational
::unsed::unused
::untill::until
::up field::upfield
::up it's::up its
::up side::upside
::upon it's::upon its
::upto::up to 
::usally::usually
::use to be::used to be
::use to have::used to have
::use to::used to
::via it's::via its
::viathe::via the
::vise versa::vice versa
::volkswagon::Volkswagen 
::vreity::variety
::wa snot::was not 
::waived off::waved off
::wan tit::want it 
::wanna::want to 
::warantee::warranty 
::warn away::worn away
::warn down::worn down
::warn out::worn out
::was apart of::was a part of
::was began::began
::was build::was built
::was cable of::was capable of
::was cutoff::was cut off
::was do to::was due to
::was drank::was drunk
::was establish::was established
::was extend::was extended
::was it's::was its
::was knew::was known
::was know::was known
::was lain::was laid
::was laying on::was lying on
::was lead by::was led by
::was lead to::was led to
::was leaded by::was led by
::was loathe to::was loath to
::was loathed to::was loath to
::was meet by::was met by
::was meet with::was met with
::was mislead::was misled
::was ran::was run
::was rebuild::was rebuilt
::was release by::was released by
::was release on::was released on
::was reran::was rerun
::was rode::was ridden
::was sang::was sung
::was schedule to::was scheduled to
::was send::was sent
::was sentence to::was sentenced to
::was set-up::was set up
::was setup::was set up
::was shook::was shaken
::was shoot::was shot
::was show by::was shown by
::was show on::was shown on
::was showed::was shown
::was shut-off::was shut off
::was shutdown::was shut down
::was shutoff::was shut off
::was shutout::was shut out
::was sold-out::was sold out
::was spend::was spent
::was succeed by::was succeeded by
::was suppose to::was supposed to
::was the dominate::was the dominant
::was though that::was thought that
::was tore::was torn
::was use to::was used to
::was wrote::was written
::wasnt::wasn't 
::wat::way
::way side::wayside
::wayword::wayward 
::we;d::we'd 
::weaponary::weaponry 
::weather or not::whether or not
::well know::well known
::wendsay::Wednesday 
::wensday::Wednesday 
::went rouge::went rogue
::went threw::went through
::were apart of::were a part of
::were began::were begun
::were build::were built
::were cutoff::were cut off
::were drew::were drawn
::were he was::where he was
::were it was::where it was
::were it's::were its
::were knew::were known
::were know::were known
::were lain::were laid
::were lead by::were led by
::were loathe to::were loath to
::were meet by::were met by
::were meet with::were met with
::were overran::were overrun
::were ran::were run
::were rebuild::were rebuilt
::were reran::were rerun
::were rode::were ridden
::were sang::were sung
::were set-up::were set up
::were setup::were set up
::were she was::where she was
::were showed::were shown
::were shut-out::were shut out
::were shutdown::were shut down
::were shutoff::were shut off
::were shutout::were shut out
::were spend::were spent
::were suppose to::were supposed to
::were the dominate::were the dominant
::were took::were taken
::were tore::were torn
::were use to::were used to
::were wrote::were written
::wereabouts::whereabouts 
::wern't::weren't 
::wet your::whet your
::wether or not::whether or not
::what lead to::what led to
::what lied::what lay
::when ever::whenever
::whent he::when the 
::wheras::whereas 
::where abouts::whereabouts
::where as::whereas
::where being::were being
::where by::whereby
::where him::where he
::where made::were made
::where taken::were taken
::where upon::whereupon
::where won::were won
::whereas as::whereas
::wherease::whereas 
::whereever::wherever
::whic::which
::which had lead::which had led
::which has lead::which has led
::which have lead::which have led
::which where::which were
::whicht he::which the 
::while him::while he
::who had lead::who had led
::who has lead::who has led
::who have lead::who have led
::who setup::who set up
::who use to::who used to
::who where::who were
::who's actual::whose actual
::who's brother::whose brother
::who's father::whose father
::who's mother::whose mother
::who's name::whose name
::who's opinion::whose opinion
::who's own::whose own
::who's parents::whose parents
::who's previous::whose previous
::who's team::whose team
::wholey::wholly
::wholy::wholly
::whther::whether
::will backup::will back up
::will buyout::will buy out
::will of::will have 
::will shutdown::will shut down
::will shutoff::will shut off
::willbe::will be 
::with be::will be
::with in::within
::with it's::with its
::with on of::with one of
::with out::without
::with regards to::with regard to
::with who::with whom
::witha::with a 
::witheld::withheld
::withi t::with it
::within it's::within its
::within site of::within sight of
::withing::within 
::witht he::with the 
::wo'nt::won't 
::won it's::won its
::wonderfull::wonderful
::wordlwide::worldwide 
::working progress::work in progress
::world wide::worldwide
::worse comes to worse::worse comes to worst
::worse then::worse than
::worse-case scenario::worst-case scenario
::worst comes to worst::worse comes to worst
::worst than::worse than
::worth it's::worth its
::worth while::worthwhile
::would backup::would back up
::would comeback::would come back
::would fair::would fare
::would forego::would forgo
::would of::would have 
::would setup::would set up
::wouldbe::would be 
::wouldnt::wouldn't 
::wreck havoc::wreak havoc
::writers block::writer's block
::you're own::your own 
::you;d::you'd 
::youare::you are 
::younger then::younger than
::your a::you're a 
::your an::you're an 
::your her::you're her 
::your here::you're here 
::your his::you're his 
::your my::you're my 
::your the::you're the 
::your their::you're their 
::your your::you're your 
::youseff::yousef 
::youself::yourself 
::youve::you've 
::youv’e::you've 
:?*:0n0::-n- ; For this-n-that
:?*:abaptiv::adaptiv ; Fixes 8 words
:?*:abberr::aberr ; Fixes 21 words
:?*:abbout::about ; Fixes 37 words
:?*:abck::back ; Fixes 410 words
:?*:abilt::abilit ; Fixes 1110 words
:?*:ablit::abilit ; Fixes 1110 words
:?*:abotu::about ; Fixes 37 words
:?*:abrit::arbit ; Fixes 53 words
:?*:abuda::abunda ; Fixes 15 words
:?*:acadm::academ ; Fixes 32 words
:?*:accadem::academ ; Fixes 32 words
:?*:acccus::accus ; Fixes 37 words
:?*:acceller::acceler ; Fixes 23 words
:?*:accensi::ascensi ; Fixes 7 words
:?*:acceptib::acceptab ; Fixes 10 words
:?*:accessab::accessib ; Fixes 14 words
:?*:accomadat::accommodat ; Fixes 23 words
:?*:accomo::accommo ; Fixes 23 words
:?*:accoring::according ; Fixes 3 words
:?*:accous::acous ; Fixes 10 words
:?*:accqu::acqu ; Fixes 89 words
:?*:accro::acro ; Fixes 145 words, but misspells accroides (An alcohol-soluble resin from Australian trees; used in varnishes and in manufacturing paper) 
:?*:accuss::accus ; Fixes 37 words
:?*:acede::acade ; Fixes 36 words
:?*:acheiv::achiev ; Fixes 33 words
:?*:achievment::achievement ; Fixes 8 words
:?*:acocu::accou ; Fixes 40 words
:?*:acom::accom ; Fixes 49 words
:?*:acquaintence::acquaintance ; Fixes 6 words
:?*:acquiantence::acquaintance ; Fixes 6 words
:?*:actial::actical ; Fixes 29 words
:?*:acurac::accurac ; Fixes 4 words
:?*:acustom::accustom ; Fixes 17 words
:?*:acys::acies ; Fixes 101 words
:?*:adantag::advantag ; Fixes 15 words
:?*:adaption::adaptation ; Fixes 8 words
:?*:adavan::advan ; Fixes 30 words
:?*:addion::addition ; Fixes 7 words
:?*:additon::addition ; Fixes 7 words
:?*:addm::adm ; Fixes 144 words
:?*:addop::adop ; Fixes 35 words
:?*:addow::adow ; Fixes 43 words
:?*:adequite::adequate ; Fixes 6 words
:?*:adif::atif ; Fixes 50 words, but misspells Gadiformes (Cods, haddocks, grenadiers; in some classifications considered equivalent to the order Anacanthini)
:?*:adiquate::adequate ; Fixes 6 words
:?*:admend::amend ; Fixes 15 words
:?*:admissab::admissib ; Fixes 9 words
:?*:admited::admitted ; Fixes 3 words
:?*:admition::admission ; Fixes 4 words
:?*:adquate::adequate ; Fixes 6 words
:?*:adquir::acquir ; Fixes 16 words
:?*:advanag::advantag ; Fixes 15 words
:?*:adventr::adventur ; Fixes 29 words
:?*:advertant::advertent ; Fixes 4 words
:?*:adviced::advised ; Fixes 8 words
:?*:aelog::aeolog ; Fixes 12 words
:?*:aeriel::aerial ; Fixes 9 words
:?*:affilat::affiliat ; Fixes 16 words
:?*:affilliat::affiliat ; Fixes 16 words
:?*:affort::afford ; Fixes 13 words
:?*:affraid::afraid ; Fixes 4 words
:?*:aggree::agree ; Fixes 28 words
:?*:agrava::aggrava ; Fixes 9 words
:?*:agreemnt::agreement ; Fixes 4 words
:?*:agreg::aggreg ; Fixes 19 words
:?*:agress::aggress ; Fixes 25 words
:?*:ahev::have ; Fixes 47 words
:?*:ahpp::happ ; Fixes 34 words
:?*:ahve::have ; Fixes 47 words, but misspells Ahvenanmaa, Jahvey, Wahvey, Yahve, Yahveh (All are different Hebrew names for God.) 
:?*:aible::able ; Fixes 2387 words
:?*:aicraft::aircraft ; Fixes 7 words
:?*:ailabe::ailable ; Fixes 12 words
:?*:ailiab::ailab ; Fixes 23 words
:?*:ailib::ailab ; Fixes 23 words
:?*:aisian::Asian ; Fixes 16 words
:?*:aiton::ation ; Fixes 5205 words
:?*:alchohol::alcohol ; Fixes 28 words
:?*:alchol::alcohol ;fixes 28 words
:?*:alcohal::alcohol ; Fixes 28 words
:?*:aliab::ailab ; Fixes 23 words
:?*:alibit::abilit ; Fixes 1110 words
:?*:alitv::lativ ; Fixes 97 words
:?*:allign::align ; Fixes 41 words
:?*:allth::alth ; Fixes 56 words
:?*:allto::alto ; Fixes 32 words
:?*:alochol::alcohol ; Fixes 28 words
:?*:alott::allott ; Fixes 8 words
:?*:alowe::allowe ; Fixes 24 words
:?*:altion::lation ; Fixes 448 words
:?*:ameria::America ; Fixes 28 words
:?*:amerli::ameli ; Fixes 41 words
:?*:ametal::amental ; Fixes 31 words
:?*:amke::make ; Fixes 122 words
:?*:amking::making ; Fixes 45 words
:?*:ammou::amou ; Fixes 99 words
:?*:amny::many ; Fixes 8 words
:?*:analitic::analytic ; Fixes 15 words
:?*:anbd::and ; Fixes 2083 words
:?*:angabl::angeabl ; Fixes 16 words
:?*:angeing::anging ; Fixes 38 words
:?*:anmd::and ; Fixes 2083 words
:?*:annn::ann ; Fixes 650 words
:?*:annoi::anoi ; Fixes 40 words
:?*:annuled::annulled ; Fixes 2 words
:?*:anomo::anoma ; Fixes 19 words
:?*:anounc::announc ; Fixes 9 words
:?*:antaine::antine ; Fixes 31 words
:?*:anwser::answer ; Fixes 20 words
:?*:aost::oast ; Fixes 75 words
:?*:aparen::apparen ; Fixes 8 words
:?*:apear::appear ; Fixes 22 words
:?*:aplic::applic ; Fixes 23 words
:?*:aplie::applie ; Fixes 11 words
:?*:apoint::appoint ; Fixes 30 words ; Misspells username Datapoint.
:?*:apparan::apparen ; Fixes 8 words
:?*:appart::apart ; Fixes 12 words
:?*:appeares::appears ; Fixes 3 words
:?*:apperance::appearance ; Fixes 8 words
:?*:appol::apol ; Fixes 64 words
:?*:apprearance::appearance ; Fixes 8 words
:?*:apreh::appreh ; Fixes 26 words
:?*:apropri::appropri ; Fixes 34 words
:?*:aprov::approv ; Fixes 23 words
:?*:aptue::apture ; Fixes 15 words
:?*:aquain::acquain ; Fixes 22 words
:?*:aquiant::acquaint ; Fixes 22 words
:?*:aquisi::acquisi ; Fixes 10 words
:?*:arange::arrange ; Fixes 27 words
:?*:arbitar::arbitrar ; Fixes 7 words
:?*:archaelog::archaeolog ; Fixes 8 words
:?*:archao::archeo ; Fixes 12 words
:?*:archetect::architect ; Fixes 20 words
:?*:architectual::architectural ; Fixes 4 words
:?*:areat::arat ; Fixes 136 words
:?*:arguement::argument ; Fixes 13 words
:?*:arhip::arship ; Fixes 10 words
:?*:ariage::arriage ; Fixes 24 words
:?*:arign::aring ; Fixes 140 words
:?*:ariman::airman ; Fixes 10 words
:?*:arogen::arrogan ; Fixes 6 words
:?*:arrri::arri ; Fixes 159 words
:?*:artdridge::artridge ; Fixes 6 words
:?*:articel::article ; Fixes 11 words
:?*:artrige::artridge ; Fixes 6 words
:?*:asdver::adver ; Fixes 67 words
:?*:asign::assign ; Fixes 27
:?*:asnd::and ; Fixes 2083 words
:?*:asociat::associat ; Fixes 34 words
:?*:asorb::absorb ; Fixes 31 words
:?*:asr::ase ; Fixes 698 words, but misspells Basra (An oil city in Iraq) 
:?*:assempl::assembl ; Fixes 33 words
:?*:assertation::assertion ; Fixes 4 words
:?*:assoca::associa ; Fixes 38 words
:?*:assoicat::associat ; Fixes 34 words
:?*:asss::as ; Fixes 9311 words
:?*:assym::asym ; Fixes 17 words
:?*:asthet::aesthet ; Fixes 48 words
:?*:asuing::ausing ; Fixes 2 words
:?*:atain::attain ; Fixes 28 words
:?*:ateing::ating ; Fixes 1117 words
:?*:atempt::attempt ; Fixes 11 words
:?*:atention::attention ; Fixes 5 words
:?*:athori::authori ; Fixes 45 words
:?*:aticula::articula ; Fixes 69 words
:?*:atoin::ation ; Fixes 5229 words
:?*:atribut::attribut ; Fixes 31 words
:?*:attemt::attempt ; Fixes 11 words
:?*:attenden::attendan ; Fixes 7 words
:?*:attensi::attenti ; Fixes 16 words
:?*:attentioin::attention ; Fixes 5 words
:?*:auclar::acular ; Fixes 32 words
:?*:audiance::audience ; Fixes 4 words
:?*:auther::author ; Fixes 56 words
:?*:authobiograph::autobiograph ; Fixes 8 words
:?*:authror::author ; Fixes 56 words
:?*:automonom::autonom ; Fixes 13 words
:?*:avaialb::availab ; Fixes 13 words
:?*:availb::availab ; Fixes 13 words
:?*:availib::availab ; Fixes 13 words
:?*:avalab::availab ; Fixes 13 words
:?*:avalib::availab ; Fixes 13 words
:?*:aveing::aving ; Fixes 60 words
:?*:avila::availa ; Fixes 13 words
:?*:awess::awless ; Fixes 12 words
:?*:awya::away ; Fixes 46 words
:?*:babilat::babilit ; Fixes 19 words
:?*:bakc::back ; Fixes 410 words
:?*:ballan::balan ; Fixes 45 words
:?*:baout::about ; Fixes 37 words
:?*:bateabl::batabl ; Fixes 5 words
:?*:bcak::back ; Fixes 410 words
:?*:beahv::behav ; Fixes 33 words
:?*:beatiful::beautiful ; Fixes 5 words
:?*:beaurocra::bureaucra ; Fixes 22 words
:?*:becoe::become ; Fixes 4 words
:?*:becomm::becom ; Fixes 11 words
:?*:bedore::before ; Fixes 4 words
:?*:beei::bei ; Fixes 40 words
:?*:behaio::behavio ; Fixes 25 words
:?*:belan::blan ; Fixes 60 words
:?*:belei::belie ; Fixes 49 words
:?*:belligeran::belligeren ; Fixes 9 words
:?*:benif::benef ; Fixes 41 words
:?*:bilsh::blish ; Fixes 56 words
:?*:biul::buil ; Fixes 46 words
:?*:blence::blance ; Fixes 7 words
:?*:bliah::blish ; Fixes 56 words
:?*:blich::blish ; Fixes 56 words
:?*:blihs::blish ; Fixes 56 words
:?*:blisg::blish ; Fixes 56 words
:?*:bllish::blish ; Fixes 56 words
:?*:boaut::about ; Fixes 37 words
:?*:bombardement::bombardment ; Fixes 4 words
:?*:bombarment::bombardment ; Fixes 4 words
:?*:bondary::boundary ; Fixes 2 words
:?*:borrom::bottom ; Fixes 14 words
:?*:boundr::boundar ; Fixes 3 words
:?*:boxs::boxes ; Fixes 44 words
:?*:bradcast::broadcast ; Fixes 13 words
:?*:breif::brief ; Fixes 22 words.
:?*:brenc::branc ; Fixes 70 words
:?*:broadacast::broadcast ; Fixes 13 words
:?*:brod::broad ; Fixes 55 words. Misspells brodiaea (a type of plant)
:?*:buisn::busin ; Fixes 17 words
:?*:buring::burying ; Fixes 4 words
:?*:burrie::burie ; Fixes 7 words
:?*:busness::business ; Fixes 14 words
:?*:bussiness::business ; Fixes 14 words
:?*:caculater::calculator ; Fixes 3 words
:?*:caffin::caffein ; Fixes 12 words
:?*:caharcter::character ; Fixes 38 words
:?*:cahrac::charac ; Fixes 45 words
:?*:calculater::calculator ; Fixes 3 words
:?*:calculla::calcula ; Fixes 41 words
:?*:calculs::calculus ; Fixes 3 words
:?*:caluclat::calculat ; Fixes 31 words
:?*:caluculat::calculat ; Fixes 31 words
:?*:calulat::calculat ; Fixes 31 words
:?*:camae::came ; Fixes 57 words
:?*:campagin::campaign ; Fixes 6 words
:?*:campain::campaign ; Fixes 6 words
:?*:candad::candid ; Fixes 15 words
:?*:candiat::candidat ; Fixes 6 words
:?*:candidta::candidat ; Fixes 6 words
:?*:cannonic::canonic ; Fixes 8 words
:?*:caperbi::capabi ; Fixes 5 words
:?*:capibl::capabl ; Fixes 10 words
:?*:captia::capita ; Fixes 69 words
:?*:caracht::charact ; Fixes 38 words
:?*:caract::charact ; Fixes 38 words
:?*:carcirat::carcerat ; Fixes 14 words
:?*:carism::charism ; Fixes 7 words
:?*:cartileg::cartilag ; Fixes 7 words
:?*:cartilidg::cartilag ; Fixes 7 words
:?*:casette::cassette ; Fixes 6 words
:?*:casue::cause ; Fixes 18 words
:?*:catagor::categor ; Fixes 52 words
:?*:catergor::categor ; Fixes 52 words
:?*:cathlic::catholic ; Fixes 28 words
:?*:catholoc::catholic ; Fixes 28 words
:?*:catre::cater ; Fixes 23 words.  Misspells fornicatress
:?*:ccce::cce ; Fixes 175 words
:?*:ccesi::ccessi ; Fixes 31 words
:?*:ceiev::ceiv ; Fixes 82 words
:?*:ceing::cing ; Fixes 275 words
:?*:cencu::censu ; Fixes 18 words
:?*:centente::centen ; Fixes 35 words
:?*:cerimo::ceremo ; Fixes 18 words
:?*:ceromo::ceremo ; Fixes 18 words
:?*:certian::certain ; Fixes 25 words
:?*:cesion::cession ; Fixes 51 words
:?*:cesor::cessor ; Fixes 33 words
:?*:cesser::cessor ; Fixes 33 words
:?*:cev::ceiv ; Fixes 82 words, but misspells ceviche (South American seafood dish)
:?*:chagne::change ; Fixes 58 words
:?*:chaleng::challeng ; Fixes 17 words
:?*:challang::challeng ; Fixes 17 words
:?*:challengabl::challengeabl ; Fixes 4 words
:?*:changab::changeab ; Fixes 25 words
:?*:charasma::charisma ; Fixes 6 words
:?*:charater::character ; Fixes 38 words
:?*:charecter::character ; Fixes 38 words
:?*:charector::character ; Fixes 38 words
:?*:chargab::chargeab ; Fixes 7 words
:?*:chartiab::charitab ; Fixes 6 words
:?*:cheif::chief ; Fixes 24 words
:?*:chemcial::chemical ; Fixes 34 words
:?*:chemestr::chemistr ; Fixes 31 words
:?*:chict::chit ; Fixes 72 words
:?*:childen::children ; Fixes 6 words
:?*:chracter::character ; Fixes 38 words
:?*:chter::cter ; Fixes 221 words
:?*:cidan::ciden ; Fixes 46 words
:?*:ciencio::cientio ; Fixes 8 words
:?*:ciepen::cipien ; Fixes 18 words
:?*:ciev::ceiv ; Fixes 82 words
:?*:cigic::cific ; Fixes 44 words
:?*:cilation::ciliation ; Fixes 8 words
:?*:cilliar::cillar ; Fixes 8 words
:?*:circut::circuit ; Fixes 14 words
:?*:ciricu::circu ; Fixes 168 words
:?*:cirp::crip ; Fixes 126 words, but misspells Scirpus (Rhizomatous perennial grasslike herbs)
:?*:cison::cision ; Fixes 22 words
:?*:citment::citement ; Fixes 5 words
:?*:civilli::civili ; Fixes 44 words
:?*:clae::clea ; Fixes 151 words
:?*:clasic::classic ; Fixes 38 words
:?*:clincial::clinical ; Fixes 7 words
:?*:clomation::clamation ; Fixes 10 words
:?*:cmo::com ; Fixes 1749 words
:?*:cna::can ; Fixes 1019 words.  Misspells Pycnanthemum (mint), and Tridacna (giant clam).+
:?*:coform::conform ; Fixes 46 words
:?*:cogis::cognis ; Fixes 36 words
:?*:cogiz::cogniz ; Fixes 42 words
:?*:cogntivie::cognitive ; Fixes 4 words
:?*:colaborat::collaborat ; Fixes 15 words
:?*:colecti::collecti ; Fixes 49 words
:?*:colelct::collect ; Fixes 69 words
:?*:collon::colon ; Fixes 89 words
:?*:comanie::companie ; Fixes 5 words
:?*:comany::company ; Fixes 6 words
:?*:comapan::compan ; Fixes 39 words
:?*:comapn::compan ; Fixes 39 words
:?*:comban::combin ; Fixes 40 words
:?*:combatent::combatant ; Fixes 4 words
:?*:combinatin::combination ; Fixes 5 words
:?*:combusi::combusti ; Fixes 17 words
:?*:comemmorat::commemorat ; Fixes 12 words
:?*:comemorat::commemorat ; Fixes 12 words
:?*:comision::commission ; Fixes 21 words
:?*:comiss::commiss ; Fixes 33 words
:?*:comitt::committ ; Fixes 27 words
:?*:commed::comed ; Fixes 18 words
:?*:commerical::commercial ; Fixes 33 words
:?*:commericial::commercial ; Fixes 33 words
:?*:commini::communi ; Fixes 117 words
:?*:commision::commission ; Fixes 21 words
:?*:commite::committe ; Fixes 16 words
:?*:commongly::commonly ; Fixes 2 words
:?*:commuica::communica ; Fixes 72 words
:?*:commuinica::communica ; Fixes 72 words
:?*:communcia::communica ; Fixes 72 words
:?*:communia::communica ; Fixes 72 words
:?*:comnt::cont ; Fixes 587 words
:?*:comon::common ; Fixes 33 words
:?*:compatab::compatib ; Fixes 16 words
:?*:compatiab::compatib ; Fixes 16 words
:?*:compeit::competit ; Fixes 17 words
:?*:compenc::compens ; Fixes 29 words
:?*:competan::competen ; Fixes 21 words
:?*:competati::competiti ; Fixes 14 words
:?*:competens::competenc ; Fixes 12 words
:?*:competive::competitive ; Fixes 12 words
:?*:comphr::compr ; Fixes 106 words
:?*:compleate::complete ; Fixes 17 words
:?*:compleatness::completeness ; Fixes 3 words
:?*:comprab::comparab ; Fixes 13 words
:?*:comprimis::compromis ; Fixes 12 words
:?*:comun::commun ; Fixes 140 words
:?*:concider::consider ; Fixes 31 words
:?*:concieve::conceive ; Fixes 13 words
:?*:concious::conscious ; Fixes 25 words
:?*:condidt::condit ; Fixes 36 words
:?*:conect::connect ; Fixes 52 words
:?*:conferanc::conferenc ; Fixes 12 words
:?*:configurea::configura ; Fixes 15 words
:?*:confort::comfort ; Fixes 21 words
:?*:conqur::conquer ; Fixes 16 words
:?*:conscen::consen ; Fixes 17 words
:?*:consdider::consider ; Fixes 31 words
:?*:consectu::consecu ; Fixes 4 words
:?*:consentr::concentr ; Fixes 32 words
:?*:consept::concept ; Fixes 46 words
:?*:consern::concern ; Fixes 17 words
:?*:conservit::conservat ; Fixes 41 words
:?*:consici::consci ; Fixes 45 words
:?*:consico::conscio ; Fixes 32 words
:?*:considerd::considered ; Fixes 5 words
:?*:considerit::considerat ; Fixes 12 words
:?*:consio::conscio ; Fixes 32 words
:?*:consitu::constitu ; Fixes 45 words
:?*:consoloda::consolida ; Fixes 18 words
:?*:consonent::consonant ; Fixes 8 words
:?*:constain::constrain ; Fixes 15 words
:?*:constin::contin ; Fixes 86 words
:?*:consumate::consummate ; Fixes 6 words
:?*:consumbe::consume ; Fixes 15 words
:?*:contian::contain ; Fixes 28 words
:?*:contien::conscien ; Fixes 13 words
:?*:contigen::contingen ; Fixes 8 words
:?*:contined::continued ; Fixes 4 words
:?*:continential::continental ; Fixes 10 words
:?*:continetal::continental ; Fixes 10 words
:?*:contino::continuo ; Fixes 11 words
:?*:contitut::constitut ; Fixes 40 words
:?*:contravers::controvers ; Fixes 10 words
:?*:contributer::contributor ; Fixes 4 words
:?*:controle::controlle ; Fixes 10 words
:?*:controling::controlling ; Fixes 4 words
:?*:controveri::controversi ; Fixes 9 words
:?*:controversal::controversial ; Fixes 8 words
:?*:controvertial::controversial ; Fixes 8 words
:?*:contru::constru ; Fixes 73 words
:?*:convenant::covenant ; Fixes 10 words
:?*:convential::conventional ; Fixes 23 words
:?*:convice::convince ; Fixes 10 words
:?*:coopor::cooper ; Fixes 26 words
:?*:coorper::cooper ; Fixes 26 words
:?*:copm::comp ; Fixes 729 words
:?*:copty::copy ; Fixes 78 words
:?*:coput::comput ; Fixes 46 words
:?*:copywrite::copyright ; Fixes 6 words
:?*:coropor::corpor ; Fixes 74 words
:?*:corpar::corpor ; Fixes 74 words
:?*:corpera::corpora ; Fixes 59 words
:?*:corporta::corporat ; Fixes 53 words
:?*:corprat::corporat ; Fixes 53 words
:?*:corpro::corpor ; Fixes 74 words
:?*:corrispond::correspond ; Fixes 12 words
:?*:corruptab::corruptib ; Fixes 10 words
:?*:costit::constit ; Fixes 45 words
:?*:cotten::cotton ; Fixes 21 words
:?*:countain::contain ; Fixes 28 words
:?*:couraing::couraging ; Fixes 7 words
:?*:couro::coro ; Fixes 53 words
:?*:courur::cour ; Fixes 144 words
:?*:cpom::com ; Fixes 1749 words
:?*:cpoy::copy ; Fixes 78 words
:?*:creaet::creat ; Fixes 75 words
:?*:credia::credita ; Fixes 13 words
:?*:credida::credita ; Fixes 13 words
:?*:criib::crib ; Fixes 119 words
:?*:crti::criti ; Fixes 59 words
:?*:crticis::criticis ; Fixes 13 words
:?*:crusie::cruise ; Fixes 9 words
:?*:crutia::crucia ; Fixes 22 words
:?*:crystalisa::crystallisa ; Fixes 5 words
:?*:ctaegor::categor ; Fixes 52 words
:?*:ctail::cktail ; Fixes 6 words
:?*:ctent::ctant ; Fixes 30 words
:?*:cticious::ctitious ; Fixes 14 words
:?*:ctinos::ctions ; Fixes 214 words
:?*:ctoin::ction ; Fixes 717 words
:?*:cualr::cular ; Fixes 256 words
:?*:cuas::caus ; Fixes 55 words
:?*:cultral::cultural ; Fixes 43 words
:?*:cultue::culture ; Fixes 48 words
:?*:culure::culture ; Fixes 48 words
:?*:curcuit::circuit ; Fixes 14 words
:?*:cusotm::custom ; Fixes 43 words
:?*:cutsom::custom ; Fixes 43 words
:?*:cuture::culture ; Fixes 48 words
:?*:cxan::can ; Fixes 1015 words
:?*:damenor::demeanor ; Fixes 4 words
:?*:damenour::demeanour ; Fixes 4 words
:?*:dammag::damag ; Fixes 11 words
:?*:damy::demy ; Fixes 28 words
:?*:daugher::daughter ; Fixes 12 words
:?*:dcument::document ; Fixes 26 words
:?*:ddti::dditi ; Fixes 14 words
:?*:deatil::detail ; Fixes 11 words
:?*:decend::descend ; Fixes 26 words
:?*:decideab::decidab ; Fixes 4 words
:?*:decrib::describ ; Fixes 19 words
:?*:dectect::detect ; Fixes 20 words
:?*:defendent::defendant ; Fixes 4 words
:?*:deffens::defens ; Fixes 26 words
:?*:deffin::defin ; Fixes 54 words
:?*:definat::definit ; Fixes 18 words
:?*:defintion::definition ; Fixes 5 words
:?*:degrat::degrad ; Fixes 31 words
:?*:degred::degrad ; Fixes 31 words
:?*:deinc::dienc ; Fixes 20 words
:?*:delag::deleg ; Fixes 42 words
:?*:delevop::develop ; Fixes 44 words
:?*:demeno::demeano ; Fixes 8 words
:?*:demorcr::democr ; Fixes 27 words
:?*:denegrat::denigrat ; Fixes 10 words
:?*:denpen::depen ; Fixes 50 words
:?*:dentational::dental ; Fixes 46 words
:?*:deparment::department ; Fixes 17 words
:?*:depedant::dependent ; Fixes 11 words
:?*:depeden::dependen ; Fixes 29 words
:?*:dependan::dependen ; Fixes 29 words
:?*:deptart::depart ; Fixes 27 words
:?*:deram::dream ; Fixes 40 words
:?*:deriviate::derive ; Fixes 9 words
:?*:derivit::derivat ; Fixes 13 words
:?*:descib::describ ; Fixes 19 words
:?*:descision::decision ; Fixes 5 words
:?*:descus::discus ; Fixes 14 words.
:?*:desided::decided ; Fixes 7 words.
:?*:desinat::destinat ; Fixes 11 words.
:?*:desireab::desirab ; Fixes 11 words
:?*:desision::decision ; Fixes 5 words.
:?*:desitn::destin ; Fixes 30 words
:?*:despatch::dispatch ; Fixes 7 words.
:?*:despensib::dispensab ; Fixes 10 words
:?*:despict::depict ; Fixes 10 words.
:?*:despira::despera ; Fixes 9 words.
:?*:dessign::design ; Fixes 51 words.
:?*:destory::destroy ; Fixes 8 words.
:?*:detecab::detectab ; Fixes 7 words
:?*:develeopr::developer ; Fixes 6 words.
:?*:devellop::develop ; Fixes 44 words.
:?*:developor::developer ; Fixes 6 words
:?*:developpe::develope ; Fixes 13 words
:?*:develp::develop ; Fixes 44 words.
:?*:devid::divid ; Fixes 61 words.
:?*:devolop::develop ; Fixes 44 words.
:?*:dgeing::dging ; Fixes 50 words
:?*:dgement::dgment ; Fixes 20 words
:?*:diapl::displ ; Fixes 33 words.
:?*:diarhe::diarrhoe ; Fixes 7 words
:?*:dicatb::dictab ; Fixes 14 words
:?*:diciplin::disciplin ; Fixes 22 words
:?*:dicover::discover ; Fixes 26 words
:?*:dicus::discus ; Fixes 14 words
:?*:difef::diffe ; Fixes 48 words
:?*:diferre::differe ; Fixes 41 words
:?*:differan::differen ; Fixes 40 words
:?*:diffren::differen ; Fixes 40 words
:?*:dimenion::dimension ; Fixes 17 words
:?*:dimention::dimension ; Fixes 17 words
:?*:dimesnion::dimension ; Fixes 17 words
:?*:diosese::diocese ; Fixes 4 words
:?*:dipend::depend ; Fixes 50 words
:?*:diriv::deriv ; Fixes 26 words
:?*:discrib::describ ; Fixes 19 words
:?*:disign::design ; Fixes 51 words
:?*:disipl::discipl ; Fixes 26 words
:?*:disolved::dissolved ; Fixes 19 words
:?*:dispaly::display ; Fixes 11 words
:?*:dispenc::dispens ; Fixes 23 words
:?*:dispensib::dispensab ; Fixes 10 words
:?*:disputib::disputab ; Fixes 12 words
:?*:disrict::district ; Fixes 10 words
:?*:distruct::destruct ; Fixes 21 words
:?*:ditonal::ditional ; Fixes 25 words
:?*:ditribut::distribut ; Fixes 37 words
:?*:divice::device ; Fixes 4 words
:?*:divsi::divisi ; Fixes 24 words
:?*:dmant::dment ; Fixes 28 words
:?*:dminst::dminist ; Fixes 27 words
:?*:doccu::docu ; Fixes 32 words
:?*:doctin::doctrin ; Fixes 14 words
:?*:docuement::document ; Fixes 26 words
:?*:docuemnt::document ; Fixes 26 words
:?*:documetn::document ; Fixes 26 words
:?*:documnet::document ; Fixes 26 words
:?*:doind::doing ; Fixes 21 words
:?*:dolan::dolen ; Fixes 12 words
:?*:doller::dollar ; Fixes 14 words
:?*:dominent::dominant ; Fixes 9 words
:?*:dowloads::download ; Fixes 9 words
:?*:dpend::depend ; Fixes 50 words
:?*:dramtic::dramatic ; Fixes 11 words
:?*:driect::direct ; Fixes 71 words
:?*:driveing::driving ; Fixes 5 words
:?*:drnik::drink ; Fixes 23 words
:?*:dulgue::dulge ; Fixes 23 words
:?*:dupicat::duplicat ; Fixes 26 words
:?*:durig::during ; Fixes 5 words
:?*:durring::during ; Fixes 5 words
:?*:duting::during ; Fixes 5 words
:?*:eacll::ecall ; Fixes 8 words
:?*:eanr::earn ; Fixes 60 words
:?*:eaolog::eolog ; Fixes 134 words
:?*:eareance::earance ; Fixes 12 words
:?*:earence::earance ; Fixes 12 words
:?*:easen::easan ; Fixes 33 words
:?*:easr::ears ; Fixes 102 words
:?*:ecco::eco ; Fixes 994 words, but misspells Prosecco (Italian wine) and recco (abbrev. for Reconnaissance)
:?*:eccu::ecu ; Fixes 353 words
:?*:eceed::ecede ; Fixes 35 words
:?*:eceonom::econom ; Fixes 50 words
:?*:ecepi::ecipi ; Fixes 28 words
:?*:ecomon::econom ; Fixes 50 words
:?*:ecuat::equat ; Fixes 22 words
:?*:ecyl::ecycl ; Fixes 15 words
:?*:edabl::edibl ; Fixes 11 words
:?*:eearl::earl ; Fixes 66 words
:?*:eeen::een ; Fixes 452 words
:?*:eeep::eep ; Fixes 316 words
:?*:eferan::eferen ; Fixes 35 words 
:?*:efered::eferred ; Fixes 5 words
:?*:efering::eferring ; Fixes 3 words
:?*:efern::eferen ; Fixes 35 words
:?*:effecien::efficien ; Fixes 10 words
:?*:efficen::efficien ; Fixes 10 words
:?*:egth::ength ; Fixes 33 words
:?*:ehter::ether ; Fixes 84 words
:?*:eild::ield ; Fixes 147 words
:?*:elavan::elevan ; Fixes 16 words
:?*:elction::election ; Fixes 20 words
:?*:electic::electric ; Fixes 40 words
:?*:electrial::electrical ; Fixes 13 words
:?*:elemin::elimin ; Fixes 14 words
:?*:eletric::electric ; Fixes 40 words
:?*:elien::elian ; Fixes 27 words
:?*:eligab::eligib ; Fixes 10 words
:?*:eligo::eligio ; Fixes 30 words
:?*:eliment::element ; Fixes 12 words
:?*:ellected::elected ; Fixes 11 words
:?*:elyhood::elihood ; Fixes 6 words
:?*:embarass::embarrass ; Fixes 17 words
:?*:emce::ence ; Fixes 775 words, but misspells emcee (host at formal occasion)
:?*:emiting::emitting ; Fixes 6 words
:?*:emmediate::immediate ; Fixes 3 words
:?*:emmigr::emigr ; Fixes 21 words
:?*:emmin::emin ; Fixes 32 words
:?*:emmis::emis ; Fixes 214 words
:?*:emmit::emitt ; Fixes 28 words
:?*:emostr::emonstr ; Fixes 45 words
:?*:empahs::emphas ; Fixes 42 words
:?*:emperic::empiric ; Fixes 10 words
:?*:emphais::emphasis ; Fixes 21 words
:?*:emphsis::emphasis ; Fixes 21 words
:?*:emprison::imprison ; Fixes 11 words
:?*:enchang::enchant ; Fixes 27 words
:?*:encial::ential ; Fixes 244 words
:?*:endand::endant ; Fixes 19 words
:?*:endig::ending ; Fixes 109 words
:?*:enduc::induc ; Fixes 33 words
:?*:enece::ence ; Fixes 775 words
:?*:enence::enance ; Fixes 18 words
:?*:enflam::inflam ; Fixes 22 words
:?*:engagment::engagement ; Fixes 6 words
:?*:engeneer::engineer ; Fixes 17 words
:?*:engieneer::engineer ; Fixes 17 words
:?*:engten::engthen ; Fixes 17 words
:?*:entagl::entangl ; Fixes 19 words
:?*:entaly::entally ; Fixes 46 words
:?*:entatr::entar ; Fixes 81 words
:?*:entce::ence ; Fixes 775 words
:?*:entgh::ength ; Fixes 33 words
:?*:enthusiatic::enthusiastic ; Fixes 6 words
:?*:entiatiation::entiation ; Fixes 8 words
:?*:entily::ently ; Fixes 261 wordsuently
:?*:envolu::evolu ; Fixes 50 words
:?*:enxt::next ; Fixes 23 words
:?*:eperat::eparat ; Fixes 33 words
:?*:equalibr::equilibr ; Fixes 20 words
:?*:equelibr::equilibr ; Fixes 20 words
:?*:equialent::equivalent ; Fixes 8 words
:?*:equilibium::equilibrium ; Fixes 4 words
:?*:equilibrum::equilibrium ; Fixes 4 words
:?*:equivelant::equivalent ; Fixes 8 words
:?*:equivilant::equivalent ; Fixes 8 words
:?*:equivilent::equivalent ; Fixes 8 words
:?*:erchen::erchan ; Fixes 42 words
:?*:ereance::earance ; Fixes 12 words
:?*:eremt::erent ; Fixes 96 words
:?*:ernece::erence ; Fixes 54 words
:?*:ernt::erent ; Fixes 8 words
:?*:erruped::errupted ; Fixes 6 words
:?*:esab::essab ; Fixes 9 words
:?*:esential::essential ; Fixes 8 words
:?*:esisten::esistan ; Fixes 11 words
:?*:esitmat::estimat ; Fixes 15 words
:?*:esnt::esent ; Fixes 103 words
:?*:esorce::esource ; Fixes 11 words
:?*:essense::essence ; Fixes 4 words
:?*:essentail::essential ; Fixes 18 words
:?*:essentual::essential ; Fixes 18 words
:?*:essesital::essential ; Fixes 18 words
:?*:estabish::establish ; Fixes 34 words
:?*:estoin::estion ; Fixes 44 words
:?*:esxual::sexual ; Fixes 91 words
:?*:etanc::etenc ; Fixes 20 words
:?*:etead::eated ; Fixes 50 words
:?*:eveyr::every ; Fixes 12 words
:?*:exagerat::exaggerat ; Fixes 15 words
:?*:exagerrat::exaggerat ; Fixes 15 words
:?*:exampt::exempt ; Fixes 7 words
:?*:exapan::expan ; Fixes 42 words
:?*:excact::exact ; Fixes 25 words
:?*:excang::exchang ; Fixes 13 words
:?*:excecut::execut ; Fixes 27 words
:?*:excedd::exceed ; Fixes 9 words
:?*:excercis::exercis ; Fixes 15 words
:?*:exchanch::exchang ; Fixes 12 words
:?*:excist::exist ; Fixes 38 words
:?*:execis::exercis ; Fixes 15 words
:?*:exeed::exceed ; Fixes 9 words
:?*:exept::except ; Fixes 25 words
:?*:exersize::exercise ; Fixes 11 words
:?*:exict::excit ; Fixes 39 words
:?*:exinct::extinct ; Fixes 4 words
:?*:exisit::exist ; Fixes 38 words
:?*:existan::existen ; Fixes 22 words
:?*:exlile::exile ; Fixes 5 words
:?*:exmapl::exampl ; Fixes 7 words
:?*:expalin::explain ; Fixes 20 words
:?*:expeced::expected ; Fixes 6 words
:?*:expecial::especial ; Fixes 5 words
:?*:experianc::experienc ; Fixes 11 words
:?*:expidi::expedi ; Fixes 32 words
:?*:expierenc::experienc ; Fixes 11 words
:?*:expirien::experien ; Fixes 15 words
:?*:explict::explicit ; Fixes 7 words
:?*:exploitit::exploitat ; Fixes 9 words
:?*:explotat::exploitat ; Fixes 9 words
:?*:exprienc::experienc ; Fixes 11 words
:?*:exressed::expressed ; Fixes 52 words
:?*:exsis::exis ; Fixes 48 words
:?*:extention::extension ; Fixes 10 words
:?*:extint::extinct ; Fixes 4 words
:?*:facist::fascist ; Fixes 7 words
:?*:fagia::phagia ; Fixes 18 words
:?*:falab::fallib ; Fixes 10 words
:?*:fallab::fallib ; Fixes 10 words
:?*:familar::familiar ; Fixes 36 words
:?*:familli::famili ; Fixes 37 words
:?*:fammi::fami ; Fixes 57 words
:?*:fascit::facet ; Fixes 14 words
:?*:fasia::phasia ; Fixes 10 words
:?*:fatc::fact ; Fixes 200 words
:?*:fature::facture ; Fixes 10 words
:?*:faught::fought ; Fixes 7 words
:?*:feasable::feasible ; Fixes 11 words, but misspells unfeasable (archaic, no longer used)
:?*:fedre::feder ; Fixes 45 words
:?*:femmi::femi ; Fixes 53 words
:?*:fencive::fensive ; Fixes 15 words
:?*:ferec::ferenc ; Fixes 45 words
:?*:fereing::fering ; Fixes 16 words
:?*:feriang::ferring ; Fixes 6 words
:?*:ferren::feren ; Fixes 113 words
:?*:fertily::fertility ; Fixes 7 words
:?*:fesion::fession ; Fixes 40 words
:?*:fesser::fessor ; Fixes 12 words
:?*:festion::festation ; Fixes 8 words
:?*:ffese::fesse ; Fixes 10 words
:?*:ffesion::fession ; Fixes 40 words
:?*:fficen::fficien ; Fixes 20 words
:?*:fianit::finit ; Fixes 79 words
:?*:fictious::fictitious ; Fixes 4 words
:?*:fidn::find ; Fixes 22 words
:?*:fiet::feit ; Fixes 23 words
:?*:filiament::filament ; Fixes 16 words
:?*:filitrat::filtrat ; Fixes 21 words
:?*:fimil::famil ; Fixes 43 words
:?*:finac::financ ; Fixes 14 words
:?*:finat::finit ; Fixes 43 words
:?*:finet::finit ; Fixes 43 words
:?*:finining::fining ; Fixes 12 words
:?*:firc::furc ; Fixes 33 words, Case-sensitive to not misspell FIRCA (sustainable funding mechanism for agricultural development)
:?*:firend::friend ; Fixes 30 words
:?*:firmm::firm ; Fixes 85 words
:?*:fisi::fissi ; Fixes 35 words
:?*:flama::flamma ; Fixes 17 words
:?*:flourid::fluorid ; Fixes 25 words
:?*:flourin::fluorin ; Fixes 5 words
:?*:fluan::fluen ; Fixes 48 words
:?*:fluorish::flourish ; Fixes 13 words
:?*:focuss::focus ; Fixes 6 words 
:?*:foer::fore ; Fixes 340 words
:?*:follwo::follow ; Fixes 10 words
:?*:folow::follow ; Fixes 10 words
:?*:fomat::format ; Fixes 72 words
:?*:fomed::formed ; Fixes 37 words
:?*:fomr::form ; Fixes 1269 words
:?*:foneti::phoneti ; Fixes 24 words
:?*:fontrier::frontier ; Fixes 6 words
:?*:fooot::foot ; Fixes 176 words
:?*:forbiden::forbidden ; Fixes 7 words
:?*:foretun::fortun ; Fixes 18 words
:?*:forgetab::forgettab ; Fixes 7 words
:?*:forgiveabl::forgivabl ; Fixes 6 words
:?*:formidible::formidable ; Fixes 5 words
:?*:formost::foremost ; Fixes 5 words
:?*:forsee::foresee ; Fixes 16 words
:?*:forwrd::forward ; Fixes 16 words
:?*:foucs::focus ; Fixes 28 words
:?*:foudn::found ; Fixes 62 words
:?*:fourti::forti ; Fixes 31 words
:?*:fourtun::fortun ; Fixes 18 words
:?*:foward::forward ; Fixes 16 words
:?*:freind::friend ; Fixes 44 words
:?*:frence::ference ; Fixes 37 words
:?*:fromed::formed ; Fixes 34 words
:?*:fromi::formi ; Fixes 84 words
:?*:fucnt::funct ; Fixes 60 words
:?*:fufill::fulfill ; Fixes 16 words
:?*:fulen::fluen ; Fixes 64 words
:?*:fullfill::fulfill ; Fixes 16 words
:?*:furut::furt ; Fixes 16 words
:?*:gallax::galax ; Fixes 4 words
:?*:galvin::galvan ; Fixes 27 words
:?*:ganaly::ginally ; Fixes 8 words
:?*:ganera::genera ; Fixes 124 words
:?*:garant::guarant ; Fixes 9 words
:?*:garav::grav ; Fixes 128 words
:?*:garnison::garrison ; Fixes 5 words
:?*:gaurant::guarant ; Fixes 9 words
:?*:gaurd::guard ; Fixes 57 words
:?*:gemer::gener ; Fixes 151 words
:?*:generatt::generat ; Fixes 58 words
:?*:gestab::gestib ; Fixes 19 words
:?*:giid::good ; Fixes 31 words, but misspells Phalangiidae (typoe of Huntsman spider)
:?*:giveing::giving ; Fixes 20 words
:?*:glight::flight ; Fixes 16 words
:?*:glph::glyph ; Fixes 27 words
:?*:glua::gula ; Fixes 174 words
:?*:gnficia::gnifica ; Fixes 29 words
:?*:gnizen::gnizan ; Fixes 9 words
:?*:godess::goddess ; Fixes 5 words
:?*:gorund::ground ; Fixes 80 words
:?*:gourp::group ; Fixes 28 words 
:?*:govement::government ; Fixes 10 words
:?*:govenment::government ; Fixes 10 words
:?*:govenrment::government ; Fixes 10 words
:?*:govera::governa ; Fixes 11 words
:?*:goverment::government ; Fixes 10 words
:?*:govor::govern ; Fixes 46 words
:?*:gradded::graded ; Fixes 13 words
:?*:graffitti::graffiti ; Fixes 6 words
:?*:grama::gramma ; Fixes 72 words, but misspells grama (Pasture grass of plains of South America and western North America)
:?*:grammma::gramma ; Fixes 72 words
:?*:greatful::grateful ; Fixes 8 words
:?*:greee::gree ; Fixes 185 words
:?*:gresion::gression ; Fixes 27 words
:?*:gropu::group ; Fixes 28 words
:?*:gruop::group ; Fixes 28 words
:?*:grwo::grow ; Fixes 67 words
:?*:gsit::gist ; Fixes 585 words
:?*:gubl::guabl ; Fixes 8 words
:?*:guement::gument ; Fixes 21 words
:?*:guidence::guidance ; Fixes 4 words
:?*:gurantee::guarantee ; Fixes 5 words
:?*:habitans::habitants ; Fixes 3 words
:?*:habition::hibition ; Fixes 21 words
:?*:haneg::hange ; Fixes 69 words
:?*:harased::harassed ; Fixes 3 words
:?*:havour::havior ; Fixes 13 words
:?*:hcange::change ; Fixes 58 words
:?*:hcih::hich ; Fixes 15 words
:?*:heirarch::hierarch ; Fixes 14 words
:?*:heiroglyph::hieroglyph ; Fixes 6 words
:?*:heiv::hiev ; Fixes 49 words
:?*:herant::herent ; Fixes 10 words
:?*:heridit::heredit ; Fixes 19 words
:?*:hertia::herita ; Fixes 23 words
:?*:hertzs::hertz ; Fixes 12 words
:?*:hicial::hical ; Fixes 170 words
:?*:hierach::hierarch ; Fixes 14 words
:?*:hierarcic::hierarchic ; Fixes 6 words
:?*:higway::highway ; Fixes 6 words
:?*:hnag::hang ; Fixes 150 words
:?*:holf::hold ; Fixes 120 words
:?*:hospiti::hospita ; Fixes 27 words
:?*:houno::hono ; Fixes 99 words
:?*:hstor::histor ; Fixes 56 words
:?*:humerous::humorous ; Fixes 6 words
:?*:humur::humour ; Fixes 12 words
:?*:hvae::have ; Fixes 47 words
:?*:hvai::havi ; Fixes 37 words
:?*:hvea::have ; Fixes 47 words
:?*:hwere::where ; Fixes 27 words
:?*:hydog::hydrog ; Fixes 50 words
:?*:hymm::hym ; Fixes 125 words
:?*:ibile::ible ; Fixes 367 words
:?*:ibilt::ibilit ; Fixes 281 words
:?*:iblit::ibilit ; Fixes 281 words
:?*:icibl::iceabl ; Fixes 14 words
:?*:iciton::iction ; Fixes 89 words
:?*:ictoin::iction ; Fixes 89 words
:?*:idenital::idential ; Fixes 18 words
:?*:iegh::eigh ; Fixes 186 words
:?*:iegn::eign ; Fixes 83 words
:?*:ievn::iven ; Fixes 440 words
:?*:igeou::igiou ; Fixes 23 words
:?*:igini::igni ; Fixes 127 words
:?*:ignf::ignif ; Fixes 50 words
:?*:igous::igious ; Fixes 23 words, but misspells pemphigous (a skin disease)
:?*:igth::ight ; Jack's fixes 315 words
:?*:ihs::his ; Fixes 618 words
:?*:iht::ith ; Fixes 560 words
:?*:ijng::ing ; Fixes 15158 words
:?*:ilair::iliar ; Fixes 46 words
:?*:illution::illusion ; Fixes 16 words
:?*:imagen::imagin ; Fixes 40 words
:?*:immita::imita ; Fixes 41 words
:?*:impliment::implement ; Fixes 17 words
:?*:imploy::employ ; Fixes 38 words
:?*:importen::importan ; Fixes 10 words
:?*:imprion::imprison ; Fixes 11 words
:?*:incede::incide ; Fixes 21 words
:?*:incidential::incidental ; Fixes 6 words
:?*:incra::incre ; Fixes 28 words
:?*:inctro::intro ; Fixes 68 words
:?*:indeca::indica ; Fixes 40 words
:?*:indite::indict ; Fixes 22 words, but misspells indite (Produce a literaryÂ work)
:?*:indutr::industr ; Fixes 59 words
:?*:indvidua::individua ; Fixes 32 words
:?*:inece::ience ; Fixes 101 words
:?*:ineing::ining ; Fixes 193 words
:?*:inential::inental ; Fixes 10 words
:?*:infectuo::infectio ; Fixes 15 words
:?*:infrant::infant ; Fixes 31 words
:?*:infrige::infringe ; Fixes 7 words
:?*:ingenius::ingenious ; Fixes 4 words
:?*:inheritage::inheritance ; Fixes 4 words
:?*:inheritence::inheritance ; Fixes 4 words
:?*:inially::inally ; Fixes 46 words
:?*:ininis::inis ; Fixes 388 words
:?*:inital::initial ; Fixes 25 words
:?*:inng::ing ; Fixes 15158 words
:?*:innocula::inocula ; Fixes 16 words
:?*:inpeach::impeach ; Fixes 15 words
:?*:inpolit::impolit ; Fixes 7 words
:?*:inprison::imprison ; Fixes 11 words
:?*:inprov::improv ; Fixes 41 words
:?*:insitut::institut ; Fixes 42 words
:?*:institue::institute ; Fixes 8 words
:?*:instu::instru ; Fixes 44 words
:?*:intelect::intellect ; Fixes 42 words
:?*:intelig::intellig ; Fixes 27 words
:?*:intenational::international ; Fixes 27 words
:?*:intented::intended ; Fixes 7 words
:?*:intepret::interpret ; Fixes 39 words
:?*:interational::international ; Fixes 27 words
:?*:interferance::interference ; Fixes 4 words
:?*:intergrat::integrat ; Fixes 35 words
:?*:interpet::interpret ; Fixes 39 words
:?*:interupt::interrupt ; Fixes 15 words
:?*:inteven::interven ; Fixes 20 words
:?*:intrduc::introduc ; Fixes 16 words
:?*:intrest::interest ; Fixes 19 words
:?*:intruduc::introduc ; Fixes 16 words
:?*:intut::intuit ; Fixes 19 words
:?*:inudstr::industr ; Fixes 59 words
:?*:investingat::investigat ; Fixes 17 words
:?*:iopn::ion ; Fixes 8515 words
:?*:iouness::iousness ; Fixes 220 words
:?*:iousit::iosit ; Fixes 15 words
:?*:irts::irst ; Fixes 41 words
:?*:isherr::isher ; Fixes 71 words
:?*:ishor::isher ; Fixes 71 words
:?*:ishre::isher ; Fixes 71 words
:?*:isile::issile ; Fixes 6 words
:?*:issence::issance ; Fixes 11 words
:?*:iticing::iticising ; Fixes 3 words
:?*:itina::itiona ; Fixes 79 words, misspells Mephitinae (skunk), neritina (snail)
:?*:ititia::initia ; Fixes 41 words
:?*:itition::ition ; Fixes 389 words
:?*:itnere::intere ; Fixes 25 words
:?*:itnroduc::introduc ; Fixes 16 words
:?*:itoin::ition ; Fixes 389 words
:?*:itttle::ittle ; Fixes 49 words
:?*:iveing::iving ; Fixes 75 words
:?*:iverous::ivorous ; Fixes 17 words
:?*:ivle::ivel ; Fixes 589 words, but misspells braaivleis (Type of S. Affrican BBQ)
:?*:iwll::will ; Fixes 64 words
:?*:iwth::with ; Fixes 56 words
:?*:jecutr::jectur ; Fixes 8 words
:?*:jist::gist ; Fixes 587 words
:?*:jstu::just ; Fixes 83 words
:?*:jsut::just ; Fixes 83 words
:?*:juct::junct ; Fixes 58 words
:?*:judgment::judgement ; Fixes 11 words
:?*:judical::judicial ; Fixes 9 words
:?*:judisua::judicia ; Fixes 11 words
:?*:juduci::judici ; Fixes 20 words
:?*:jugment::judgment ; Fixes 12 words
:?*:juristiction::jurisdiction ; Fixes 4 words
:?*:kindergarden::kindergarten ; Fixes 4 words
:?*:knowldeg::knowledg ; Fixes 32 words
:?*:knowldg::knowledg ; Fixes 32 words
:?*:knowleg::knowledg ; Fixes 32 words
:?*:knwo::know ; Fixes 66 words
:?*:konw::know ; Fixes 66 words
:?*:kwno::know ; Fixes 66 words
:?*:labat::laborat ; Fixes 39 words
:?*:laeg::leag ; Fixes 21 words
:?*:laguage::language ; Fixes 12 words
:?*:laimation::lamation ; Fixes 10 words
:?*:laion::lation ; Fixes 448 words
:?*:lalbe::lable ; Fixes 122 words
:?*:laraty::larity ; Fixes 41 words
:?*:lastes::lates ; Fixes 212 words
:?*:lateab::latab ; Fixes 29 words
:?*:latrea::latera ; Fixes 70 words
:?*:lattitude::latitude ; Fixes 5 words
:?*:launhe::launche ; Fixes 6 words
:?*:lcud::clud ; Fixes 33 words
:?*:leagur::leaguer ; Fixes 8 words
:?*:leathal::lethal ; Fixes 7 words
:?*:lece::lesce ; Fixes 52 words, but misspells Illecebrum (contains the single species Illecebrum verticillatum, which is a trailing annual plant native to Europe)
:?*:lecton::lection ; Fixes 52 words
:?*:legitamat::legitimat ; Fixes 35 words
:?*:legitm::legitim ; Fixes 67 words
:?*:legue::league ; Fixes 13 words
:?*:leiv::liev ; Fixes 52 words
:?*:libgui::lingui ; Fixes 34 words
:?*:liek::like ; Fixes 405 words
:?*:liement::lement ; Fixes 128 words
:?*:lieuenan::lieutenan ; Fixes 6 words
:?*:lieutenen::lieutenan ; Fixes 6 words
:?*:likl::likel ; Fixes 14 words
:?*:liscen::licen ; Fixes 34 words
:?*:lisehr::lisher ; Fixes 14 words
:?*:lisen::licen ; Fixes 34 words, but misspells lisente (100 lisente equal 1 loti in Lesotho, S. Afterica)
:?*:lisheed::lished ; Fixes 27 words
:?*:lishh::lish ; Fixes 211 words
:?*:lissh::lish ; Fixes 211 words
:?*:listn::listen ; Fixes 19 words
:?*:litav::lativ ; Fixes 97 words
:?*:litert::literat ; Fixes 49 words
:?*:littel::little ; Fixes 15 words
:?*:litteral::literal ; Fixes 27 words
:?*:littoe::little ; Fixes 15 words
:?*:liuke::like ; Fixes 405 words
:?*:llarious::larious ; Fixes 6 words
:?*:llegen::llegian ; Fixes 7 words
:?*:llegien::llegian ; Fixes 7 words
:?*:lmits::limits ; Fixes 3 words
:?*:loev::love ; Fixes 111 words
:?*:lonle::lonel ; Fixes 9 words
:?*:lpp::lp ; Fixes 509 words
:?*:lsih::lish ; Fixes 211 words
:?*:lsot::lso ; Fixes 42 words
:?*:lutly::lutely ; Fixes 7 words
:?*:lyed::lied ; Fixes 50 words
:?*:machne::machine ; Fixes 8 words
:?*:maintina::maintain ; Fixes 14 words
:?*:maintion::mention ; Fixes 15 words
:?*:majorot::majorit ; Fixes 7 words
:?*:makeing::making ; Fixes 45 words
:?*:making it's::making its
:?*:makse::makes ; Fixes 7 words
:?*:mallise::malize ; Fixes 17 words ; Ambiguous
:?*:mallize::malize ; Fixes 17 words
:?*:mamal::mammal ; Fixes 13 words
:?*:mamant::mament ; Fixes 11 words
:?*:managab::manageab ; Fixes 9 words
:?*:managment::management ; Fixes 6 words
:?*:maneouv::manoeuv ; Fixes 17 words
:?*:manoeuver::maneuver ; Fixes 13 words
:?*:manouver::maneuver ; Fixes 13 words
:?*:mantain::maintain ; Fixes 14 words
:?*:manuever::maneuver ; Fixes 13 words
:?*:manuver::maneuver ; Fixes 13 words
:?*:marjorit::majorit ; Fixes 7 words
:?*:markes::marks ; Fixes 32 words
:?*:markett::market ; Fixes 49 words
:?*:marrage::marriage ; Fixes 13 words
:?*:mathamati::mathemati ; Fixes 17 words
:?*:mathmati::mathemati ; Fixes 17 words
:?*:mberan::mbran ; Fixes 26 words
:?*:mbintat::mbinat ; Fixes 18 words
:?*:mchan::mechan ; Fixes 54 words
:?*:meber::member ; Fixes 32 words
:?*:medac::medic ; Fixes 76 words
:?*:medeival::medieval ; Fixes 6 words
:?*:medevial::medieval ; Fixes 6 words
:?*:meent::ment ; Fixes 1763 words
:?*:meing::ming ; Fixes 410 words
:?*:melad::malad ; Fixes 21 words
:?*:memeber::member ; Fixes 32 words
:?*:memmor::memor ; Fixes 70 words
:?*:memt::ment ; Fixes 1763 words
:?*:menatr::mentar ; Fixes 71 words
:?*:metalic::metallic ; Fixes 9 words
:?*:mialr::milar ; Fixes 14 words
:?*:mibil::mobil ; Fixes 78 words
:?*:mileau::milieu ; Fixes 3 words
:?*:milen::millen ; Fixes 33 words
:?*:mileu::milieu ; Fixes 3 words
:?*:milirat::militar ; Fixes 54 words
:?*:millit::milit ; Fixes 85 words
:?*:millon::million ; Fixes 13 words
:?*:milta::milita ; Fixes 70 words
:?*:minatur::miniatur ; Fixes 27 words
:?*:minining::mining ; Fixes 15 words.
:?*:miscelane::miscellane ; Fixes 4 words
:?*:mision::mission ; Fixes 63 words
:?*:missabi::missibi ; Fixes 13 words
:?*:misson::mission ; Fixes 63 words
:?*:mition::mission ; Fixes 63 words
:?*:mittm::mitm ; Fixes 8 words
:?*:mitty::mittee ; Fixes 12 words
:?*:mkae::make ; Fixes 122 words
:?*:mkaing::making ; Fixes 45 words
:?*:mkea::make ; Fixes 122 words
:?*:mmorow::morrow ; Fixes 4 words
:?*:mnet::ment ; Fixes 1763 words
:?*:modle::model ; Fixes 29 words
:?*:moent::moment ; Fixes 15 words
:?*:moleclue::molecule ; Fixes 7 words
:?*:morgag::mortgag ; Fixes 18 words
:?*:mornal::normal ; Fixes 66 words 
:?*:morot::motor ; Fixes 72 words  
:?*:morow::morrow ; Fixes 4 words
:?*:mortag::mortgag ; Fixes 18 words
:?*:mostur::moistur ; Fixes 16 words
:?*:moung::mong ; Fixes 89 words
:?*:mounth::month ; Fixes 13 words
:?*:mpossa::mpossi ; Fixes 7 words
:?*:mrak::mark ; Fixes 175 words
:?*:mroe::more ; Fixes 72 words
:?*:msot::most ; Fixes 73 words
:?*:mtion::mation ; Fixes 119 words
:?*:mucuous::mucous ; Fixes 3 words
:?*:muder::murder ; Fixes 13 words
:?*:mulatat::mulat ; Fixes 110 words
:?*:munber::number ; Fixes 28 words
:?*:munites::munities ; Fixes 3 words
:?*:muscel::muscle ; Fixes 11 words
:?*:muscial::musical ; Fixes 15 words
:?*:mutiliat::mutilat ; Fixes 9 words
:?*:naisance::naissance ; Fixes 5 words
:?*:naton::nation ; Fixes 451 words but misspells Akhenaton (Early ruler of Egypt who regected old gods and replaced with sun worship, died 1358 BC).
:?*:naturely::naturally ; Fixes 6 words
:?*:naturual::natural ; Fixes 54 words
:?*:nclr::ncr ; Fixes 193 words
:?*:ndunt::ndant ; Fixes 34 words
:?*:necass::necess ; Fixes 24 words
:?*:neccesar::necessar ; Fixes 9 words
:?*:neccessar::necessar ; Fixes 9 words
:?*:necesar::necessar ; Fixes 9 words
:?*:necesser::necessar ; Fixes 9 words 
:?*:nefica::neficia ; Fixes 12 words
:?*:negociat::negotiat ; Fixes 19 words
:?*:negota::negotia ; Fixes 26 words
:?*:neice::niece ; Fixes 4 words
:?*:neigbor::neighbor ; Fixes 11 words
:?*:neigbour::neighbor ; Fixes 11 words
:?*:neize::nize ; Fixes 475 words
:?*:neolitic::neolithic ; Fixes 5 words
:?*:nerial::neral ; Fixes 103 words
:?*:neribl::nerabl ; Fixes 11 words
:?*:nessasar::necessar ; Fixes 9 words
:?*:nessec::necess ; Fixes 24 words
:?*:nght::ngth ; Jack's fixes 33 words
:?*:ngiht::night ; Fixes 103 words
:?*:ngng::nging ; Fixes 126 words
:?*:nht::nth ; Jack's fixes 769 words
:?*:niant::nant ; Fixes 147 words
:?*:niare::naire ; Fixes 30 words
:?*:nickle::nickel ; Fixes 14 words
:?*:nifiga::nifica ; Fixes 55 words
:?*:nihgt::night ; Fixes 103 words
:?*:nilog::nolog ; Fixes 223 words
:?*:nisator::niser ; Fixes 43 words
:?*:nisb::nsib ; Fixes 88 words
:?*:nistion::nisation ; Fixes 140 words
:?*:nitian::nician ; Fixes 8 words
:?*:niton::nition ; Fixes 37 words
:?*:nizator::nizer ; Fixes 44 words
:?*:niztion::nization ; Fixes 154 words
:?*:nkow::know ; Fixes 66 words, but misspells Minkowski (German mathematician)
:?*:nlcu::nclu ; Fixes 34 words
:?*:nlees::nless ; Fixes 89 words
:?*:nmae::name ; Fixes 100 words
:?*:nnst::nst ; Fixes 729 words, misspells Dennstaedtia (fern), Hoffmannsthal, (poet)
:?*:nnung::nning ; Fixes 107 words
:?*:nonom::nonym ; Fixes 40 words
:?*:nouce::nounce ; Fixes 47 words
:?*:nounch::nounc ; Fixes 54 words
:?*:nouncia::nuncia ; Fixes 47 words
:?*:nsistan::nsisten ; Fixes 17 words
:?*:nsitu::nstitu ; Fixes 87 words
:?*:nstade::nstead ; Fixes 6 words
:?*:nstatan::nstan ; Fixes 44 words
:?*:nsted::nstead ; Fixes 6 words
:?*:nstiv::nsitiv ; Fixes 62 words
:?*:ntaines::ntains ; Fixes 9 words
:?*:ntamp::ntemp ; Fixes 52 words
:?*:ntfic::ntific ; Fixes 28 words
:?*:ntifc::ntific ; Fixes 28 words
:?*:ntrui::nturi ; Fixes 21 words
:?*:nucular::nuclear ; Fixes 17 words
:?*:nuculear::nuclear ; Fixes 17 words
:?*:nuei::nui ; Fixes 37 words
:?*:nuptual::nuptial ; Fixes 7 words
:?*:nvien::nven ; Fixes 101 words
:?*:obedian::obedien ; Fixes 11 words
:?*:obelm::oblem ; Fixes 28 words
:?*:occassi::occasi ; Fixes 14 words
:?*:occasti::occasi ; Fixes 14 words
:?*:occour::occur ; Fixes 20 words
:?*:occuran::occurren ; Fixes 8 words
:?*:occurran::occurren ; Fixes 8 words
:?*:ocup::occup ; Fixes 39 words
:?*:ocurran::occurren ; Fixes 8 words
:?*:odouriferous::odoriferous ; Fixes 3 words
:?*:odourous::odorous ; Fixes 9 words
:?*:oducab::oducib ; Fixes 13 words
:?*:oeny::oney ; Fixes 83 words
:?*:oeopl::eopl ; Fixes 53 words
:?*:oeprat::operat ; Fixes 58 words
:?*:offereing::offering ; Fixes 4 words
:?*:offesi::ofessi ; Fixes 34 words
:?*:offical::official ; Fixes 24 words
:?*:offred::offered ; Fixes 4 words
:?*:ogeous::ogous ; Fixes 13 words
:?*:ogess::ogress ; Fixes 38 words
:?*:ohter::other ; Fixes 229 words
:?*:ointiment::ointment ; Fixes 10 words
:?*:olece::olesce ; Fixes 18 words
:?*:olgist::ologist ; Fixes 445 words
:?*:olision::olition ; Fixes 16 words
:?*:ollum::olum ; Fixes 69 words
:?*:olpe::ople ; Fixes 62 words
:?*:olther::other ; Fixes 229 words
:?*:omenom::omenon ; Fixes 7 words
:?*:ommision::omission ; Fixes 4 words
:?*:ommm::omm ; Fixes 606 words
:?*:omnio::omino ; Fixes 18 words
:?*:omptabl::ompatibl ; Fixes 7 words
:?*:omre::more ; Fixes 72 words
:?*:omse::onse ; Fixes 159 words
:?*:ongraph::onograph ; Fixes 31 words
:?*:onnal::onal ; Fixes 1038 words
:?*:onnsibilt::onsibilit ; Fixes 4 words
:?*:ononent::onent ; Fixes 18 words
:?*:ononym::onym ; Fixes 137 words
:?*:onsenc::onsens ; Fixes 19 words
:?*:onsern::concern ; Fixes 17 words
:?*:ontruc::onstruc ; Fixes 63 words
:?*:ontstr::onstr ; Fixes 165 words
:?*:onyic::onic ; Fixes 353 words
:?*:onymn::onym ; Fixes 137 words
:?*:oook::ook ; Fixes 427 words
:?*:oparate::operate ; Fixes 10 words
:?*:oportun::opportun ; Fixes 14 words
:?*:opperat::operat ; Fixes 58 words
:?*:oppertun::opportun ; Fixes 14 words
:?*:oppini::opini ; Fixes 12 words
:?*:opprotun::opportun ; Fixes 14 words
:?*:opth::ophth ; Fixes 47 words
:?*:ordianti::ordinati ; Fixes 21 words
:?*:orginis::organiz ; Fixes 34 words
:?*:orginiz::organiz ; Fixes 34 words
:?*:orht::orth ; Fixes 275 words
:?*:oridal::ordial ; Fixes 15 words
:?*:oridina::ordina ; Fixes 63 words
:?*:origion::origin ; Fixes 37 words
:?*:orign::origin ; Fixes 37 words
:?*:ormenc::ormanc ; Fixes 11 words
:?*:osible::osable ; Fixes 23 words
:?*:oteab::otab ; Fixes 22 words
:?*:otehr::other ; Fixes 229 words
:?*:ouevre::oeuvre ; Fixes 10 words
:?*:ouhg::ough ; Fixes 230 words
:?*:oulb::oubl ; Fixes 63 words
:?*:ountian::ountain ; Fixes 25 words
:?*:ourious::orious ; Fixes 30 words
:?*:owinf::owing ; Fixes 133 words
:?*:owrk::work ; Fixes 338 words
:?*:oxident::oxidant ; Fixes 4 words
:?*:oxigen::oxygen ; Fixes 40 words
:?*:paiti::pati ; Fixes 157 words
:?*:palce::place ; Fixes 94 words
:?*:paliament::parliament ; Fixes 11 words
:?*:papaer::paper ; Fixes 69 words
:?*:paralel::parallel ; Fixes 41 words
:?*:parellel::parallel ; Fixes 41 words
:?*:parision::parison ; Fixes 6 words
:?*:parisit::parasit ; Fixes 57 words
:?*:paritucla::particula ; Fixes 29 words
:?*:parliment::parliament ; Fixes 11 words
:?*:parment::partment ; Fixes 41 words
:?*:parralel::parallel ; Fixes 41 words
:?*:parrall::parall ; Fixes 44 words
:?*:parren::paren ; Fixes 65 words
:?*:pased::passed ; Fixes 10 words
:?*:patab::patib ; Fixes 16 words
:?*:pattent::patent ; Fixes 16 words
:?*:pbli::publi ; Fixes 67 words
:?*:pbuli::publi ; Fixes 67 words
:?*:pcial::pical ; Fixes 102 words
:?*:pcitur::pictur ; Fixes 25 words
:?*:peall::peal ; Fixes 31 words
:?*:peapl::peopl ; Fixes 38 words
:?*:pefor::perfor ; Fixes 43 words
:?*:peice::piece ; Fixes 60 words
:?*:peiti::petiti ; Fixes 34 words
:?*:pendece::pendence ; Fixes 12 words
:?*:pendendet::pendent ; Fixes 17 words
:?*:penerat::penetrat ; Fixes 19 words
:?*:penisula::peninsula ; Fixes 3 words
:?*:penninsula::peninsula ; Fixes 3 words
:?*:pennisula::peninsula ; Fixes 3 words
:?*:pensanti::pensati ; Fixes 13 words
:?*:pensinula::peninsula ; Fixes 3 words
:?*:penten::pentan ; Fixes 12 words
:?*:pention::pension ; Fixes 15 words
:?*:peopel::people ; Fixes 32 words
:?*:percepted::perceived ; Fixes 7 words
:?*:perfom::perform ; Fixes 31 words
:?*:performes::performs ; Fixes 3 words
:?*:permenan::permanen ; Fixes 17 words
:?*:perminen::permanen ; Fixes 17 words
:?*:permissab::permissib ; Fixes 9 words
:?*:peronal::personal ; Fixes 49 words
:?*:perosn::person ; Fixes 130 words
:?*:persistan::persisten ; Fixes 6 words
:?*:persud::persuad ; Fixes 20 words
:?*:pertrat::petrat ; Fixes 14 words
:?*:pertuba::perturba ; Fixes 12 words
:?*:peteti::petiti ; Fixes 34 words
:?*:petion::petition ; Fixes 11 words
:?*:petive::petitive ; Fixes 19 words
:?*:phenomenonal::phenomenal ; Fixes 11 words
:?*:phenomon::phenomen ; Fixes 21 words
:?*:phenonmen::phenomen ; Fixes 21 words
:?*:philisoph::philosoph ; Fixes 28 words
:?*:phillipi::Philippi ; Fixes 7 words
:?*:phillo::philo ; Fixes 61 words
:?*:philosph::philosoph ; Fixes 28 words
:?*:phoricial::phorical ; Fixes 6 words
:?*:phyllis::philis ; Fixes 33 words
:?*:phylosoph::philosoph ; Fixes 28 words
:?*:piant::pient ; Fixes 16 words
:?*:piblish::publish ; Fixes 17 words
:?*:pinon::pion ; Fixes 44 words
:?*:piten::peten ; Fixes 29 words
:?*:plament::plement ; Fixes 42 words
:?*:plausab::plausib ; Fixes 10 words
:?*:pld::ple ; Fixes 843 words
:?*:pleasent::pleasant ; Fixes 11 words
:?*:plesan::pleasan ; Fixes 14 words
:?*:pletetion::pletion ; Fixes 8 words
:?*:pmant::pment ; Fixes 38 words
:?*:poenis::penis ; Fixes 4 words
:?*:poepl::peopl ; Fixes 38 words
:?*:poleg::polog ; Fixes 59 words
:?*:polina::pollina ; Fixes 11 words
:?*:politican::politician ; Fixes 4 words
:?*:polti::politi ; Fixes 61 words
:?*:polut::pollut ; Fixes 20 words
:?*:pomd::pond ; Fixes 109 words
:?*:ponan::ponen ; Fixes 17 words
:?*:ponsab::ponsib ; Fixes 10 words
:?*:poportion::proportion ; Fixes 25 words
:?*:popoul::popul ; Fixes 71 words
:?*:porblem::problem ; Fixes 22 words
:?*:portad::ported ; Fixes 26 words
:?*:porv::prov ; Fixes 213 words
:?*:posat::posit ; Fixes 215 words
:?*:posess::possess ; Fixes 41 words
:?*:posion::poison ; Fixes 17 words
:?*:possab::possib ; Fixes 13 words
:?*:postion::position ; Fixes 103 words
:?*:postit::posit ; Fixes 215 words
:?*:postiv::positiv ; Fixes 36 words
:?*:potunit::portunit ; Fixes 4 words
:?*:poulat::populat ; Fixes 29 words
:?*:poverful::powerful ; Fixes 5 words
:?*:poweful::powerful ; Fixes 5 words
:?*:ppment::pment ; Fixes 38 words
:?*:pposs::ppos ; Fixes 90 words
:?*:ppub::pub ; Fixes 96 words
:?*:practial::practical ; Fixes 14 words
:?*:prait::priat ; Fixes 39 words
:?*:pratic::practic ; Fixes 42 words
:?*:precendent::precedent ; Fixes 11 words
:?*:precic::precis ; Fixes 20 words
:?*:precid::preced ; Fixes 18 words
:?*:prega::pregna ; Fixes 25 words
:?*:pregne::pregna ; Fixes 25 words
:?*:preiod::period ; Fixes 30 words
:?*:prelifer::prolifer ; Fixes 13 words
:?*:prepair::prepare ; Fixes 10 words
:?*:prerio::perio ; Fixes 46 words
:?*:presan::presen ; Fixes 90 words
:?*:presp::persp ; Fixes 33 words
:?*:pretect::protect ; Fixes 43 words
:?*:pricip::princip ; Fixes 20 words
:?*:priestood::priesthood ; Fixes 3 words
:?*:prisonn::prison ; Fixes 21 words
:?*:privale::privile ; Fixes 7 words
:?*:privele::privile ; Fixes 7 words
:?*:privelig::privileg ; Fixes 7 words
:?*:privelle::privile ; Fixes 7 words
:?*:privilag::privileg ; Fixes 7 words
:?*:priviledg::privileg ; Fixes 7 words
:?*:privledg::privileg ; Fixes 7 words
:?*:probabli::probabili ; Fixes 12 words
:?*:probal::probabl ; Fixes 9 words
:?*:procce::proce ; Fixes 49 words
:?*:proclame::proclaime ; Fixes 4 words
:?*:proffession::profession ; Fixes 33 words
:?*:progrom::program ; Fixes 46 words
:?*:prohabit::prohibit ; Fixes 17 words
:?*:prominan::prominen ; Fixes 8 words
:?*:prominate::prominent ; Fixes 4 words::prominately::prominently
:?*:proov::prov ; Fixes 213 words
:?*:propiat::priat ; Fixes 39 words
:?*:propiet::propriet ; Fixes 17 words
:?*:propmt::prompt ; Fixes 19 words
:?*:propotion::proportion ; Fixes 25 words::propotions::proportions
:?*:propper::proper ; Fixes 15 words
:?*:propro::pro ; Fixes 2311 words
:?*:prorp::propr ; Fixes 68 words
:?*:protie::protei ; Fixes 44 words
:?*:protray::portray ; Fixes 14 words
:?*:prounc::pronounc ; Fixes 24 words
:?*:provd::provid ; Fixes 21 words
:?*:provicial::provincial ; Fixes 10 words
:?*:provinicial::provincial ; Fixes 10 words
:?*:provison::provision ; Fixes 14 words
:?*:proxia::proxima ; Fixes 22 words
:?*:psect::spect ; Fixes 177 words
:?*:psoiti::positi ; Fixes 155 words
:?*:psuedo::pseudo ; Fixes 70 words
:?*:psyco::psycho ; Fixes 161 words
:?*:psyh::psych ; Fixes 192 words, but misspells gypsyhood.
:?*:ptenc::ptanc ; Fixes 9 words
:?*:ptete::pete ; Fixes 61 words
:?*:ptition::petition ; Fixes 11 words
:?*:ptogress::progress ; Fixes 24 words
:?*:ptoin::ption ; Fixes 183 words
:?*:pturd::ptured ; Fixes 6 words
:?*:pubish::publish ; Fixes 17 words
:?*:publian::publican ; Fixes 9 words
:?*:publise::publishe ; Fixes 7 words
:?*:publush::publish ; Fixes 17 words
:?*:pulare::pular ; Fixes 40 words
:?*:puler::pular ; Fixes 40 words
:?*:pulishe::publishe ; Fixes 7 words
:?*:puplish::publish ; Fixes 17 words
:?*:pursuad::persuad ; Fixes 20 words
:?*:purtun::portun ; Fixes 25 words
:?*:pususad::persuad ; Fixes 20 words
:?*:putar::puter ; Fixes 24 words
:?*:putib::putab ; Fixes 34 words
:?*:pwoer::power ; Fixes 67 words
:?*:pysch::psych ; Fixes 192 words
:?*:qtuie::quite ; Fixes 11 words
:?*:quesece::quence ; Fixes 21 words
:?*:quesion::question ; Fixes 26 words
:?*:questiom::question ; Fixes 26 words
:?*:queston::question ; Fixes 26 words
:?*:quetion::question ; Fixes 26 words
:?*:quirment::quirement ; Fixes 4 words
:?*:qush::quish ; Fixes 27 words
:?*:quti::quit ; Fixes 86 words
:?*:rabinn::rabbin ; Fixes 9 words
:?*:radiactiv::radioactiv ; Fixes 5 words
:?*:raell::reall ; Fixes 24 words
:?*:rafic::rific ; Fixes 85 words
:?*:ranie::rannie ; Fixes 8 words
:?*:ratly::rately ; Fixes 30 words
:?*:raverci::roversi ; Fixes 19 words
:?*:rcaft::rcraft ; Fixes 11 words
:?*:reaccurr::recurr ; Fixes 8 words
:?*:reaci::reachi ; Fixes 18 words
:?*:rebll::rebell ; Fixes 17 words
:?*:recide::reside ; Fixes 34 words
:?*:recqu::requ ; Fixes 96 words
:?*:recration::recreation ; Fixes 5 words
:?*:recrod::record ; Fixes 26 words
:?*:recter::rector ; Fixes 26 words
:?*:recuring::recurring ; Fixes 3 words
:?*:reedem::redeem ; Fixes 22 words
:?*:reenfo::reinfo ; Fixes 9 words
:?*:referal::referral ; Fixes 2 words
:?*:reffer::refer ; Fixes 58 words
:?*:refrer::refer ; Fixes 58 words
:?*:reigin::reign ; Fixes 25 words
:?*:reing::ring ; Fixes 1481 words
:?*:reiv::riev ; Fixes 44 words
:?*:relese::release ; Fixes 13 words
:?*:releven::relevan ; Fixes 12 words
:?*:renial::rennial ; Fixes 6 words
:?*:renno::reno ; Fixes 85 words
:?*:rentee::rantee ; Fixes 9 words
:?*:rentor::renter ; Fixes 4 words
:?*:reomm::recomm ; Fixes 31 words
:?*:repatiti::repetiti ; Fixes 10 words
:?*:repb::repub ; Fixes 23 words
:?*:repentent::repentant ; Fixes 5 words
:?*:repetant::repentant ; Fixes 5 words
:?*:repetent::repentant ; Fixes 5 words
:?*:replacab::replaceab ; Fixes 8 words
:?*:reposd::respond ; Fixes 22 words
:?*:resense::resence ; Fixes 6 words
:?*:residental::residential ; Fixes 7 words
:?*:resistab::resistib ; Fixes 10 words
:?*:resiv::ressiv ; Fixes 80 words
:?*:responc::respons ; Fixes 25 words
:?*:respondan::responden ; Fixes 11 words
:?*:restict::restrict ; Fixes 25 words
:?*:revelan::relevan ; Fixes 12 words 
:?*:reversab::reversib ; Fixes 15 words
:?*:rhitm::rithm ; Fixes 20 words
:?*:rhythem::rhythm ; Fixes 34 words
:?*:rhytm::rhythm ; Fixes 34 words
:?*:ributred::ributed ; Fixes 10 words
:?*:ridgid::rigid ; Fixes 25 words 
:?*:rieciat::reciat ; Fixes 32 words
:?*:rifing::rifying ; Fixes 31 words
:?*:rigeur::rigor ; Fixes 13 words
:?*:rigourous::rigorous ; Fixes 6 words
:?*:rilia::rillia ; Fixes 11 words
:?*:rimetal::rimental ; Fixes 9 words
:?*:rininging::ringing ; Fixes 21 words
:?*:riodal::roidal ; Fixes 14 words
:?*:ritent::rient ; Fixes 74 words
:?*:ritm::rithm ; Fixes 20 words
:?*:rixon::rison ; Fixes 39 words
:?*:rmaly::rmally ; Fixes 11 words
:?*:rmaton::rmation ; Fixes 46 words
:?*:rnign::rning ; Fixes 77 words
:?*:rocord::record ; Fixes 26 words
:?*:ropiat::ropriat ; Fixes 39 words
:?*:rowm::rown ; Fixes 85 words
:?*:roximite::roximate ; Fixes 8 words
:?*:rraige::rriage ; Fixes 26 words
:?*:rshan::rtion ; Fixes 84 words, but misspells darshan (Hinduism)
:?*:rshon::rtion ; Fixes 84 words
:?*:rshun::rtion ; Fixes 84 words
:?*:rtaure::rature ; Fixes 8 words
:?*:rtnat::rtant ; Fixes 7 words
:?*:ruming::rumming ; Fixes 5 words
:?*:ruptab::ruptib ; Fixes 11 words
:?*:rwit::writ ; Fixes 88 words
:?*:ryed::ried ; Fixes 98 words
:?*:rythim::rhythm ; Fixes 34 words
:?*:rythym::rhythm ; Fixes 34 words
:?*:saccari::sacchari ; Fixes 31 words
:?*:safte::safet ; Fixes 5 words
:?*:saidit::said it ; Fixes 0 words
:?*:saidthat::said that ; Fixes 0 words
:?*:sampel::sample ; Fixes 20 words 
:?*:santion::sanction ; Fixes 7 words
:?*:sassan::sassin ; Fixes 12 words
:?*:satelite::satellite ; Fixes 4 words
:?*:satric::satiric ; Fixes 4 words
:?*:sattelite::satellite ; Fixes 4 words
:?*:saveing::saving ; Fixes 11 words
:?*:scaleable::scalable ; Fixes 4 words
:?*:scedul::schedul ; Fixes 12 words
:?*:schedual::schedule ; Fixes 9 words
:?*:scholarstic::scholastic ; Fixes 9 words
:?*:scince::science ; Fixes 25 words, but misspells Scincella (A reptile genus of Scincidae)
:?*:scipt::script ; Fixes 113 words
:?*:scripton::scription ; Fixes 32 words
:?*:sctruct::struct ; Fixes 171 words
:?*:sdide::side ; Fixes 317 words
:?*:sdier::sider ; Fixes 74 words
:?*:seach::search ; Fixes 25 words, but misspells Taoiseach (The prime minister of the Irish Republic)
:?*:secretery::secretary ; Fixes 4 words
:?*:sedere::sidere ; Fixes 7 words
:?*:seeked::sought ; Fixes 3 words
:?*:segement::segment ; Fixes 14 words
:?*:seige::siege ; Fixes 10 words
:?*:seing::seeing ; Fixes 14 words
:?*:senqu::sequ ; Fixes 91 words
:?*:sensativ::sensitiv ; Fixes 32 words
:?*:sensur::censur ; Fixes 12 words
:?*:sentive::sentative ; Fixes 15 words
:?*:seper::separ ; Fixes 36 words
:?*:sepulchure::sepulcher ; Fixes 7 words
:?*:sepulcre::sepulcher ; Fixes 7 words
:?*:sequentually::sequently ; Fixes 4 words
:?*:serach::search ; Fixes 25 words
:?*:sercu::circu ; Fixes 168 words
:?*:sesi::sessi ; Fixes 41 words
:?*:sevic::servic ; Fixes 25 words, but misspells seviche (South American dish of raw fish)
:?*:sgin::sign ; Fixes 243 words.
:?*:shaddow::shadow ; Fixes 31 words
:?*:shco::scho ; Fixes 117 words
:?*:sheild::shield ; Fixes 13 words
:?*:siad::said ; Fixes 9 words
:?*:sibile::sible ; Fixes 137 words
:?*:siblit::sibilit ; Fixes 110 words
:?*:sicion::cision ; Fixes 22 words
:?*:sicne::since ; Fixes 22 words
:?*:sidenta::sidentia ; Fixes 9 words
:?*:signifa::significa ; Fixes 20 words
:?*:significe::significa ; Fixes 20 words
:?*:signit::signat ; Fixes 35 words
:?*:simala::simila ; Fixes 38 words
:?*:similia::simila ; Fixes 38 words
:?*:simmi::simi ; Fixes 64 words
:?*:simpt::sympt ; Fixes 15 words
:?*:sincerley::sincerely ; Fixes 2 words
:?*:sincerly::sincerely ; Fixes 2 words
:?*:sinse::since ; Fixes 22 words
:?*:sistend::sistent ; Fixes 10 words
:?*:sistion::sition ; Fixes 135 words
:?*:sitll::still ; Fixes 62 words
:?*:siton::sition ; Fixes 135 words
:?*:skelaton::skeleton ; Fixes 19 words
:?*:slowy::slowly ; Fixes 2 words
:?*:smae::same ; Fixes 19 words
:?*:smealt::smelt ; Fixes 10 words
:?*:smoe::some ; Fixes 260 words
:?*:snese::sense ; Fixes 17 words
:?*:socal::social ; Fixes 47 words
:?*:socre::score ; Fixes 34 words 
:?*:soem::some ; Fixes 260 words
:?*:sohw::show ; Fixes 79 words
:?*:soica::socia ; Fixes 115 words
:?*:sollut::solut ; Fixes 42 words
:?*:soluab::solub ; Fixes 26 words
:?*:sonent::sonant ; Fixes 20 words
:?*:sophicat::sophisticat ; Fixes 13 words
:?*:sorbsi::sorpti ; Fixes 32 words
:?*:sorbti::sorpti ; Fixes 32 words
:?*:sosica::socia ; Fixes 115 words
:?*:sotry::story ; Fixes 23 words
:?*:soudn::sound ; Fixes 51 words
:?*:soverign::sovereign ; Fixes 10 words
:?*:specal::special ; Fixes 24 words
:?*:specfic::specific ; Fixes 20 words
:?*:specialliz::specializ ; Fixes 15 words
:?*:specifiy::specify ; Fixes 8 words
:?*:spectaular::spectacular ; Fixes 5 words
:?*:spectum::spectrum ; Fixes 4 words
:?*:speices::species ; Fixes 8 words
:?*:speling::spelling ; Fixes 9 words
:?*:spesial::special ; Fixes 48 words
:?*:spiria::spira ; Fixes 70 words
:?*:spoac::spac ; Fixes 83 words
:?*:sponib::sponsib ; Fixes 10 words
:?*:sponser::sponsor ; Fixes 12 words
:?*:spred::spread ; Fixes 37 words
:?*:spririt::spirit ; Fixes 70 words
:?*:spritual::spiritual ; Fixes 31 words, but misspells spritual (A light spar that crosses a fore-and-aft sail diagonally) 
:?*:spyc::psyc ; Fixes 192 words, but misspells spycatcher (secret spy stuff) 
:?*:sqaur::squar ; Fixes 22 words
:?*:ssanger::ssenger  ; Fixes 6 words
:?*:ssese::ssesse ; Fixes 17 words
:?*:ssition::sition ; Fixes 135 words
:?*:sssurect::surrect ; Fixes 15 words
:?*:ssurect::surrect ; Fixes 15 words
:?*:stablise::stabilise ; Fixes 10 words
:?*:staleld::stalled ; Fixes 6 words
:?*:stancial::stantial ; Fixes 40 words
:?*:stange::strange ; Fixes 12 words
:?*:starna::sterna ; Fixes 13 words
:?*:starteg::strateg ; Fixes 21 words
:?*:stateman::statesman ; Fixes 6 words
:?*:statment::statement ; Fixes 14 words
:?*:steriod::steroid ; Fixes 16 words
:?*:sterotype::stereotype ; Fixes 5 words
:?*:stingent::stringent ; Fixes 9 words
:?*:stiring::stirring ; Fixes 4 words
:?*:stirrs::stirs ; Fixes 2 words
:?*:stituan::stituen ; Fixes 7 words
:?*:stnad::stand ; Fixes 119 words
:?*:stoin::stion ; Fixes 53 words, but misspells histoincompatibility.
:?*:stong::strong ; Fixes 22 words
:?*:stradeg::strateg ; Fixes 21 words
:?*:stratagic::strategic ; Fixes 5 words
:?*:streem::stream ; Fixes 45 words
:?*:strengh::strength ; Fixes 15 words
:?*:structual::structural ; Fixes 12 words
:?*:sttr::str ; Fixes 2295 words
:?*:stuct::struct ; Fixes 171 words
:?*:studdy::study ; Fixes 8 words
:?*:studing::studying ; Fixes 4 words
:?*:sturctur::structur ; Fixes 39 words
:?*:stutionaliz::stitutionaliz ; Fixes 16 words
:?*:substancia::substantia ; Fixes 55 words
:?*:succesful::successful ; Fixes 6 words
:?*:succsess::success ; Fixes 19 words
:?*:sueing::suing ; Fixes 9 words
:?*:suffc::suffic ; Fixes 14 words
:?*:sufferr::suffer ; Fixes 19 words
:?*:suffician::sufficien ; Fixes 10 words
:?*:superintendan::superintenden ; Fixes 6 words
:?*:suph::soph ; Fixes 153 words
:?*:supos::suppos ; Fixes 30 words
:?*:suppoed::supposed ; Fixes 3 words
:?*:supposs::suppos ; Fixes 30 words
:?*:suppy::supply ; Fixes 8 words
:?*:suprass::surpass ; Fixes 14 words
:?*:supress::suppress ; Fixes 31 words
:?*:supris::surpris ; Fixes 16 words
:?*:supriz::surpris ; Fixes 16 words
:?*:surect::surrect ; Fixes 15 words
:?*:surence::surance ; Fixes 12 words
:?*:surfce::surface ; Fixes 15 words
:?*:surle::surel ; Fixes 11 words
:?*:suro::surro ; Fixes 13 words
:?*:surpress::suppress ; Fixes 31 words
:?*:surpriz::surpris ; Fixes 16 words
:?*:susept::suscept ; Fixes 21 words
:?*:svae::save ; Fixes 15 words
:?*:swepth::swept ; Fixes 7 words
:?*:symetr::symmetr ; Fixes 36 words
:?*:symettr::symmetr ; Fixes 36 words
:?*:symmetral::symmetric ; Fixes 16 words
:?*:syncro::synchro ; Fixes 72 words
:?*:sypmtom::symptom ; Fixes 11 words
:?*:sysmatic::systematic ; Fixes 11 words
:?*:sytem::system ; Fixes 62 words
:?*:sytl::styl ; Fixes 100 words
:?*:tagan::tagon ; Fixes 40 words
:?*:tahn::than ; Fixes 135 words
:?*:taht::that ; Fixes 26 words
:?*:tailled::tailed ; Fixes 16 words.
:?*:taimina::tamina ; Fixes 26 words
:?*:tainence::tenance ; Fixes 12 words
:?*:taion::tation ; Fixes 490 words
:?*:tait::trait ; Fixes 32 words
:?*:tamt::tant ; Fixes 330 words
:?*:tanous::taneous ; Fixes 29 words
:?*:taral::tural ; Fixes 140 words
:?*:tarey::tary ; Fixes 86 words
:?*:tatch::tach ; Fixes 105 words
:?*:tatn::tant ; Fixes 530 words
:?*:taxan::taxon ; Fixes 10 words
:?*:techic::technic ; Fixes 39 words
:?*:techini::techni ; Fixes 44 words
:?*:techt::tect ; Fixes 102 words
:?*:tecn::techn ; Fixes 87 words
:?*:telpho::telepho ; Fixes 23 words
:?*:tempalt::templat ; Fixes 14 words
:?*:tempara::tempera ; Fixes 22 words
:?*:temperar::temporar ; Fixes 11 words
:?*:tempoa::tempora ; Fixes 35 words
:?*:temporaneus::temporaneous ; Fixes 6 words
:?*:tendac::tendenc ; Fixes 7 words
:?*:tendor::tender ; Fixes 54 words
:?*:tepmor::tempor ; Fixes 73 words
:?*:teriod::teroid ; Fixes 21 words
:?*:terranian::terranean ; Fixes 4 words
:?*:terrestial::terrestrial ; Fixes 9 words
:?*:terrior::territor ; Fixes 28 words
:?*:territorist::terrorist ; Fixes 11 words
:?*:terroist::terrorist ; Fixes 11 words
:?*:tghe::the ; Fixes 2176 words
:?*:tghi::thi ; Fixes 827 words
:?*:thakn::thank ; Fixes 19 words 
:?*:thaph::taph ; Fixes 60 words
:?*:theather::theater ; Fixes 7 words
:?*:theese::these ; Fixes 13 words
:?*:thgat::that ; Fixes 26 words
:?*:thiun::thin ; Fixes 212 words
:?*:thnig::thing ; Fixes 103 words
:?*:threatn::threaten ; Fixes 10 words
:?*:thsoe::those ; Fixes 8 words
:?*:thyat::that ; Fixes 26 words
:?*:tiait::tiat ; Fixes 139 words
:?*:tiblit::tibilit ; Fixes 75 words
:?*:tibut::tribut ; Fixes 92 words
:?*:ticeing::ticing ; Fixes 9 words
:?*:ticial::tical ; Fixes 863 words
:?*:ticio::titio ; Fixes 68 words
:?*:ticlular::ticular ; Fixes 36 words
:?*:tiction::tinction ; Fixes 8 words
:?*:tiget::tiger ; Fixes 11 words
:?*:tihkn::think ; Fixes 43 words
:?*:tihs::this ; Fixes 57 words
:?*:tiion::tion ; Fixes 7052 words
:?*:tingish::tinguish ; Fixes 38 words
:?*:tioge::toge ; Fixes 74 words
:?*:tionnab::tionab ; Fixes 42 words
:?*:tionnal::tional ; Fixes 713 words
:?*:tionne::tione ; Fixes 108 words
:?*:tionni::tioni ; Fixes 265 words
:?*:tiosn::tion ; Fixes 7055 words
:?*:tisment::tisement ; Fixes 4 words
:?*:titid::titud ; Fixes 88 words
:?*:titity::tity ; Fixes 14 words
:?*:titui::tituti ; Fixes 83 words
:?*:tiviat::tivat ; Fixes 100 words
:?*:tje::the ; Fixes 2176 words, but misspells Ondaatje (Canadian writer (born in Sri Lanka in 1943)) 
:?*:tjhe::the ; Fixes 2176 words
:?*:tkae::take ; Fixes 83 words
:?*:tkaing::taking ; Fixes 23 words
:?*:tlak::talk ; Fixes 74 words
:?*:tlied::tled ; Fixes 18 words
:?*:tlme::tleme ; Fixes 21 words
:?*:tlye::tyle ; Fixes 81 words
:?*:tned::nted ; Fixes 288 words
:?*:tofy::tify ; Fixes 73 words
:?*:togani::tagoni ; Fixes 25 words
:?*:toghether::together ; Fixes 4 words
:?*:toleren::toleran ; Fixes 11 words
:?*:tority::torily ; Fixes 15 words
:?*:touble::trouble ; Fixes 25 words
:?*:tounge::tongue ; Fixes 15 words
:?*:tourch::torch ; Fixes 20 words
:?*:toword::toward ; Fixes 5 words
:?*:towrad::toward ; Fixes 5 words
:?*:tradion::tradition ; Fixes 19 words
:?*:tradtion::tradition ; Fixes 19 words
:?*:tranf::transf ; Fixes 72 words
:?*:transmissab::transmissib ; Fixes 5 words
:?*:tribusion::tribution ; Fixes 20 words
:?*:triger::trigger ; Fixes 10 words
:?*:tritian::trician ; Fixes 27 words
:?*:tritut::tribut ; Fixes 92 words
:?*:troling::trolling ; Fixes 8 words
:?*:troverci::troversi ; Fixes 19 words
:?*:trubution::tribution ; Fixes 20 words
:?*:tstion::tation ; Fixes 490 words
:?*:ttele::ttle ; Fixes 237 words
:?*:tuara::taura ; Fixes 12 words
:?*:tudonal::tudinal ; Fixes 12 words
:?*:tuer::teur ; Fixes 53 words
:?*:twpo::two ; Fixes 92 words
:?*:tyfull::tiful ; Fixes 20 words
:?*:tyha::tha ; Fixes 512 words
:?*:udner::under ; Fixes 803 words
:?*:udnet::udent ; Fixes 23 words
:?*:ugth::ught ; Jack's fixes 146 words
:?*:uitious::uitous ; Fixes 15 words
:?*:ulaton::ulation ; Fixes 192 words
:?*:umetal::umental ; Fixes 27 words
:?*:understoon::understood ; Fixes 4 words
:?*:untion::unction ; Fixes 79 words
:?*:unviers::univers ; Fixes 26 words
:?*:uoul::oul ; Fixes 207 words
:?*:uraunt::urant ; Fixes 34 words
:?*:uredd::ured ; Fixes 196 words
:?*:urgan::urgen ; Fixes 21 words
:?*:urveyer::urveyor ; Fixes 4 words
:?*:useage::usage ; Fixes 9 words
:?*:useing::using ; Fixes 78 words
:?*:usuab::usab ; Fixes 31 words
:?*:ususal::usual ; Fixes 7 words
:?*:utrab::urab ; Fixes 138 words
:?*:vacative::vocative ; Fixes 12 words
:?*:valant::valent ; Fixes 31 words
:?*:valubl::valuabl ; Fixes 7 words
:?*:valueabl::valuabl ; Fixes 7 words
:?*:varation::variation ; Fixes 5 words
:?*:varien::varian ; Fixes 17 words
:?*:varing::varying ; Fixes 5 words
:?*:varous::various ; Fixes 3 words
:?*:vegat::veget ; Fixes 31 words
:?*:vegit::veget ; Fixes 31 words
:?*:vegt::veget ; Fixes 31 words
:?*:veinen::venien ; Fixes 19 words
:?*:veiw::view ; Fixes 52 words
:?*:velant::valent ; Fixes 31 words
:?*:velent::valent ; Fixes 31 words
:?*:venem::venom ; Fixes 15 words
:?*:vereal::veral ; Fixes 20 words
:?*:verison::version ; Fixes 52 words
:?*:vertibrat::vertebrat ; Fixes 6 words
:?*:vertion::version ; Fixes 52 words
:?*:vetat::vitat ; Fixes 27 words
:?*:veyr::very ; Fixes 42 words
:?*:vigeur::vigor ; Fixes 26 words
:?*:vigilen::vigilan ; Fixes 13 words
:?*:visiosn::vision ; Fixes 51 words
:?*:vison::vision ; Fixes 51 words
:?*:visting::visiting ; Fixes 3 words
:?*:vivous::vious ; Fixes 28 words
:?*:vlalent::valent ; Fixes 31 words
:?*:vment::vement ; Fixes 26 words
:?*:voiu::viou ; Fixes 45 words 
:?*:volont::volunt ; Fixes 26 words
:?*:volount::volunt ; Fixes 26 words
:?*:volumn::volum ; Fixes 13 words
:?*:volvment::volvement ; Fixes 6 words
:?*:vrey::very ; Fixes 42 words
:?*:vyer::very ; Fixes 42 words
:?*:vyre::very ; Fixes 42 words
:?*:waer::wear ; Fixes 99 words
:?*:waht::what ; Fixes 34 words
:?*:warrent::warrant ; Fixes 24 words
:?*:wehn::when ; Fixes 6 words
:?*:weildl::wield ; Fixes 15 words
:?*:werre::were ; Fixes 31 words
:?*:whant::want ; Fixes 20 words
:?*:wherre::where ; Fixes 27 words
:?*:whta::what ; Fixes 34 words
:?*:wief::wife ; Fixes 28 words
:?*:wieldl::wield ; Fixes 15 words
:?*:wierd::weird ; Fixes 16 words
:?*:wiew::view ; Fixes 52 words
:?*:willk::will ; Fixes 64 words
:?*:windoes::windows ; Fixes 5 words
:?*:wirt::writ ; Fixes 88 words
:?*:witten::written ; Fixes 9 words
:?*:wiull::will ; Fixes 64 words
:?*:wnat::want ; Fixes 20 words
:?*:woh::who ; Fixes 92 words
:?*:wokr::work ; Fixes 338 words
:?*:worls::world ; Fixes 31 words
:?*:wriet::write ; Fixes 48 words
:?*:wrighter::writer ; Fixes 31 words
:?*:writen::written ; Fixes 9 words
:?*:writting::writing ; Fixes 18 words
:?*:wrod::word ; Fixes 92 words
:?*:wrok::work ; Fixes 338 words
:?*:wtih::with ; Fixes 56 words
:?*:wupp::supp ; Fixes 168 words
:?*:yaer::year ; Fixes 24 words
:?*:yearm::year ; Fixes 24 words
:?*:yoiu::you ; Fixes 51 words
:?*:ythim::ythm ; Fixes 38 words
:?*:ytou::you ; Fixes 51 words
:?*:yuo::you ; Fixes 51 words
:?*:zyne::zine ; Fixes 89 words
:?*C:Amercia::America ; Fixes 28 words, Case sensitive to not misspell amerciable (Of a crime or misdemeanor) 
:?*C:bouy::buoy ; Fixes 13 words.  Case-sensitive to not misspell Bouyie (a branch of Tai language).
:?*C:comt::cont ; Fixes 587 words.  Misspells vicomte (French nobleman), Case sensitive so not misspell Comte (founder of Positivism and type of cheese)
:?*C:doimg::doing ; Fixes 21 words but might be a variable name(??)
:?*C:elicid::elicit ; Fixes 26 words, :C: so not to misspell Lelicidae (snail).
:?*C:elpa::epla ; Fixes 92 words.  Case sensitive to not misspell CELPA.
:?*C:manan::manen ; Fixes 27 words.  Case sensitive, so not to misspell Manannan (Celtic god of the sea; son of Ler)
:?*C:mnt::ment ; Fixes 1763 words.  Case-sensitive, to not misspell TMNT (Teenage Mutant Ninja Turtles)
:?*C:moust::mous ; Fixes 445 words, Case-sensitive to not Mousterian (archaeological culture, Neanderthal, before 70,000â€“32,000 BC)
:?*C:oppen::open ; Fixes 91 words.  Case-sensitive so not to misspell "Oppenheimer."
:?*C:origen::origin ; Fixes 37 words, Case sensitive to not misspell Origen (Greek philosopher and theologian).
:?*C:pulic::public ; Fixes 50 words, Case-sensitive to not misspell Pulicaria (Genus of temperate Old World herbs: fleabane)
:?*C:sigin::sign ; Fixes 243 words. Case-sensitive to not misspell SIGINT "Info from electronics telemetry intel."
:?*C:tehr::ther ; Fixes 921 words. Case sesnsitive to not misspell Tehran (capital and largest city of Iran).
:?*C:tempra::tempora ; Fixes 35 words. Case sensitive to not misspell Tempra (type of medicine).
:?:'nt::n't ; Fixes 24 words
:?:, btu::, but ; Not just replacing "btu", as that is a unit of heat.
:?:; btu::; but
:?:;ll::'ll
:?:;re::'re
:?:;s::'s
:?:;ve::'ve
:?:Spet::Sept ; Fixes 2 words 
:?:abely::ably ; Fixes 568 words
:?:abley::ably ; Fixes 568 words
:?:acn::can ; Fixes 64 words
:?:addres::address ; Fixes 4 words
:?:adresing::addressing ; Fixes 3 words
:?:aelly::eally ; Fixes 23 words
:?:aindre::ained ; Fixes 81 words
:?:ainity::ainty ; Fixes 4 words
:?:alekd::alked ; Fixes 16 words
:?:alowing::allowing ; Fixes 8 words
:?:alyl::ally ; Fixes 2436 words
:?:amde::made ; Fixes 6 words
:?:ancestory::ancestry
:?:ancles::acles ; Fixes 21 words
:?:andd::and ; Fixes 251 words
:?:anim::anism ; Fixes 123 words, but misspells minyanim (The quorum required by Jewish law to be present for public worship)
:?:aotrs::ators ; Fixes 414 words
:?:appearred::appeared ; Fixes 3 words
:?:artice::article ; Fixes 5 words
:?:aticly::atically ; Fixes 113 words
:?:ativs::atives ; Fixes 63 words
:?:atley::ately ; Fixes 162 words, but misspells Wheatley (a fictional artificial intelligence from the Portal franchise)
:?:atn::ant ; Fixes 506 words
:?:attemp::attempt ; Fixes 2 words
:?:aunchs::aunches ; Fixes 9 words
:?:autor::author ; Fixes 2 words
:?:ayd::ady ; Fixes 24 words
:?:aywa::away ; Fixes 24 words
:?:bilites::bilities ; Fixes 487 words
:?:bilties::bilities ; Fixes 487 words
:?:bilty::bility ; Fixes 915 words
:?:blility::bility ; Fixes 915 words
:?:blities::bilities ; Fixes 487 words
:?:blity::bility ; Fixes 915 words
:?:blly::bly ; Fixes 735 words
:?:boared::board
:?:borke::broke ; Fixes 5 words
:?:bthe::b the
:?:busines::business ; Fixes 3 words
:?:busineses::businesses ; Fixes 2 words
:?:bve::be ; Fixes 127 words
:?:caht::chat ; Fixes 8 words
:?:certainity::certainty ; Fixes 2 words
:?:certaintly::certainly ; Fixes 3 words
:?:cialy::cially ; Fixes 39 words
:?:cisly::cisely ; Fixes 4 words
:?:claimes::claims ; Fixes 10 words
:?:claming::claiming ; Fixes 9 words
:?:clas::class ; Fixes 8 words
:?:clud::clude ; Fixes 6 words
:?:comit::commit ; Fixes 3 words
:?:comming::coming ; Fixes 14 words
:?:commiting::committing ; Fixes 3 words
:?:committe::committee ; Fixes 2 words
:?:compability::compatibility ; Fixes 5 words
:?:competely::completely ; Fixes 3 words
:?:controll::control ; Fixes 3 words
:?:controlls::controls ; Fixes 3 words
:?:criticists::critics ; Fixes 2 words
:?:cthe::c the
:?:cticly::ctically ; Fixes 23 words
:?:ctino::ction ; Fixes 226 words
:?:ctoty::ctory ; Fixes 23 words
:?:cually::cularly ; Fixes 38 words
:?:cuarly::cularly ; Fixes 38 words
:?:cularily::cularly ; Fixes 38 words
:?:culem::culum ; Fixes 19 words
:?:currenly::currently ; Fixes 5 words
:?:decidely::decidedly ; Fixes 2 words
:?:develope::develop ; Fixes 5 words
:?:developes::develops ; Fixes 5 words
:?:dfull::dful ; Fixes 14 words
:?:difere::differe ; Fixes 41 words
:?:disctinct::distinct ; Fixes 18 words
:?:dng::ding ; Fixes 618 words
:?:doens::does ; Fixes 23 words
:?:doese::does ; Fixes 23 words
:?:dreasm::dreams ; Fixes 2 words
:?:dtae::date ; Fixes 59 words
:?:dthe::d the
:?:eamil::email ; Fixes 6 words
:?:eath::each 
:?:ecclectic::eclectic ; Fixes 6 words
:?:eclisp::eclips ; Fixes 6 words
:?:edely::edly ; Fixes 674 words
:?:efel::feel ; Fixes 8 words
:?:efort::effort ; Fixes 8 words
:?:efull::eful ; Fixes 74 words
:?:efulls::efuls ; Fixes 18 words
:?:ehre::here ; Fixes 49 words
:?:elyl::ely ; Fixes 1076 words
:?:encs::ences ; Fixes 301 words
:?:equiped::equipped ; Fixes 4 words
:?:eraly::erally ; Fixes 26 words
:?:essess::esses ; Fixes 200 words
:?:establising::establishing ; Fixes 4 words
:?:examinated::examined ; Fixes 3 words
:?:ferrs::fers ; Fixes 72 words
:?:ficaly::fically ; Fixes 20 words
:?:fiel::file ; Fixes 9 words
:?:finit::finite ; Fixes 6 words
:?:finitly::finitely ; Fixes 4 words
:?:forceing::forcing ; Fixes 6 words
:?:frmo::from ; Fixes 3 words
:?:frp,::from ; Fixes 3 words
:?:fthe::f the
:?:fuly::fully ; Fixes 191 words
:?:gardes::gards ; Fixes 5 words
:?:getted::geted ; Fixes 8 words
:?:gettin::getting ; Fixes 4 words
:?:gfulls::gfuls ; Fixes 4 words
:?:ginaly::ginally ; Fixes 8 words
:?:giory::gory ; Fixes 7 words
:?:glases::glasses ; Fixes 11 words
:?:gracefull::graceful ; Fixes 3 words
:?:gratefull::grateful ; Fixes 3 words
:?:gred::greed ; Fixes 6 words
:?:gthe::g the
:?:hace::hare ; Fixes 9 words
:?:herad::heard ; Fixes 5 words
:?:herefor::herefore ; Fixes 2 words
:?:hfull::hful ; Fixes 30 words
:?:hge::he ; Fixes 147 words
:?:higns::hings ; Fixes 79 words
:?:higsn::hings ; Fixes 79 words
:?:hsa::has ; Fixes 62 words
:?:hsi::his ; Fixes 59 words
:?:hte::the ; Fixes 44 words
:?:hthe::h the
:?:iaing::iating ; Fixes 84 words
:?:ialy::ially ; Fixes 244 words, but misspells bialy (Flat crusty-bottomed onion roll) 
:?:iatly::iately ; Fixes 12 words
:?:iblilty::ibility ; Fixes 168 words
:?:icaly::ically ; Fixes 1432 words
:?:icm::ism ; Fixes 1075 words
:?:icms::isms ; Fixes 717 words
:?:idty::dity ; Fixes 67 words
:?:ienty::iently ; Fixes 36 words
:?:ign::ing ; Fixes 11384 words, but misspells a bunch (which are nullified above)
:?:ikn::ink ; Fixes 66 words
:?:ilarily::ilarly ; Fixes 5 words
:?:ilny::inly ; Fixes 18 words
:?:inm::in 
:?:iosn::ions ; Fixes 3055 words
:?:isio::ision ; Fixes 27 words
:?:itino::ition ; Fixes 113 words
:?:itiy::ity ; Fixes 1890 words
:?:itoy::itory ; Fixes 23 words
:?:itr::it ; Fixes 366 words, but misspells Savitr (Important Hindu god) 
:?:ityes::ities ; Fixes 1347 words
:?:ivites::ivities ; Fixes 73 words
:?:kc::ck ; Fixes 610 words.  Misspells kc (thousand per second).
:?:kfulls::kfuls ; Fixes 7 words
:?:kn::nk ; Fixes 168 words
:?:kthe::k the
:?:l;y::ly ; Fixes 10464 words
:?:laly::ally ; Fixes 2436 words
:?:letness::leteness ; Fixes 5 words
:?:lfull::lful ; Fixes 13 words
:?:lieing::lying ; Fixes 46 words
:?:lighly::lightly ; Fixes 3 words
:?:ligy::lify ; ixes 15 words
:?:likey::likely ; Fixes 4 words
:?:lility::ility ; Fixes 956 words
:?:llete::lette ; Fixes 17 words
:?:lsit::list ; Fixes 244 words
:?:lthe::l the
:?:lwats::lways ; Fixes 6 words
:?:lyu::ly ; Fixes 9123 words
:?:maked::marked ; Fixes 15 words
:?:maticas::matics ; Fixes 26 words
:?:metn::ment ; Fixes 587 words
:?:metns::ments ; Fixes 577 words
:?:miantly::minately ; Fixes 6 words
:?:mibly::mably ; Fixes 16 words
:?:miliary::military ; Fixes 4 words, but misspells miliary ()
:?:morphysis::morphosis ; Fixes 4 words
:?:motted::moted ; Fixes 5 words
:?:mpley::mply ; Fixes 13 words
:?:mpyl::mply ; Fixes 13 words
:?:mthe::m the
:?:n;t::n't
:?:narys::naries ; Fixes 47 words
:?:natley::nately ; Fixes 42 words
:?:natly::nately ; Fixes 42 words
:?:ndacies::ndances ; Fixes 8 words
:?:nfull::nful ; Fixes 36 words
:?:nfulls::nfuls ; Fixes 17 words
:?:ngment::ngement ; Fixes 18 words
:?:nicly::nically ; Fixes 136 words
:?:nig::ing ; Fixes 11414 words.  Misspells pfennig (100 pfennigs formerly equaled 1 DeutscheÂ Mark in Germany).
:?:nision::nisation ; Fixes 93 words
:?:nnally::nally ; Fixes 249 words
:?:nnology::nology ; Fixes 43 words
:?:ns't::sn't ; Fixes 4 words
:?:nsly::nsely ; Fixes 6 words
:?:nsof::ns of
:?:nsur::nsure ; Fixes 10 words
:?:ntay::ntary ; Fixes 34 words
:?:nyed::nied ; Fixes 15 words
:?:oachs::oaches ; Fixes 13 words
:?:occured::occurred ; Fixes 3 words
:?:occurr::occur ; Fixes 3 words
:?:olgy::ology ; Fixes 316 words
:?:omst::most ; Fixes 39 words
:?:onaly::onally ; Fixes 174 words
:?:onw::one ; Fixes 341 words
:?:otaly::otally ; Fixes 6 words
:?:otherw::others ; Fixes 16 words
:?:otino::otion ; Fixes 12 words
:?:otu::out ; Fixes 97 words
:?:ougly::oughly ; Fixes 3 words
:?:ouldent::ouldn't ; Fixes 3 words
:?:ouldnt::ouldn't ; Fixes 3 words
:?:ourary::orary ; Fixes 6 words
:?:paide::paid ; Fixes 7 words
:?:pich::pitch ; Fixes 3 words
:?:pleatly::pletely ; Fixes 4 words
:?:pletly::pletely ; Fixes 4 words
:?:polical::political ; Fixes 7 words
:?:proces::process ; Fixes 3 words
:?:proprietory::proprietary ; Fixes 2 words
:?:pthe::p the
:?:publis::publics ; Fixes 2 words
:?:puertorrican::Puerto Rican ; Fixes 2 words
:?:quater::quarter ; Fixes 4 words
:?:quaters::quarters ; Fixes 4 words
:?:querd::quered ; Fixes 5 words
:?:raly::rally ; Fixes 120 words
:?:rarry::rary ; Fixes 23 words
:?:realy::really ; Fixes 12 words
:?:receeded::receded ; Fixes 2 words
:?:reched::reached ; Fixes 6 words
:?:reciding::residing ; Fixes 2 words
:?:reday::ready ; Fixes 7 words
:?:resed::ressed ; Fixes 50 words
:?:resing::ressing ; Fixes 40 words
:?:returnd::returned ; Fixes 2 words
:?:riey::riety ; Fixes 8 words
:?:rithy::rity ; Fixes 120 words
:?:ritiers::rities ; Fixes 105 words
:?:rthe::r the
:?:ruley::ruly ; Fixes 4 words
:?:ryied::ried ; Fixes 70 words
:?:saccharid::saccharide ; Fixes 8 words
:?:safty::safety ; Fixes 2 words
:?:sasy::says ; Fixes 12 words
:?:saught::sought ; Fixes 3 words
:?:schol::school ; Fixes 5 words
:?:scoll::scroll ; Fixes 2 words
:?:seses::sesses ; Fixes 8 words
:?:sfull::sful ; Fixes 7 words
:?:sfuly::sfully ; Fixes 5 words
:?:sfulyl::sfully ; Fixes 5 words
:?:shiping::shipping ; Fixes 8 words
:?:shorly::shortly ; Fixes 2 words
:?:siary::sary ; Fixes 16 words
:?:sicaly::sically ; Fixes 24 words
:?:sice::sive ; Fixes 166 words, but misspells sice (The number six at dice)
:?:sicly::sically ; Fixes 24 words
:?:smoothe::smooth ; Fixes 2 words
:?:sorce::source ; Fixes 5 words
:?:specif::specify ; Fixes 4 words
:?:ssfull::ssful ; Fixes 7 words
:?:ssully::ssfully ; Fixes 5 words
:?:stanly::stantly ; Fixes 8 words
:?:sthe::s the
:?:stino::stion ; Fixes 14 words
:?:storicians::storians ; Fixes 4 words
:?:stpo::stop ; Fixes 8 words
:?:strat::start ; Fixes 5 words
:?:struced::structed ; Fixes 11 words
:?:stuls::sults ; Fixes 4 words
:?:sucesfuly::successfully ; Fixes 2 words
:?:syas::says ; Fixes 12 words, but misspells Vaisyas (A member of the mercantile and professional Hindu caste.) 
:?:t eh::the ; Fixes 44 words ; Made case sensitive for 'at EH.'
:?:targetting::targeting ; Fixes 3 words
:?:teh::the ; Fixes 44 words
:?:tempory::temporary ; Fixes 3 words
:?:teraly::terally ; Fixes 13 words
:?:tfull::tful ; Fixes 64 words
:?:theh::the ; Fixes 44 words
:?:thge::the ; Fixes 44 words
:?:thh::th ; Fixes 408 words
:?:thn::then ; Fixes 11 words
:?:thne::then ; Fixes 11 words
:?:throught::through ; Fixes 3 words
:?:tht::th ; Fixes 408 words
:?:thw::the ; Fixes 44 words
:?:thyness::thiness ; Fixes 32 words
:?:tialy::tially ; Fixes 57 words
:?:tiem::time ; Fixes 44 words
:?:timne::time ; Fixes 44 words
:?:tionar::tionary ; Fixes 68 words
:?:tooes::toos ; Fixes 4 words
:?:topry::tory ; Fixes 317 words
:?:toreis::tories ; Fixes 62 words
:?:toyr::tory ; Fixes 317 words
:?:traing::traying ; Fixes 4 words
:?:tricly::trically ; Fixes 72 words
:?:tricty::tricity ; Fixes 13 words
:?:truely::truly ; Fixes 2 words
:?:tust::trust ; Fixes 7 words
:?:twon::town ; Fixes 32 words
:?:tyo::to ; Fixes 185 words
:?:typicaly::typically ; Fixes 9 words
:?:ualy::ually ; Fixes 72 words
:?:uarly::ularly ; Fixes 66 words
:?:ularily::ularly ; Fixes 66 words
:?:ultimely::ultimately ; Fixes 2 words
:?:uraly::urally ; Fixes 44 words
:?:urchs::urches ; Fixes 4 words
:?:urnk::runk ; Fixes 8 words
:?:usefull::useful ; Fixes 2 words
:?:utino::ution ; Fixes 55 words
:?:veill::veil ; Fixes 3 words
:?:verd::vered ; Fixes 39 words
:?:videntally::vidently ; Fixes 3 words
:?:vly::vely ; Fixes 547 words
:?:wass::was ; Fixes 13 words
:?:wasy::ways ; Fixes 106 words
:?:weas::was ; Fixes 13 words
:?:weath::wealth ; Fixes 3 words
:?:wifes::wives ; Fixes 7 words
:?:wille::will ; Fixes 10 words
:?:willingless::willingness ; Fixes 2 words
:?:wordly::worldly ; Fixes 3 words
:?:wroet::wrote ; Fixes 7 words
:?:wthe::w the
:?:wya::way ; Fixes 113 words
:?:wyas::ways ; Fixes 106 words
:?:xthe::x the
:?:yng::ying ; Fixes 514 words
:?:ywat::yway ; Fixes 6 words
:?C:hc::ch ; Fixes 446 words ; :C: so not to break THC or LHC
:?C:itn::ith ; Fixes 70 words, Case sensitive, to not misspell ITN (Independent Television News) 
:C:ASS::ADD ; Case-sensitive to fix acronym, but not word.
:C:may of::may have


;------------------------------------------------------------------------------
; Accented English words, from, amongst others,
; http://en.wikipedia.org/wiki/List_of_English_words_with_diacritics
; Most of the definitions are from https://www.easydefine.com/ or from the WordWeb application.
;------------------------------------------------------------------------------
::aesop::Æsop ; noun Greek author of fables (circa 620-560 BC)
::a bas::à bas ; French: Down with -- To the bottom.  A type of clothing.
::a la::à la ; In the manner of...
::ancien regime::Ancien Régime ; noun a political and social system that no longer governs (especially the system that existed in France before the French Revolution)
:*:angstrom::Ångström ; noun a metric unit of length equal to one ten billionth of a meter (or 0.0001 micron); used to specify wavelengths of electromagnetic radiation
:*:anime::animé ; noun any of various resins or oleoresins; a hard copal derived from an African tree
::ao dai::ào dái  ; noun the traditional dress of Vietnamese women consisting of a tunic with long sleeves and panels front and back; the tunic is worn over trousers
:*:apertif::apértif ; noun an alcoholic drink that is taken as an appetizer before a meal
:*:applique::appliqué ; noun a decorative design made of one material sewn over another; verb sew on as a decoration
::apres::après ; French:  Too late.  After the event.
::arete::arête ; noun a sharp narrow ridge found in rugged mountains
::attache::attaché ; noun a specialist assigned to the staff of a diplomatic mission; a shallow and rectangular briefcase
::auto-da-fe::auto-da-fé ; noun the burning to death of heretics (as during the Spanish Inquisition)
::belle epoque::belle époque ; French: Fine period.   noun the period of settled and comfortable life preceding World War I
::bete noire::bête noire ; noun a detested person
::betise::bêtise ; noun a stupid mistake
::Bjorn::Bjørn ; An old norse name.  Means "Bear."
::blase::blasé ; adj. nonchalantly unconcerned; uninterested because of frequent exposure or indulgence; very sophisticated especially because of surfeit; versed in the ways of the world
:*:boite::boîte ; French: "Box."  a small restaurant or nightclub.
::boutonniere::boutonnière ; noun a flower that is worn in a buttonhole.
:*:canape::canapé  ; noun an appetizer consisting usually of a thin slice of bread or toast spread with caviar or cheese or other savory food
:*:celebre::célèbre ; Cause célèbre An incident that attracts great public attention.
:*:chaine::chaîné ; / (ballet) noun A series of small fast turns, often with the arms extended, used to cross a floor or stage.
:*:cinema verite::cinéma vérité ; noun a movie that shows ordinary people in actual activities without being controlled by a director
::cinemas verite::cinémas vérit ; noun a movie that shows ordinary people in actual activities without being controlled by a directoré
::champs-elysees::Champs-Élysées ; noun a major avenue in Paris famous for elegant shops and cafes
::charge d'affaires::chargé d'affaires ; noun the official temporarily in charge of a diplomatic mission in the absence of the ambassador
:*:chateau::château ; noun an impressive country house (or castle) in France
:*:cliche::cliché ; noun a trite or obvious remark; clichéd adj. repeated regularly without thought or originality
::cloisonne::cloisonné ; adj. (for metals) having areas separated by metal and filled with colored enamel and fired; noun enamelware in which colored areas are separated by thin metal strips
:*:consomme::consommé ; noun clear soup usually of beef or veal or chicken
:*:communique::communiqué ; noun an official report (usually sent in haste)
:*:confrere::confrère ; noun a person who is member of your class or profession
:*:cortege::cortège ; noun the group following and attending to some important person; a funeral procession
:*:coup d'etat::coup d'état ; noun a sudden and decisive change of government illegally or by force
:*:coup de tat::coup d'état ; noun a sudden and decisive change of government illegally or by force
:*:coup de grace::coup de grâce ; noun the blow that kills (usually mercifully)
:*:creche::crèche ; noun a hospital where foundlings (infant children of unknown parents) are taken in and cared for; a representation of Christ's nativity in the stable at Bethlehem
:*:coulee::coulée ; A stream of lava.  A deep gulch or ravine, frequently dry in summer.
::creme brulee::crème brûlée ; noun custard sprinkled with sugar and broiled
:*:crepe::crêpe ; noun a soft thin light fabric with a crinkled surface; paper with a crinkled texture; usually colored and used for decorations; small very thin pancake; verb cover or drape with crape
:*:creme caramel::crème caramel ; noun baked custard topped with caramel
::creme de cacao::crème de cacao ; noun sweet liqueur flavored with vanilla and cacao beans
::creme de menthe::crème de menthe ; noun sweet green or white mint-flavored liqueur
:*:crouton::croûton ; noun a small piece of toasted or fried bread; served in soup or salads
::creusa::Creüsa ; In Greek mythology, Creusa was the daughter of Priam and Hecuba.
::crudites::crudités ; noun raw vegetables cut into bite-sized strips and served with a dip
::curacao::curaçao ; noun flavored with sour orange peel; a popular island resort in the Netherlands Antilles
:*:dais::daïs ; noun a platform raised above the surrounding level to give prominence to the person on it
:*:debacle::débâcle ; noun a sudden and violent collapse; flooding caused by a tumultuous breakup of ice in a river during the spring or summer; a sound defeat
:*:debutante::débutant ; noun a sudden and violent collapse; flooding caused by a tumultuous breakup of ice in a river during the spring or summer; a sound defeat
::declasse::déclassé ; Fallen or lowered in class, rank, or social position; lacking high station or birth; of inferior status
::decolletage::décolletage ; noun a low-cut neckline on a woman's dress
::decollete::décolleté ; adj. (of a garment) having a low-cut neckline
:*:decor::décor ; noun decoration consisting of the layout and furnishings of a livable interior
::decoupage::découpage ; noun the art of decorating a surface with shapes or pictures and then coating it with vanish or lacquer; art produced by decorating a surface with cutouts and then coating it with several layers of varnish or lacquer
::degage::dégagé ; adj. showing lack of emotional involvement; free and relaxed in manner
::deja vu::déjà vu ; noun the experience of thinking that a new situation had occurred before
::demode::démodé ; adj. out of fashion
::denoument::dénoument ; Narrative structure.  (Not in most dictionaries)
::derailleur::dérailleur ; (cycling) the mechanism on a bicycle used to move the chain from one sprocket (gear) to another
:*:derriere::derrière ; noun the fleshy part of the human body that you sit on
::deshabille::déshabillé ; noun the state of being carelessly or partially dressed
::detente::détente ; noun the easing of tensions or strained relations (especially between nations)
::diamante::diamanté ; noun adornment consisting of a small piece of shiny material used to decorate clothing
:*:discotheque::discothèque ; noun a public dance hall for dancing to recorded popular music
:*:divorcee::divorcée ; noun a divorced woman or a woman who is separated from her husband
:*:doppelganger::doppelgänger ; noun a ghostly double of a living person that haunts its living counterpart
:*:eclair::éclair ; noun oblong cream puff
::eclat::éclat ; noun brilliant or conspicuous success or effect; ceremonial elegance and splendor; enthusiastic approval
::el nino::El Niño ; noun the Christ child; (oceanography) a warm ocean current that flows along the equator from the date line and south off the coast of Ecuador at Christmas time
::elan::élan ; noun enthusiastic and assured vigor and liveliness; distinctive and stylish elegance; a feeling of strong eagerness (usually in favor of a person or cause)
:*:emigre::émigré ; noun someone who leaves one country to settle in another
:*:entree::entrée ; noun the act of entering; the right to enter; the principal dish of a meal; something that provides access (to get in or get out)
::entrepot::entrepôt ; noun a port where merchandise can be imported and then exported without paying import duties; a depository for goods
::entrecote::entrecôte ; Cut of meat taken from between the ribs
:*:epee::épée ; noun a fencing sword similar to a foil but with a heavier blade
::etouffee::étouffée ; A Cajun shellfish dish.
:*:facade::façade ; noun the face or front of a building; a showy misrepresentation intended to conceal something unpleasant
:*:fete::fête ; noun an elaborate party (often outdoors); an organized series of acts and performances (usually in one place); verb have a celebration
::faience::faïence ; noun an elaborate party (often outdoors); an organized series of acts and performances (usually in one place); verb have a celebration
:*:fiance::fiancé ; noun a man who is engaged to be married. fiancee ; noun a woman who is engaged to be married
::filmjolk::filmjölk ; Nordic milk product.
::fin de siecle::fin de siècle ; adj. relating to or characteristic of the end of a century (especially the end of the 19th century)
:*:flambe::flambé ; verb pour liquor over and ignite (a dish)
::fleche::flèche ; a type of church spire; a team cycling competition; an aggressive offensive fencing technique; a defensive fortification; ships of the Royal Navy
::Fohn wind::Föhn wind ; A type of dry, relatively warm, downslope wind that occurs in the lee (downwind side) of a mountain range.
::folie a deux::folie à deux ; noun the simultaneous occurrence of symptoms of a mental disorder (as delusions) in two persons who are closely related (as siblings or man and wife)
::folies a deux::folies à deux
::fouette::fouetté ; From Ballet: The working leg is extended and whipped around
:*:frappe::frappé ; noun thick milkshake containing ice cream; liqueur poured over shaved ice; a frozen dessert with fruit flavoring (especially one containing no milk)
:*:fraulein::fräulein ; noun a German courtesy title or form of address for an unmarried woman
:*:garcon::garçon ; A waiter, esp. at a French restaurant
::gardai::gardaí ; Policeman or policewoman
:*:gateau::gâteau ; noun any of various rich and elaborate cakes
::gemutlichkeit::gemütlichkeit ; Friendliness.
::glace::glacé ; adj. (used especially of fruits) preserved by coating with or allowing to absorb sugar
::glogg::glögg ; noun Scandinavian punch made of claret and aquavit with spices and raisins and orange peel and sugar
::gewurztraminer::Gewürztraminer ; An aromatic white wine grape variety that grows best in cooler climates
::gotterdammerung::Götterdämmerung ; noun myth about the ultimate destruction of the gods in a battle with evil
::grafenberg spot::Gräfenberg spot ;  An erogenous area of the vagina.
:*:habitue::habitué ; noun a regular patron
::ingenue::ingénue ; noun an actress who specializes in playing the role of an artless innocent young girl
::jager::jäger ; A German or Austrian hunter, rifleman, or sharpshooter
:*:jalapeno::jalapeño ; noun hot green or red pepper of southwestern United States and Mexico; plant bearing very hot and finely tapering long peppers; usually red
::jardiniere::jardinière ; A preparation of mixed vegetables stewed in a sauce.  An arrangement of flowers.
::krouzek::kroužek ; A ring-shaped diacritical mark (°), whose use is largely restricted to Å, å and U, u.
::kummel::kümmel ; noun liqueur flavored with caraway seed or cumin
::kaldolmar::kåldolmar ; Swedish cabbage rolls filled with rice and minced meat.
::landler::ländler ; noun a moderately slow Austrian country dance in triple time; involves spinning and clapping; music in triple time for dancing the landler
::langue d'oil::langue d'oïl ; noun medieval provincial dialects of French spoken in central and northern France
::la nina::La Niña ; Spanish:'The Girl' is an oceanic and atmospheric phenomenon that is the colder counterpart of El Niño.
::litterateur::littérateur ; noun a writer of literary works
::lycee::lycée ; noun a school for students intermediate between elementary school and college; usually grades 9 to 12
::macedoine::macédoine ; noun mixed diced fruits or vegetables; hot or cold
::macrame::macramé ; noun a coarse lace; made by weaving and knotting cords; verb make knotted patterns
::maitre d'hotel::maître d'hôtel ; noun a dining-room attendant who is in charge of the waiters and the seating of customers
::malaguena::malagueña ; A Spanish dance or folk tune resembling the fandango.
::manana::mañana ; Spanish: Tomorrow.
::manege::manège ; The art of horsemanship or of training horses.
::manque::manqué ; adj. unfulfilled or frustrated in realizing an ambition
::materiel::matériel ; noun equipment and supplies of a military force
:*:matinee::matinée ; noun a theatrical performance held during the daytime (especially in the afternoon)
::melange::mélange ; noun a motley assortment of things
:*:melee::mêlée ; noun a noisy riotous fight
::menage a trois::ménage à trois ; noun household for three; an arrangement where a married couple and a lover of one of them live together while sharing sexual relations
::menages a trois::ménages à trois
::mesalliance::mésalliance ; noun a marriage with a person of inferior social status
::metier::métier ; noun an occupation for which you are especially well suited; an asset of special worth or utility
::minaudiere::minaudière ; A small, decorative handbag without handles or a strap.
::mobius::Möbius ; noun a continuous closed surface with only one side; formed from a rectangular strip by rotating one end 180 degrees and joining it with the other end
::moire::moiré ; adj. (of silk fabric) having a wavelike pattern; noun silk fabric with a wavy surface pattern
:*:moireing::moiré ; A textile technique that creates a wavy or "watered" effect in fabric.
::motley crue::Mötley Crüe ; American heavy metal band formed in Hollywood, California in 1981.
::motorhead::Motörhead ; English rock band formed in London in 1975.
:*:naif::naïf ; adj. marked by or showing unaffected simplicity and lack of guile or worldly experience; noun a naive or inexperienced person
::naive::naïve ; adj. inexperienced; marked by or showing unaffected simplicity and lack of guile or worldly experience
::naiver::naïver ; See above.
::naives::naïves ; See above.
::naivete::naïveté ; See above.
::nee::née ; adj. (meaning literally `born') used to indicate the maiden or family name of a married woman
:*:negligee::negligée ; noun a loose dressing gown for women
::neufchatel::Neufchâtel ; a cheese
::nez perce::Nez Percé ; noun the Shahaptian language spoken by the Nez Perce; a member of a tribe of the Shahaptian people living on the pacific coast
:*:noel::Noël ; French:  Christmas.
::número uno::número uno ; Number one
::objet trouve::objet trouvé ; An object found or picked up at random and considered aesthetically pleasing.
::objets trouve::objets trouvé ; See above.
:*:ombre::ombré ;  (literally "shaded" in French) is the blending of one color hue to another.  A card game.
::omerta::omertà ; noun a code of silence practiced by the Mafia; a refusal to give evidence to the police about criminal activities
::opera bouffe::opéra bouffe ; noun opera with a happy ending and in which some of the text is spoken
::operas bouffe::opéras bouffe ; see above.
::opera comique::opéra comique ; noun opera with a happy ending and in which some of the text is spoken
::operas comique::opéras comique ; See above.
::outre::outré ; adj. conspicuously or grossly unconventional or unusual
::papier-mache::papier-mâché ; noun a substance made from paper pulp that can be molded when wet and painted when dry
::passe::passé ; adj. out of fashion
::piece de resistance::pièce de résistance ; noun the most important dish of a meal; the outstanding item (the prize piece or main exhibit) in a collection
::pied-a-terre::pied-à-terre ; noun lodging for occasional or secondary use
::plisse::plissé ; (Of a fabric) chemically treated to produce a shirred or puckered effect.
:*:pina colada::Piña Colada ; noun a mixed drink made of pineapple juice and coconut cream and rum
:*:pinata::piñata ; noun plaything consisting of a container filled with toys and candy; suspended from a height for blindfolded children to break with sticks
:*:pinon::piñon ; noun any of several low-growing pines of western North America
::pirana::piraña ; noun small voraciously carnivorous freshwater fishes of South America that attack and destroy living animals
::pique::piqué ; noun tightly woven fabric with raised cords; a sudden outburst of anger; verb cause to feel resentment or indignation
::piqued::piquéd ;noun Animosity or ill-feeling, Offence taken. transitive verb To wound the pride of To arouse, stir, provoke.
::più::più ; Move.
::plie::plié ; A movement in ballet, in which the knees are bent while the body remains upright
::precis::précis ; noun a sketchy summary of the main points of an argument or theory; verb make a summary (of)
:*:protege::protégé ; noun a person who receives support and protection from an influential patron who furthers the protege's career.  protegee ; noun a woman protege
:*:puree::purée ; noun food prepared by cooking and straining or processed in a blender; verb rub through a strainer or process in an electric blender
::polsa::pölsa ; A traditional northern Swedish dish which has been compared to hash
::pret-a-porter::prêt-à-porter ; Ready-to-wear / Off-the-rack.
::Quebecois::Québécois ; adj. of or relating to Quebec
::raison d'etre::raison d'être ; noun the purpose that justifies a thing's existence; reason for being
::recherche::recherché ; adj. lavishly elegant and refined
::retrousse::retroussé ; adjective (of a person's nose) turned up at the tip in an attractive way.
::risque::risqué ; adjective slightly indecent and liable to shock, especially by being sexually suggestive.
::riviere::rivière ; noun a necklace of gems that increase in size toward a large central stone, typically consisting of more than one string.
::roman a clef::roman à clef ; noun a novel in which actual persons and events are disguised as fictional characters
::roue::roué ; noun a dissolute man in fashionable society
:*:saute::sauté ; adj. fried quickly in a little fat; noun a dish of sauteed food; verb fry briefly over high heat
:*:seance::séance ; noun a meeting of spiritualists
:*:senor::señor ; noun a Spanish title or form of address for a man; similar to the English `Mr' or `sir'. senora/señorita ; noun a Spanish title or form of address for a married woman; similar to the English `Mrs' or `madam'
:*:smorgasbord::smörgåsbord ; noun served as a buffet meal; a collection containing a variety of sorts of things
:*:soiree::soirée ; noun a party of people assembled in the evening (usually at a private house)
:*:souffle::soufflé ; noun light fluffy dish of egg yolks and stiffly beaten egg whites mixed with e.g. cheese or fish or fruit
::sinn fein::Sinn Féin ; noun an Irish republican political movement founded in 1905 to promote independence from England
::smorgastarta::smörgåstårta ; "sandwich-cake" or "sandwich-torte" is a dish of Swedish origin
::soigne::soigné ; adj. polished and well-groomed; showing sophisticated elegance
::sprachgefühl::sprachgefuhl ; The essential character of a language.
:*:soupcon::soupçon ; noun a slight but appreciable addition
::surstromming::surströmming ; Lightly salted fermented Baltic Sea herring.
:*:tete-a-tete::tête-à-tête ; adj. involving two persons; intimately private; noun a private conversation between two people; small sofa that seats two people
::touche::touché ; Acknowledgement of a hit in fencing or a point made at one's expense.
::tourtiere::tourtière ; A meat pie that is usually eaten at Christmas in Québec
:*:ubermensch::Übermensch ; noun a person with great powers and abilities
::ventre a terre::ventre à terre ; (French) At high speed (literally, belly to the ground.)
::vicuna::vicuña ; noun small wild cud-chewing Andean animal similar to the guanaco but smaller; valued for its fleecy undercoat; a soft wool fabric made from the fleece of the vicuna; the wool of the vicuna
::vin rose::vin rosé ; White wine.
::vins rose::vins rosé ; See above
::vis a vis::vis à vis ; adv. face-to-face
::vis-a-vis::vis-à-vis ; See above
::voila::voilà ; Behold.  There you are.

;-------------------------------------------------------------------------------
;  Capitalize dates
;-------------------------------------------------------------------------------
:C:monday::Monday
:C:tuesday::Tuesday
:C:wednesday::Wednesday
:C:thursday::Thursday
:C:friday::Friday
:C:saturday::Saturday
:C:sunday::Sunday

:C:january::January
:C:february::February
:C:april::April
:C:june::June
:C:july::July
:C:august::August
:C:september::September
:C:october::October
:C:november::November
:C:december::December

;-------------------------------------------------------------------------------
;  Items added via HotString Helpter appear down here
;-------------------------------------------------------------------------------
